#!/bin/csh -f
#This C shell script runs the test suite for RMPROP 2.1.2 and takes 1 argument,
#the test name, which follows the name of this script on the command line.
#
#This script also sets the following environment variables:
#  DIR :  current working directory (where this script is found)
# SDIR :  directory with scripts for test runs
# TDIR :  directory with test run input and output distributed files
# FDIR :  directory with fortran source codes
#
#          The following are machine-dependent and should be set by
#          hand by the end-user if this script does not recognize the
#          machine used.
#  FTN :  name of fortran compiler.
# LOAD :  name of loader
#FFLAGS:  compiler flags
# SDR  :  list of machine-dependent source codes to compile.  If your machine
#         is not recognized by this script, it is recommended that you set
#         this variable by hand and write your own codes to determine time
#         and date information.  See Section 6 of the RMPROP 2.1.2 manual
#LIBRS :  libraries that must be accessed by the compiler
#
#
#             initialize some variables
set TEST="0"
@ MKILL = 0
setenv DIR `pwd`
setenv SDIR ${DIR}/script
setenv TDIR ${DIR}/test
setenv FDIR ${DIR}/src
#
#parse the command line
#
if ( $#argv > 0 ) then
	if ( $#argv > 1 ) then
		echo "Tests must be run one at a time; ignoring command arguments following $1"
	endif
	set TEST="$1"
endif
#
#  Loop over possible test names
#
setenv READY 0
while ( "${READY}" == "0" )
	while ( "${TEST}" == "0" )
		echo "Test names are:"
		echo "	hfhfstr1"
		echo "	hfhfstr2"
		echo "	hfhfstr3"
		echo "	hfhfstr4"
                echo "	hfhfstr5"
		echo "	hehfr1"
		echo "	heh2cdr1"
		echo "	heh2cdr2"
		echo "	hfhfpbsr1"
		echo "	hfhfadr1"
		echo "	hfhfadr2"
		echo "	atdir1"
		echo "	atdir1.pspec"
		echo "	ehydr1"
		echo "	hei2r1"
                echo "	heh2tkr1"
                echo "	heh2tkr2"
		echo -n "Which test do you want to run? "
		set TEST="$<"
	end
	switch ( ${TEST} )
	case hfhfstr[1245]:
		setenv READY 1
		breaksw
	case hfhfstr3:
		if ( ! -r ${DIR}/hfhfstr2.17 ) then
			echo "${DIR}/hfhfstr2.17 is not readable or does not exist"
			echo "Test hfhfstr2 must be run prior to hfhfstr3"
			exit 1
		endif
                if ( ! -r ${DIR}/hfhfstr2.2 ) then
                        echo "${DIR}/hfhfstr2.2 is not available"
                        echo "Test hfhfstr2 must be run prior to hfhfstr3"
                        exit 1
                endif
		setenv READY 1
		breaksw
	case "hehfr1":
		setenv READY 1
		breaksw
	case heh2cdr1:
		setenv READY 1
		breaksw
	case heh2cdr2:
		setenv READY 1
		breaksw
	case hfhfpbsr1:
		setenv READY 1
		breaksw
	case hfhfadr1:
		setenv READY 1
		breaksw
	case hfhfadr2:
		if ( ! -r ${DIR}/hfhfadr1.8 ) then
			echo "${DIR}/hfhfadr1.8 is not readable or does not exist"
			echo "Test hfhfadr1 must be run prior to hfhfadr2"
			exit 1
		endif
		if ( ! -r ${DIR}/hfhfadr1.14 ) then
			echo "${DIR}/hfhfadr1.14 is not readable or does not exist"
			echo "Test hfhfadr1 must be run prior to hfhfadr2"
			exit 1
		endif
		setenv READY 1
		breaksw
	case atdir1:
		setenv READY 1
		breaksw
	case atdir1.pspec:
		setenv READY 1
		breaksw
	case ehydr1:
		setenv READY 1
		breaksw 
	case hei2r1:
		setenv READY 1
		breaksw 
	case heh2tkr1:
		setenv READY 1
		breaksw 
	case heh2tkr2:
		setenv READY 1
		breaksw 
	default:
		echo
		echo "${TEST}:  Invalid test name"
		echo
                if ($MKILL == 5) then
                  set TEST = "DIE"
                  setenv READY 1
                  breaksw
                else
		set TEST="0"
                @ MKILL++
                endif
	endsw
end
if ("${TEST}" == "DIE") then
  echo "Too many wrong test names"
else
# 
# Now create the environment variables FTN, LOAD, FFLAGS, LIBRS, and SDR
#             If your machine is not recognized by this script, comment
#             the following lines and uncomment the ones below, 
#             inserting the proper choices for your machine for these
#             environment variables.
setenv NAMER "`uname -m`"
setenv NAMER2 "`uname`"
if (  `expr  "${NAMER}" :   '^\(....\).*$'` == "CRAY" ) then
     echo This run is performed on a CRAY
     setenv FTN cf77
     setenv LOAD cf77
     unsetenv LIBRS
     setenv FFLAGS '-c -Wf,"-a static -dp -en"'
     setenv SDR "sdrcray.o"
else if ( `expr "${NAMER}" :  '^.*\(.....\)$'` == "alpha" ) then
     echo This run is performed on a DEC Alpha
     setenv FTN f77
     setenv LOAD 'f77 -O4 -v'
     unsetenv LIBRS
     setenv FFLAGS '-c -i4 -M -O4 -std'
     setenv SDR "sdralpha.o"
else if ( `expr "${NAMER}" :  '^.*\(.....\)$'` == "sun4c" ) then
     echo This run is performed on a SUN
     setenv FTN f77
     setenv LOAD f77
     setenv LIBRS "-llinpack -leispack"
     setenv FFLAGS "-ansi -c -O3 -temp=/usr/local/tmp"
     setenv SDR "sdrsun.o"
else if ( `expr "${NAMER}" :  '^.*\(...\)$'` == "AIX" ) then
     echo this run is performed on an IBM 
     setenv FTN xlf
     setenv LOAD xlf
     unsetenv LIBRS
     setenv FFLAGS '-c -O -Q -qfips'
     setenv SDR "sdrrs6000.o dateclock.o"
else if ( `expr "${NAMER}" :  '^.*\(....\)$'` == "IP21" ) then
     echo this run is performed on an SGI
     setenv FTN f77
     setenv LOAD f77
     setenv LIBRS "-lcomplib.sgimath"
     setenv FFLAGS '-c -mips4 -64 -O3 -Olimit=3000 -OPT:const_copy_limit=14956'
     setenv SDR "sdrsgi.o"
else if (  `expr  "${NAMER2}" :   '^\(....\).*$'` == "CRAY" ) then
     echo This run is performed on a CRAY
     setenv FTN cf77
     setenv LOAD cf77
     unsetenv LIBRS
     setenv FFLAGS '-c -Wf,"-a static -dp -en"'
     setenv SDR "scrcray.o"
else if ( `expr "${NAMER}" :  '^.*\(....\)$'` == "OSF1" ) then
     echo This run is performed on a DEC Alpha
     setenv FTN f77
     setenv LOAD 'f77 -O4 -v'
     unsetenv LIBRS
     setenv FFLAGS '-c -i4 -M -O4 -std'
     setenv SDR "sdralpha.o"
else if ( `expr "${NAMER}" :  '^.*\(.....\)$'` == "SunOS" ) then
     echo This run is performed on a SUN
     setenv FTN f77
     setenv LOAD f77
     setenv LIBRS "-llinpack -leispack"
     setenv FFLAGS "-ansi -c -O3 -temp=/usr/local/tmp"
     setenv SDR "sdrsun.o"
else if ( `expr "${NAMER2}" :  '^.*\(...\)$'` == "AIX" ) then
     echo this run is performed on an IBM 
     setenv FTN xlf
     setenv LOAD xlf
     unsetenv LIBRS
     setenv FFLAGS '-c -O -Q -qfips'
     setenv SDR "sdrrs6000.o dateclock.o"
else if ( `expr "${NAMER2}" :  '^.*\(....\)$'` == "IRIX64" ) then
     echo this run is performed on an SGI
     setenv FTN xlf
     setenv LOAD xlf
     setenv LIBRS "-lcomplib.sgimath"
     setenv FFLAGS '-c -mips4 -64 -O3 -Olimit=3000 -OPT:const_copy_limit=14956'
     setenv SDR "sdrsgi.o"
else
     echo "the requested machine ${NAMER} is unknown"
     echo "the requested machine ${NAMER2} is unknown"
endif
#             End of commenting for unknown machine type.
#             Uncomment the following lines:
#    setenv FTN (fortran compiler command)
#    setenv FFLAGS (fortran compiler flags)
#    setenv LOAD (loader command)
#    setenv LIBRS (libraries which must be linked with the code)
#    setenv SDR (code for machine-specific routines)
#             End of uncommenting
echo "Beginning test ${TEST}"
${SDIR}/${TEST}.csh
endif
