       SUBROUTINE GNSCAT(PD,ID,JICT,R0,RASY,IS,EFACT,NDIM,RMAX,NSECT,
     1R4MT,AKMT,AFMT,AGMT,AEMT,AHMT,AK0MT,SPRRE,SPRIM,MAT,MAT2,TEMPR1,
     2R1MT,R2MT,R3MT,U,LAGS,IOPT2,IOPT3,LAM0SQ,L,LAMSQ,RABC,JIN,
     3ETA,JTOT,IE,OAM,LPSMH,LBGS,NOPEN,LPSINF,LPEPS,EVALI,PMAT,ISI,
     4ISJ2,EI,CENT,ETOT,LPRINT,EFCNI,IMATCH,TMU,ITPRNT,
     5EFASY,LTASY,ITCOL,BPOT,INE,IPRINT,RPSM,NIND,IND,EPSMAG,EPSPH,
     6LPSYM,IERR,EPS,PCDMT,IPIV,TEMP4,EPSDR)
C***This subroutine is for use with RMPROP: Version 2.1.2.              3M22R95
C***GNSCAT is called by PROGRAM RMPROP.
C***  This subroutine calculates the elements of the reactance matrix.
C***  It calculates and prints the information determined by the logical
C***  variables in LGS, as well as the scattering matrix.  The
C***  subroutine is applicable to the general problem with open and
C***  closed channels.
C***    PD is the number of channels propagated.
C***    JICT=MIN0(ICT,PD)
C***    R0 is the location of the left hand side of the first sector.
C***    RASY is the location of the right hand side of the current
C***  sector.
C***  The logical variables LCONV and LENTER are set FALSE by the
C***  calling program each time a new calculation of the propagator is
C***  started.  The first time subroutine GNSCAT is called, the
C***  subroutine sets LENTER to TRUE.  LCONV is set TRUE for all RASY
C***  .GE.RMAX.
C***    LSTOP1 is TRUE in the third sector before the last allowed
C***  by NSECT.
C***    LSTOP2 is TRUE in the sector before the last allowed.
C***    LEARLY is TRUE if the title for the sector has previously been
C***  printed in calling program.
C***    LASY is TRUE when RABC(IS).GT.RBIG.
C***  Since LR4MT must be true, only R4MT is propagated and the
C***  calculation of the reactance matrix is simplified.
C***  Note that at RASY it is possible to match to SIN and COS functions
C***  (SIN/COS) or to Ricatti-Bessel functions (RJL/RNL) in the open
C***  channels while retaining exactly the same form for the equations
C***  to be solved although the definitions of AEMT,AFMT,AGMT AND AHMT
C***  differ for the two cases.
C***  If LBES is TRUE matching is to Ricatti-Bessel functions.
C***  Note that at RASY the appropriate wave number is the asymptotic
C***  wave number.
C***  The matrices A and M referred to below are simply intermediates
C***  in the calculation of the reactance matrix.  For details consult
C***  the chapter on RMPROP: Version 2.0 in MOTECC-93, Modern Techniques in
C***  Computational Chemistry, edited by Enrico Clementi.
C***  the irregular Ricatti-Bessel functions and the reactance matrix
C***  sign follow the convention of Truhlar, Abdallah, and Smith.
C***    LAGS is LGS read in PRSCAT and governs printing when
C***  calculations have stopped, and LBGS governs printing at
C***  intermediate distances defined here by LPSMH .EQ. .TRUE.
C***  the meaning of LAGS(I) and LBGS(I) is the same as LGS(I) below.
C***********************************************************************
C***  The logical variables LGS are defined as follows  :
C Variable  If TRUE
C
C  LGS(1)   Each time the scattering matrix is printed also print R, the
C           midpoint of the sector, and EFACT.
C  LGS(2)   Print the scattering matrix.
C
C       Select one of the following options (J) by setting the integer
C       input variable IOPT2 equal to J.
C       Option (J)
C         (1)   Each time it is calculated.
C         (2)   For the previous and current sectors after the
C               calculations converge.
C         (3)   In the last sector only.
C
C  LGS(3)   Check unitarity and print checks each time the scattering
C           matrix is printed.
C
C  LGS(4)   In the last sector calculate and print the phase shifts.
C
C  LGS(5)   In the last sector calculate and print the cross sections.
C
C  LGS(6)   In the last sector calculate and print the transition
C           probabilities.
C
C  LGS(7)   In the last sector print the reactance matrix.
C
C  LGS(8)   In the last sector try to calculate and print the quantities
C           requested in LGS(4),LGS(5), and LGS(6) even if the
C           calculations are terminated before convergence is reached.
C
C  LGS(9)   Calculate the symmetrized reactance matrix.
C       Select one of the following options by setting
C       the integer input variable IOPT3 equal to J.
C       Option (J)
C         (1)   Symmetrize the reactance matrix by imposing the
C               lower left triangle on the upper right.
C         (2)   Symmetrize the reactance matrix by imposing the
C               upper right triangle on the lower left.
C         (3)   Symmetrize the reactance matrix by setting
C               RSCAT(I,J)=RSCAT(J,I) equal to the arithmetic
C               mean of the originally calculated off diagonal
C               elements.
C         (4)   Do all of the above.
C
C       LGS(9) must be true if any of the following are true:
C
C  LGS(10)  In the last sector print the symmetrized reactance matrix.
C
C  LGS(11)  In the last sector print the symmetrized scattering matrix
C           and check unitarity.
C
C  LGS(12)  From the symmetrized matrices calculate and print the
C           quantities requested in LGS(4), LGS(5),and LGS(6).
C
C  LGS(13)  Write the symmetrized reactance matrix onto tape 7 in
C           format requested by Brandt, Truhlar, Smith D.C.S. program.
C
C  LGS(14)   Write JTOT, the energy and the T matrix to tape 10 using
C            1X,I5,1PE15.8 and 1X,1PE13.6 format. EXSCAT will do this.
C
C  LGS(15)   Calculate and write the eigenphases. The eigenphases as a
C            function of R will be written with R on tape 11, and the
C            eigenphases, R and the eigenvectors will be written on tape
C            16.
C***********************************************************************
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      INCLUDE 'parameter.inc'
      DOUBLE PRECISION LAM0SQ,LAMSQ,MAT,MAT2
      INTEGER OAM,PD,PD1
      COMMON/PRNTCM/IUNITS,IFORRR
      COMMON/SROWCM/IRWSPT,IRWNEG
      COMMON/LCM/LDUM1,LBES,LCONV,LEARLY,LENTER,LR4MT,LSTOP1,LSTOP2
      COMMON/TIMCOM/TIMC(50)
      DIMENSION R4MT(IDX,IDX),ETA(IDX),AKMT(IDX),AFMT(IDX),AGMT(IDX),
     1ISI(IDX,2),AHMT(IDX),SPRRE(IDX,IDX),SPRIM(IDX,IDX),U(IDX,2),
     2MAT(IDX,IDX*2),MAT2(IDX,IDX),LGS(15),LAM0SQ(IDX),LAMSQ(IDX),
     3RABC(NSECTX),L(IDX),ISJ2(IDX,NVIBX),JIN(IDX,NANX),OAM(10),
     4AEMT(IDX),LAGS(16),LBGS(15),EVALI(IDX),PMAT(IDX,IDX),EI(IDX),
     5BPOT(IDX,IDX,NVIB1X),CENT(IDX),EFCNI(IDX,IDX),EFASY(IDX,IDX),
     6RPSM(20),IND(10,2),LPSYM(8),AK0MT(IDX),TEMPR1(IDX,IDX),
     7PCDMT(NBARX),TEMP4(IDX,8)
      DIMENSION R1MT(IDX,IDX),R2MT(IDX,IDX),R3MT(IDX,IDX)
      INTEGER IPIV(IDX)
      LOGICAL LDUM1,LBES,LCONV,LEARLY,LENTER,LR4MT,LSTOP1,LSTOP2,LTASY,
     1LPSINF,LPRINT,LPEPS,LSYM,LGS,LU,LPSMH,LAGS,LBGS,LSYM2,LSYM3,
     2LSYM4,L1,L2,L3,L4,LPSYM
      WRITE(6,669)
  669 FORMAT(1X,9HIn GNSCAT)

C***Initialize logical variables L1, L2, L3, L4, LSYM.

      L1=.FALSE.
      L2=.FALSE.
      L3=.FALSE.
      L4=.FALSE.
      LSYM=.FALSE.

      CALL SECOND(TIME1)
      PI=3.14159265358979323846

C***If any errors occur in the asymptotic analysis, IERR will be set
C***to a nonzero value.

      IERR=0

C***Calculate symmetry of raw R4MT matrix and the average relative
C***difference of the off-diagonal elements.
C***Initialize timing element TIMES1.

      TIMES1=0.0D0
      IF(LPSYM(4))THEN
      CALL SECOND(TIMES1)
      RSYM=0.0D0
      RSYMA=0.0D0
      DO 703 IROW=1,PD
         DO 703 ICOM=IROW,PD
            BOTT=MAX(ABS(R4MT(IROW,ICOM)),ABS(R4MT(ICOM,IROW)))
            RSYQM=ABS(R4MT(IROW,ICOM)-R4MT(ICOM,IROW))/BOTT
            RSYMA=RSYMA+RSYQM
            RSYM=MAX(RSYM,RSYQM)
  703 CONTINUE
      RSYMA=RSYMA/DBLE(PD*(PD+1)/2)
      WRITE(6,704)RSYM,RSYMA
  704 FORMAT(4X,44HSymmetry check on raw R4MT: maximum relative,
     126H differece of off diagonal/4X,9HElements ,1PE15.8,
     2/4X,28Haverage relative difference:,1PE15.8)

C***Print out the raw R4MT.

      WRITE(6,7044)
 7044 FORMAT(/,3X,8HRaw R4MT/)

      CALL PRNTM2(R4MT,PD,PD,ID)
      CALL SECOND(TIMES2)
      TIMC(12)=TIMC(12)+TIMES2-TIMES1
      END IF
      PD1=PD+1

C***Set logical variables to initial values-these may change during the
C***subroutine.  Note that LCONV is not really used-one must manually
C***converge with respect to RMAX using the RPSM(I).

      LCONV=.FALSE.
      LSYM=.FALSE.
      LSYM2=.FALSE.
      LSYM3=.FALSE.
      LSYM4=.FALSE.

C***Reassign LGS(I) as either LAGS(I) or LBGS(I) depending in LPSMH.
C***For a discussion of LPSMH see the driver, RMPROP.

      IF(.NOT.LPSMH)GOTO 901
      DO 902 I=1,15
  902 LGS(I)=LBGS(I)
      GOTO 903
  901 DO 904 I=1,15
  904 LGS(I)=LAGS(I)
  903 CONTINUE

C***Copy EFCNI (not to be modified) to 2nd part of MAT. Then if MATCH
C***is called,
C***It will return the local eigenvectors in MAT. By copying EFCNI
C***here we don't need to distinguish between matching options later.
C***Recall these are actually the transposed eigenvectors.

      DO 537 I=1,NDIM
         DO 537 J=1,NDIM
            MAT(J,I+NDIM)=EFCNI(I,J)
  537 CONTINUE

C***Calculate wave vector squared used to match.
C***For safety's sake initialize ICT.

      ICT=JICT
      IF(IMATCH.EQ.1)GOTO401
      IF(IMATCH.EQ.2)GOTO402
      DO 403 I=1,NDIM
  403 EVALI(I)=LAMSQ(I)
      GOTO 401
  402 CALL MATCH(ISI,EI,JIN,CENT,L,EVALI,U,
     1U(1,2),ID,RASY,NDIM,TMU,ETOT,LPRINT,JTOT,NOPEN,BPOT,
     2MAT(1,NDIM+1),PCDMT,TEMP4)
      DO 4021 I=1,NDIM
         EVALI(I)=EVALI(I)*TMU
 4021 CONTINUE
  401 IF(IMATCH.EQ.0)ICT=JICT
      IF(IMATCH.NE.0)ICT=NOPEN
      IF(IMATCH.GT.0)PD=MAX0(PD,NOPEN)
      ICTP1=ICT+1
      IF(ICT.EQ.0)RLAST=RASY
      IF(NOPEN.EQ.0)RETURN

C***Calculate the absolute values of the asymptotic channel wave
C***numbers.

      DO 911 I=1,PD
  911 AKMT(I)=EVALI(I)

C***Form transformation between local basis and asymptotic basis.
C***MAT will contain the transformation matrix.

      IF(.NOT.LTASY)THEN
      DO 9111 I=1,PD
         DO 9111 J=1,PD
            MAT2(J,I)=R4MT(J,I)
 9111 CONTINUE
      END IF

      IF(.NOT.LTASY)GOTO 910
      CALL SECOND(TIMEM1)

C***Note we wanted transpose of vectors here.

      CALL DGEMM('T','N',PD,NDIM,PD,1.0D0,MAT(1,NDIM+1),IDX,EFASY,IDX,
     10.0D0,MAT,IDX)

C***Copy transformation.

      DO 920 I=1,PD
         DO 920 J=1,PD
            MAT2(J,I)=MAT(J,I)
920   CONTINUE

C***Current storage in MAT:
C***1st PD columns: transformation.
C***2nd PD columns: blank.
C***MAT2: transformation.

      CALL SECOND(TIMEM2)
      TIMC(19)=TIMC(19)+TIMEM2-TIMEM1

C***Initialize and calculate various quantities used to check results.
C***FSYM is the sum of the diagonal elements of EFASY (the asymptotic
C***basis), ESYM is the sum of the diagonal elements of EFCNI (the
C***local sector basis), and RSYM is the sum of the squares of all the
C***elements of RSCAT.

      IF(LPSYM(8))THEN
      CALL SECOND(TIMES1)
      FSYM=0.0
      ESYM=0.0
      RSYM=0.0
      DO 708 I=1,PD
         FSYM=FSYM+EFASY(I,I)
         ESYM=ESYM+EFCNI(I,I)
  708 CONTINUE
      DO 7081 I=1,PD
      DO 7081 J=1,PD
 7081 RSYM=RSYM+MAT2(J,I)**2
      WRITE(6,709)PD,ICT,NOPEN,NDIM,RSYM,FSYM,ESYM
  709 FORMAT(1X,17HPD,ICT,NOPEN,NDIM,4I9,/3X,14HRSYM,FSYM,ESYM,
     13(1PE15.8))

C***Write out the matrices above if desired.

      WRITE(6,9812)
 9812 FORMAT(1X,'EFASY,EFCNI and TRANS')
      CALL PRNTM2(EFASY,PD,PD,ID)
      CALL PRNTM2(EFCNI,PD,PD,ID)
      CALL PRNTM2(MAT,PD,PD,ID)
      CALL SECOND(TIMES2)
      TIMC(16)=TIMC(16)+TIMES2-TIMES1
      END IF

C***Now calculate inverse transformation.

C***Current storage in MAT:
C***1st PD columns: transformation.
C***2nd PD columns: blank.
C***MAT2: transformation.

      DO 922 IP=1,PD
      DO 922 IQ=1,PD
      MAT(IQ,IP+PD)=0.0
  922 CONTINUE

      DO 658 I=1,PD
  658 MAT(I,I+PD)=1.0

C***Current storage in MAT:
C***1st PD columns: transformation.
C***2nd PD columns: unit matrix.
C***MAT2: transformation.

      CALL SECOND(TIMGL1)

C***The code through the line 'ELSE' below calculates the inverse
C***transformation for single-channel runs: otherwise use DGETRF.

      IF(PD.EQ.1)THEN
      MAT(1,PD+1)=MAT(1,PD+1)/MAT(1,1)
      ELSE
         IERR=0
         CALL MINV(MAT,PD,IDX,U,DET,EPS,PD,0)                           6M7R94
         IF(DET.EQ.0.D0)IERR=1                                          6M7R94
      CALL DGETRF(PD,PD,MAT,IDX,IPIV,IERR)
      IF(IERR.EQ.0)GO TO 536
      WRITE(6,538)IERR
  538 FORMAT(/1X,'On return from inversion of the transformation',
     $       /1X,'matrix, IERR = ',I5)
      RETURN
  536 CONTINUE
       CALL DGETRS('N',PD,PD,MAT,IDX,IPIV,MAT(1,PD+1),IDX,IERR)         5M10R94
       IF(IERR.NE.0)THEN                                                5M10R94
           WRITE(6,538)IERR                                             5M10R94
           RETURN                                                       5M10R94
       ENDIF                                                            5M10R94
      END IF                                                            5M10R94

C***Current storage in MAT:
C***1st PD columns: junk.
C***2nd PD columns: inverse transformation.
C***MAT2: transformation.

      CALL SECOND(TIMGL2)
      TIMC(17)=TIMC(17)+TIMGL2-TIMGL1

C***Write out a check on the inverse transformation.

      IF(LPSYM(8))THEN
      CALL SECOND(TIMES1)
      RSYM=0.0
      DO 710 I=1,PD
      DO 710 J=1,PD
  710 RSYM=RSYM+MAT(J,I+PD)**2
      WRITE(6,711)RSYM
  711 FORMAT(1X,22HInverse transformation ,1PE15.8)
      END IF
      CALL SECOND(TIMES2)
      TIMC(16)=TIMC(16)+TIMES2-TIMES1

C***Transform wave vectors-AKMT(I) will contain the I'th transformed
C***wave vector.

C***Current storage in MAT:
C***1st PD columns: junk.
C***2nd PD columns: inverse transformation.
C***MAT2: transformation.

      DO 912 I=1,PD
      ATEMP=0.0
      DO 913 J=1,PD
  913 ATEMP=ATEMP+MAT(I,J+PD)*EVALI(J)*MAT2(J,I)
  912 AKMT(I)=ATEMP

C***Note if LTASY is .FALSE. we skip to here.

  910 CONTINUE

C***In the loops below ICT should contain the number of asymptotically
C***open channels and ICTP1 is the number of the first asymptotically
C***closed channel.  The logic below says that if we find a closed
C***channel (wave vector .gt. zero) among the asymptotically open ones
C***or if we find an open channel among the asymptotically closed ones
C***then the channels are not yet in the proper order and so we cannot
C***quit yet.  If everything is proper we go to line 11, which begins
C***asymptotic boundary conditions.

      DO 5 I=1,ICT
      IF(AKMT(I).GT.0.0)GOTO 914
    5 AKMT(I)=DSQRT(-AKMT(I))
      IF(ICTP1.GT.PD)GO TO 11
      DO 7 I=ICTP1,PD
      IF(AKMT(I).LT.0.0)GOTO 914
    7 AKMT(I)=DSQRT(AKMT(I))
      GOTO 11
  914 WRITE(6,915)
  915 FORMAT(1X,51HIn GNSCAT the asymptotic order of channels has not
     1,14H been reached. )
      IF(RMAX.GT.RASY)RETURN
      STOP 981

C***Calculate the required quantities for the asymptotic region defined
C***by R=RASY where RASY is the right hand boundary of the current
C***sector.  For these diagonal matrices calculate and store only the
C***diagonal elements.
C***If LBES match to Ricatti-Bessel functions, otherwise to sine/cosine.

   11 IF(LBES)GO TO 15

C***Open channels matching to sin and cosine.

      WRITE(6,998)
  998 FORMAT(/6X,2H R,4X,13HWAVE VECTOR K,6X,3HK*R,6X,6HL*PI/2,6X,
     12H I,1X,4HL(I),1X,6HOAM(I),3X,10HEnergy no./)
      DO 10 I=1,ICT
      AKR=AKMT(I)*RASY
      ALPI=(DBLE(L(I))+DBLE(OAM(IE)))*PI/2.0
      WRITE(6,999)RASY,AKMT(I),AKR,ALPI,I,L(I),OAM(IE),IE
  999 FORMAT(1X,4(1PE12.5),3I5,4X,I5)
   10 CONTINUE

      DO 102 I=1,ICT
      AKR=AKMT(I)*RASY
      ALPI=(DBLE(L(I))+DBLE(OAM(IE)))*PI/2.0
      AFMT(I)=DCOS(AKR-ALPI)
      AGMT(I)=AKMT(I)*AFMT(I)
      AEMT(I)=DSIN(AKR-ALPI)
      AHMT(I)=AKMT(I)*AEMT(I)

C***Diagnostic write statement.

C     WRITE(6,999)AFMT(I),AGMT(I),AEMT(I),AHMT(I)
  102 CONTINUE

      GO TO 20

C***Open channels matching to Ricatti-Bessel functions (rjl/rnl).

   15 DO 18 I=1,ICT
         Z=AKMT(I)*RASY
         IF(OAM(IE).EQ.0)LL=L(I)
         IF(L(I).EQ.0)LL=OAM(IE)
         CALL RBES(LL,Z,RJL,RDJL,RNL,RDNL)
         AEMT(I)=RJL
         AFMT(I)=-RNL
         AGMT(I)=RDJL*AKMT(I)
   18 AHMT(I)=RDNL*AKMT(I)

C***Closed channels.

   20 IF(ICTP1.GT.PD) GO TO 40
      DO 30 I=ICTP1,PD
         AKR=AKMT(I)*RASY
         AEMT(I)=0.0
         AGMT(I)=0.0
         AFMT(I)=EXP(-AKR)
   30 AHMT(I)=AKMT(I)*AFMT(I)

C***If we do not wish to transform to the asymptotic basis there is no
C***need to calculate the transformation matrix or its inverse.

   40 IF(.NOT.LTASY)GOTO 640

C***RSYM will contain the sum of the squares of the elements of the
C***transformation matrix and FSYM will contain the sum of the squares
C***of the elements of the inverse transformation matrix.

C***Current storage in MAT:
C***1st PD columns: junk.
C***2nd PD columns: inverse transformation.
C***MAT2: transformation.

      CALL SECOND(TIMES2)
      RSYM=0.0
      FSYM=0.0
      DO 712 I=1,PD
      DO 712 J=1,PD
      RSYM=RSYM+MAT2(J,I)**2
  712 FSYM=FSYM+MAT(J,PD+I)**2
      WRITE(6,7121)
 7121 FORMAT(/1X,38HRSYM is the sum of the squares of the ,
     130Htransformation matrix elements/1X,19Hand FSYM is the sum,
     331H of the squares of the inverse ,
     4/1X,32H transformation matrix elements.)

      WRITE(6,713)RSYM,FSYM,PD
  713 FORMAT(1X,13HRSYM,FSYM,PD ,2(1PE15.8),I10)
      CALL SECOND(TIMES2)
      TIMC(16)=TIMC(16)+TIMES2-TIMES1
      CALL SECOND(TIMEM1)

      CALL DGEMM('N','N',PD,PD,PD,1.0D0,R4MT,IDX,MAT2,IDX,
     10.0D0,MAT,IDX)

C***Current storage in MAT:
C***1st PD columns: half transformed R4MT.
C***2nd PD columns: inverse transformation.
C***MAT2: transformation.

C***Now transfer the contents of MAT into TEMPR1 so we can transform
C***the R1MT, R2MT, R3MT if we are propagating the full R matrix
C***(inhomogeneous option).

      IF(.NOT.LR4MT)THEN
      DO 6000 I=1,IDX
      DO 6000 J=1,IDX
      TEMPR1(J,I)=MAT2(J,I)
6000  CONTINUE
      END IF
      CALL SECOND(TIMEM2)
      TIMC(18)=TIMC(18)+TIMEM2-TIMEM1

C***Done with MAT2, now use it for scratch.
C***It will contain the transformed R4MT matrix.

      CALL SECOND(TIMEM1)

C***Current storage in MAT:
C***1st PD columns: half transformed R4MT.
C***2nd PD columns: inverse transformation.
C***MAT2: transformation.
C***TEMPR1: transformation.

      CALL DGEMM('N','N',PD,PD,PD,1.0D0,MAT(1,PD+1),IDX,MAT,IDX,
     10.0D0,MAT2,IDX)

C***Current storage in MAT:
C***1st PD columns: half transformed R4MT.
C***2nd PD columns: inverse transformation.
C***MAT2: transformed R4MT.
C***TEMPR1: transformation.

      CALL SECOND(TIMEM2)
      TIMC(18)=TIMC(18)+TIMEM2-TIMEM1
      TIMC(18)=TIMC(18)+TIMEM2-TIMEM1

C***Print out the elements of the transformed R4MT matrix, and then
C***calculate maximum and average relative difference of off-diagonal
C***elements of transformed R4MT matrix.

      IF(LPSYM(5))THEN
      CALL SECOND(TIMES1)
      WRITE(6,992)
  992 FORMAT(1X,23HTransformed R4MT matrix)
      CALL PRNTM2(MAT2,PD,PD,ID)
      RSYM=0.0D0
      RSYMA=0.0D0
      DO 705 IROW=1,PD
       DO 705 ICOM=IROW,PD
         BOTT=MAX(ABS(MAT2(IROW,ICOM)),ABS(MAT2(ICOM,IROW)))
         RSYQM=ABS(MAT2(IROW,ICOM)-MAT2(ICOM,IROW))/BOTT
         RSYM=MAX(RSYM,RSYQM)
         RSYMA=RSYMA+RSYQM
  705 CONTINUE
      RSYMA=RSYMA/DBLE(PD*(PD+1)/2)
      WRITE(6,706)RSYM,RSYMA
  706 FORMAT(4X,43HSymmetry check on transformed R4MT: Maximum,
     127H relative difference of off/3X,17Hdiagonal elements ,1PE10.2,
     2/4X,28HAverage relative difference:,1PE10.2)
      CALL SECOND(TIMES2)
      TIMC(13)=TIMC(13)+TIMES2-TIMES1
      END IF

       IF(.NOT.LR4MT)THEN

C***First move MAT2 into R4MT to make room for scratch, and we will
C***move it back when we are done.

       DO 6001 I=1,IDX
       DO 6001 J=1,IDX
       R4MT(J,I)=MAT2(J,I)
6001   CONTINUE

C***Now move transformation from TEMPR1 into MAT2.

       DO 6002 I=1,IDX
       DO 6002 J=1,IDX
       MAT2(J,I)=TEMPR1(J,I)
6002   CONTINUE

C***Now transform R1MT just as we transformed R4MT.

      CALL DGEMM('N','N',PD,PD,PD,1.0D0,R1MT,IDX,MAT2,IDX,
     10.0D0,MAT,IDX)

C***Current storage in MAT:
C***1st PD columns: half transformed R1MT.
C***2nd PD columns: inverse transformation.
C***MAT2: transformation.
C***TEMPR1: transformed R1MT.

C***Now use TEMPR1 to temporarily hold the transformed R1MT.

      CALL DGEMM('N','N',PD,PD,PD,1.0D0,MAT(1,PD+1),IDX,MAT,IDX,
     10.0D0,TEMPR1,IDX)

C***Current storage in MAT:
C***1st PD columns: half transformed R1MT.
C***2nd PD columns: inverse transformation.
C***MAT2: transformation.
C***TEMPR1: transformed R1MT.

C***Now transfer the contents of TEMPR1 into R1MT.

      DO 6003 I=1,IDX
      DO 6003 J=1,IDX
      R1MT(J,I)=TEMPR1(J,I)
6003  CONTINUE

C***Now we transform the R2MT just as we transformed R1MT and R4MT.

      CALL DGEMM('N','N',PD,PD,PD,1.0D0,R2MT,IDX,MAT2,IDX,
     10.0D0,MAT,IDX)

C***Current storage in MAT:
C***1st PD columns: half transformed R2MT.
C***2nd PD columns: inverse transformation.
C***MAT2: transformation.
C***TEMPR1: still the transformed R1MT.

C***Now use TEMPR1 to temporarily hold the transformed R2MT.

      CALL DGEMM('N','N',PD,PD,PD,1.0D0,MAT(1,PD+1),IDX,MAT,IDX,
     10.0D0,TEMPR1,IDX)

C***Current storage in MAT:
C***1st PD columns: half transformed R2MT.
C***2nd PD columns: inverse transformation.
C***MAT2: transformation.
C***TEMPR1: fully transformed R2MT.

C***Now transfer the contents of TEMPR1 into R2MT.

      DO 6004 I=1,IDX
      DO 6004 J=1,IDX
      R2MT(J,I)=TEMPR1(J,I)
6004  CONTINUE

C***Now we transform the R3MT just as we transformed R1MT, R2MT, and R4MT.

      CALL DGEMM('N','N',PD,PD,PD,1.0D0,R3MT,IDX,MAT2,IDX,
     10.0D0,MAT,IDX)

C***Current storage in MAT:
C***1st PD columns: half transformed R3MT.
C***2nd PD columns: inverse transformation.
C***MAT2: transformation.
C***TEMPR1: still the transformed R2MT.
C***Now use TEMPR1 to temporarily hold the transformed R3MT.

      CALL DGEMM('N','N',PD,PD,PD,1.0D0,MAT(1,PD+1),IDX,MAT,IDX,
     10.0D0,TEMPR1,IDX)

C***Current storage in MAT:
C***1st PD columns: half transformed R3MT.
C***2nd PD columns: inverse transformation.
C***MAT2: transformation.
C***TEMPR1: fully transformed R3MT.

C***Now transfer the contents of TEMPR1 into R2MT.

      DO 6005 I=1,IDX
      DO 6005 J=1,IDX
      R3MT(J,I)=TEMPR1(J,I)
6005  CONTINUE

C***Now move the contents of R4MT back into MAT2.

      DO 6006 I=1,IDX
      DO 6006 J=1,IDX
      MAT2(J,I)=R4MT(J,I)
6006  CONTINUE
       END IF

  640 CONTINUE

C***If only want to propagate R4MT, matrix M is just R4MT.  Thus gO
C***on to calc matrix A.

      IF(LR4MT)GOTO 85
      IF(LENTER)GOTO 59

C***Calculate the required quantities in the small R region defined
C***by R=R0 where R0 is the left hand side of the first sector
C***for these diagonal matrices calculate and store only the diagonal
C***elements.
C***Construct matrix M.

      DO 50 I=1,PD
      IF(LAM0SQ(I).LT.0.0D0)GO TO 55

C***Closed channels.

      AK0MT(I)=DSQRT(LAM0SQ(I))
      GO TO 50

C***Open channels.

   55 AK0=DSQRT(-LAM0SQ(I))
      AK0R=AK0*R0
      AK0MT(I)=AK0*COS(AK0R)/SIN(AK0R)
   50 CONTINUE

   59 DO 60 I=1,PD
       DO 60 J=1,PD
          R1MT(I,J)=-R1MT(I,J)*AK0MT(J)
          IF(I.EQ.J)R1MT(I,J)=R1MT(I,J)+1.0
   60 CONTINUE

      DO 62 I=1,PD
       DO 62 J=1,PD
          MAT(J,I)=R1MT(J,I)
          MAT(J,I+PD)=R2MT(J,I)
   62 CONTINUE
      IERR=0
      CALL MINV(MAT,PD,IDX,U,DET,EPS,PD,0)                              6M7R94
      CALL DGETRF(PD,PD,MAT,IDX,IPIV,IERR)

      IF (IERR.EQ.0)GO TO 621
      WRITE(6,622)IERR
  622 FORMAT(/1X,'In GNSCAT using LR4MT = .FALSE., IERR is ',I3)
  621 CONTINUE
 
       CALL DGETRS('N',PD,PD,MAT,IDX,IPIV,MAT(1,PD+1),IDX,IERR)
      DO 65 I=1,PD
       DO 65 J=1,PD
          R1MT(J,I)=MAT(J,I+PD)
   65 CONTINUE

      DO 80 I=1,PD
       DO 80 J=1,PD
          R3MT(J,I)=R3MT(J,I)*AK0MT(I)
   80 CONTINUE

      CALL DGEMM('N','N',PD,PD,PD,1.0D0,R3MT,IDX,MAT(1,PD+1),IDX,
     10.0D0,TEMPR1,IDX)

      DO 81 I=1,PD
       DO 81 J=1,PD
          MAT2(J,I)=MAT2(J,I)+TEMPR1(J,I)
   81 CONTINUE
85    CONTINUE                                                          5M31R94
C***MAT2 now contains the full matrix M for LR4MT=.FALSE. or the R4     5M31R94
C***matrix if LR4MT=.TRUE..  Now we want to test its                    5M31R94
C***off-diagonal elements to consider dropping closed channels from     5M31R94
C***the asymptotic analysis.                                            5M31R94

C  201  JJ=NDR
C  351  JJM1=JJ-1
                                                                        
C       DO 4401 I=1,JJM1
C         A=ABS(MAT2(I,J))
C          B=ABS(MAT2(J,I))
C          IF(A.GT.EPSDR)GO TO 501
C          IF(B.GT.EPSDR)GO TO 501
C 4401  CONTINUE

C       JJ=JJM1
C       IF(JJ.GT.ICT)GO TO 351
C  501  NDR=JJ

      IF(PD.GT.ICT)THEN                                                 5M10R94
         CALL DROP(ICT,IDUM,IDUM2,DUM,PD,EPSDR,IDUM3,2,ID,SR2,          5M10R94
     &    MAT2,RABC(IS))                                                5M10R94
      ENDIF                                                             5M10R94
      WRITE(6,2250)IS,PD                                                5M10R94
2250  FORMAT(1X,9HIn sector,I6,25H the number of functions ,            5M10R94
     & 38Hincluded in the asymptotic analysis is,I5)                    5M10R94
                                                                        
C***For LR4MT=.TRUE. MAT2 contains transformed matrix R4MT.
C***This corresponds to matrix M in equation (87B) of MOTECC-93 chapteR.
C***Therefore go on to construct matrix A.


      DO 90 I=1,PD
       DO 90 J=1,PD
   90    MAT(J,I)=MAT2(J,I)*AHMT(I)

      DO 91 I=1,PD
   91    MAT(I,I)=MAT(I,I)-AFMT(I)

      DO 100 I=1,PD
       DO 100 J=1,PD
  100    MAT(J,I+PD)=MAT2(J,I)*AGMT(I)

      DO 101 I=1,PD
  101    MAT(I,I+PD)=MAT(I,I+PD)+AEMT(I)

      CALL SECOND(TIMGL1)

      IF(PD.EQ.1)THEN
      MAT(1,1+PD)=MAT(1,1+PD)/MAT(1,1)
      ELSE
         IERR=0
         CALL MINV(MAT,PD,IDX,U,DET,EPS,PD,0)                           6M7R94
         IF(DET.EQ.0.D0)IERR=1                                          6M7R94
      CALL DGETRF(PD,PD,MAT,IDX,IPIV,IERR)

      IF(IERR.EQ.0)GO TO 539
      WRITE(6,540)IERR
  540  FORMAT(/1X,'On return from inversion to determine the A matrix',
     $        /1X,'IERR = ',I5)
       RETURN
  539 CONTINUE
       CALL DGETRS('N',PD,PD,MAT,IDX,IPIV,MAT(1,PD+1),IDX,IERR)

      ENDIF

C***Current storage in MAT:
C***1st PD columns: junk.
C***2nd PD columns: almost reactance matrix.
C***MAT2: transformed R4MT matrix.

      CALL SECOND(TIMGL2)
      TIMC(17)=TIMC(17)+TIMGL2-TIMGL1

C***Calculate reactance matrix RSCAT using the open/open channels.
C***Recall that the AKMT are the asymptotic wave vectors squared.

      DO 122 J=1,ICT
         AFMT(J)=DSQRT(AKMT(J))
  122 CONTINUE

      DO 120 J=1,ICT
      ATEMP=1.0/AFMT(J)
        DO 120 M=1,ICT
           MAT2(M,J)=AFMT(M)*MAT(M,J+PD)*ATEMP
  120 CONTINUE

C***Current storage in MAT:
C***1st PD columns: junk.
C***2nd PD columns: almost reactance matrix.
C***MAT2: reactance matrix.

      IF(LPSYM(6))THEN
      CALL SECOND(TIMES1)
      RSYM=0.0D0
      RSYMA=0.0D0

      DO 707 IROW=1,ICT
       DO 707 ICOM=IROW,ICT
          BOTT=MAX(ABS(MAT2(IROW,ICOM)),ABS(MAT2(ICOM,IROW)))
          RSYQM=ABS(MAT2(IROW,ICOM)-MAT2(ICOM,IROW))/BOTT
          RSYM=MAX(RSYM,RSYQM)
          RSYMA=RSYMA+RSYQM
  707 CONTINUE

      RSYMA=RSYMA/DBLE(ICT*(ICT+1)/2)
      WRITE(6,718)RSYM,RSYMA
  718 FORMAT(4X,36HSymmetry check on reactance matrix: ,/4X,7HMaximum
     1,45H relative difference of off diagonal elements, 1PE10.2,
     2/4X,28HAverage relative difference:,1PE10.2)

      WRITE(6,994)
  994 FORMAT(1X,16HReactance matrix)
      CALL PRNTM2(MAT2,ICT,ICT,ID)

      CALL SECOND(TIMES2)
      TIMC(14)=TIMC(14)+TIMES2-TIMES1
      END IF

C***Calculate eigenphase sum from reactance matrix: this is the sum of
C***the tangents of the eigenvalues of the reactance matrix-LPEPS.
C***initialize ESUM.

      ESUM=0.0D0
      IF(LPEPS.OR.LGS(15))THEN
         IF(IMATCH.EQ.0)NOPEN=MIN0(NOPEN,JICT)

         DO 541 I=1,ICT
          DO 541 J=1,ICT
            MAT(J,I)=MAT2(J,I)
  541    CONTINUE
         CALL RS(IDX,NOPEN,MAT,AFMT,1,MAT,U,U(1,2),IERR)                4M20R94
         CALL EV2RSP(0,NOPEN,NOPEN,NBARX,IDX,PCDMT,TEMP4,IPIV,AFMT,
     1MAT,0,IERR)      

       IF(IERR.NE.0)THEN
       WRITE(6,544)IERR
  544   FORMAT(/1X,'On return from EV2RSP to determine the eigenphases'
     1  ,/1X,'IERR WAS ',I5)
           END IF

         DO 214 I=1,NOPEN
            AEMT(I)=ATAN(AFMT(I))
            ESUM=ESUM+AEMT(I)
  214    CONTINUE

      END IF

      IF(LPEPS)THEN
       WRITE(6,6)ESUM,RASY
    6  FORMAT(/1X,16HEigenphase sum (,1PE15.7,9H) at R = ,1PE15.7)
      END IF

      IF(LGS(15))THEN
       WRITE(11,8)RASY,ESUM
       WRITE(16,9)RASY,(AEMT(I),I=1,NOPEN),((MAT(I,J),J=1,NOPEN),I=1,
     1 NOPEN)
    8  FORMAT(1X,5(1PE15.7))
    9  FORMAT(8(1PE10.3))
      END IF

  121 CONTINUE

C***Calculate the real and imaginary parts of the scattering matrix
C***to calculate the imaginary part use the relation of the scattering
C***matrix to the reactance matrix, to calculate the real part use the
C***same plus some algebra.

      CALL SECOND(TIMEM1)

C***Current storage in MAT:
C***1st PD columns: junk.
C***2nd PD columns: almost reactance matrix.
C***MAT2: reactance matrix.

      CALL DGEMM('N','N',ICT,ICT,ICT,1.0D0,MAT2,IDX,MAT2,IDX,0.0D0,
     1MAT,IDX)

      CALL SECOND(TIMEM2)
      TIMC(18)=TIMC(18)+TIMEM2-TIMEM1

      DO 125 I=1,ICT
  125    MAT(I,I)=MAT(I,I)+1.0

      DO 936 IP=1,ICT
       DO 936 IQ=1,ICT
         MAT(IQ,IP+ICT)=2.0*MAT2(IQ,IP)
  936 CONTINUE

      CALL SECOND(TIMGL1)

      IF(ICT.EQ.1)THEN
       MAT(1,1+ICT)=MAT(1,1+ICT)/MAT(1,1)
      ELSE
         IERR=0
         CALL MINV(MAT,ICT,IDX,U,DET,EPS,ICT,0)                         6M7R94
         IF(DET.EQ.0.D0)IERR=1                                          6M7R94
         CALL DGETRF(ICT,ICT,MAT,IDX,IPIV,IERR)                         8M16R94

       IF(IERR.EQ.0)GO TO 542
       WRITE(6,543)IERR
  543  FORMAT(/1X,'On return from inversion to determine SIM, IERR = ',
     1 I5)
      RETURN
  542 CONTINUE
       CALL DGETRS('N',ICT,ICT,MAT,IDX,IPIV,MAT(1,ICT+1),IDX,IERR)

      ENDIF

C***Current storage in MAT:
C***1st ICT columns: junk.
C***2nd ICT columns: IMAG(S).
C***MAT2: reactance matrix.

      CALL SECOND(TIMGL2)
      TIMC(17)=TIMC(17)+TIMGL2-TIMGL1
      CALL SECOND(TIMEM1)

      CALL DGEMM('N','N',ICT,ICT,ICT,1.0D0,MAT(1,ICT+1),IDX,MAT2,IDX,
     10.0D0,MAT,IDX)

      DO 668 J=1,ICT
       DO 668 K=1,ICT
        MAT(K,J)=-MAT(K,J)
  668 CONTINUE
 
      CALL SECOND(TIMEM2)
      TIMC(18)=TIMC(18)+TIMEM2-TIMEM1

      DO 150 I=1,ICT
  150    MAT(I,I)=MAT(I,I)+1.0

C***Current storage in MAT:
C***1st ICT columns: RE(S).
C***2nd ICT columns: IMAG(S).
C***MAT2: reactance matrix.

      CALL SECOND(TIME2)
      TIMC(7)=TIMC(7)+TIME2-TIME1

      IF(LSYM)GO TO 1000
      IF((RASY.GE.RMAX).AND.(IPRINT.LE.1))GO TO 211
      IF(LENTER)GO TO 200

C***If this is the first time GNSCAT is entered do the following.

  173 CONTINUE
      IF(.NOT.((IOPT2.EQ.1).OR.LSTOP1))GO TO 175
      LU=LGS(3).OR.LSTOP1
      IF(LEARLY)GO TO 174
      CALL TITLES(IS,2,EFACT,ID,NSECT,LGS,RABC)
      LEARLY=.TRUE.
  174 CONTINUE
      CALL PRNTSU(MAT,MAT(1,ICT+1),U,ID,LU,ICT)
  175 IF(INE.GE.2)GO TO 200
      LENTER=.TRUE.
      RETURN

C***Test convergence of the real and imaginary parts of the scattering
C***matrix individually.

  200 IF((RASY.GE.RMAX).AND.(IPRINT.LE.1))GO TO 211
      IF((INE.GE.2).AND.(RASY.GE.RMAX))GO TO 211
      IF((RASY.LE.RMAX).AND.(IPRINT.LE.1))GOTO 220
      IF((INE.GE.2).AND.(RASY.LT.RMAX))GO TO 220
      IF((.NOT.LPSMH).AND.(RASY.LT.RMAX))GO TO 220
      IF(EPSMAG.GT.0.0D0)THEN
      WRITE(6,208)
  208 FORMAT(/,53HConvergence tests for magnitudes of S matrix elements)

C***Current storage in MAT:
C***1st ICT columns: RE(S).
C***2nd ICT columns: IMAG(S).
C***MAT2: reactance matrix.

      DO 209 K=1,NIND
       DO 209 J=1,ICT
        DO 209 I=1,ICT
           IF(I.NE.IND(K,1))GO TO 209
           IF(J.NE.IND(K,2))GO TO 209
           A=DSQRT(SPRRE(I,J)**2+SPRIM(I,J)**2)
           B=DSQRT(MAT(I,J)**2+MAT(I,J+ICT)**2)
           C=B
           LCONV=ABS(A-B)/C.LE.EPSMAG
           IF(RABC(IS).LT.RASY)WRITE(6,217)RPSM(IPRINT-1),RPSM(IPRINT-2)
           IF(RABC(IS).GE.RASY)WRITE(6,217)RASY,RPSM(IPRINT-1)

           WRITE(6,218)IND(K,1),IND(K,2),B,A,ABS(A-B)/C,LCONV

           IF((.NOT.LCONV).AND.(RASY.GE.RMAX))GO TO 211
           IF(.NOT.LCONV)GO TO 220
  209 CONTINUE

      END IF

      IF(EPSPH.GT.0.0D0)THEN
       WRITE(6,2081)
 2081  FORMAT(/,49HConvergence tests for phases of S matrix elements)

C***Current storage in MAT:
C***1st ICT columns: RE(S).
C***2nd ICT columns: IMAG(S).
C***MAT2: reactance matrix.

      DO 210 K=1,NIND
       DO 210 J=1,ICT
         DO 210 I=1,ICT
            IF(I.NE.IND(K,1))GO TO 210
            IF(J.NE.IND(K,2))GO TO 210
            D=ATAN(SPRIM(I,J)/SPRRE(I,J))
            E=ATAN(MAT(I,J+ICT)/MAT(I,J))
            F=E
            LCONV=ABS((D-E)/F).LE.EPSPH
            IF(RABC(IS).LT.RASY)WRITE(6,217)RPSM(IPRINT-1),
     1      RPSM(IPRINT-2)
            IF(RABC(IS).GE.RASY)WRITE(6,217)RASY,RPSM(IPRINT-1)
            WRITE(6,218)IND(K,1),IND(K,2),D,E,ABS(D-E)/D,LCONV
            IF((.NOT.LCONV).AND.(RASY.GE.RMAX))GO TO 211
            IF(.NOT.LCONV)GO TO 220
  210 CONTINUE
      END IF

  217 FORMAT(10HInit state,1X,11HFinal state,2X,2(7Hat R = ,F7.2,3X),
     115HRel. Abs. Diff.,6H LCONV)
  218 FORMAT(3X,I5,6X,I5,4X,1PE14.6,3X,1PE14.6,2X,1PE14.6,7X,L1)

      GOTO 300
  211 LCONV=.TRUE.

      WRITE(6,213)RASY,RMAX
      IF(RASY.GE.RMAX)GOTO 300
  213 FORMAT(/////1X,26HAsymptotic R value RASY = ,E12.6,2X,
     115His .GE. RMAX = ,E12.6,/1X,
     251HCalculations are stopped here by subroutine GNSCAT.//)

C***If convergence has not yet been reached do the following.

  220 IF(.NOT.((IOPT2.EQ.1).OR.LSTOP1))GO TO 275
      LU=LGS(5).OR.LSTOP1
      IF(LEARLY)GO TO 274
      CALL TITLES(IS,2,EFACT,ID,NSECT,LGS,RABC)
      LEARLY=.TRUE.
  274 CONTINUE

C***Current storage in MAT:
C***1st ICT columns: RE(S).
C***2nd ICT columns: IMAG(S).
C***MAT2: reactance matrix.

      CALL PRNTSU(MAT,MAT(1,ICT+1),U,ID,LU,ICT)
      IF(.NOT.LSTOP2)GO TO 275
      IF(LGS(8))GO TO 500
      RETURN

  275 IF((.NOT.LPSMH).OR.(RASY.LT.RMAX))RETURN

      IF(INE.NE.1)RETURN

      DO 285 J=1,ICT
       DO 285 I=1,ICT
         SPRRE(I,J)=MAT(I,J)
  285 SPRIM(I,J)=MAT(I,J+ICT)

  300 WRITE(6,900)RASY

      WRITE(15,900)RASY
  900 FORMAT(1X,33HAsymptotic analysis performed at ,1PE15.7)

C***If convergence has been reached do the following.

      WRITE(6,98701)(I,MAT(I,I),MAT(I,I+ICT),I=1,ICT)
      WRITE(15,98701)(I,MAT(I,I),MAT(I,I+ICT),I=1,ICT)
      ITEMPM=IRWSPT
      ITEMP=IRWSPT
      IF(IRWSPT.GT.0)THEN
      WRITE(6,98702)IRWSPT
      WRITE(15,98702)IRWSPT
      ELSE
      ITEMP=ABS(IRWSPT)
      IF(ITEMP.EQ.0)ITEMP=1
      ITEMPM=1
      WRITE(6,215)ITEMP
      WRITE(15,215)ITEMP
  215 FORMAT(1X,9HRows 1 to,I5,35H of scattering matrix, real portion,
     123H followed by imaginary.)
      ENDIF
98701 FORMAT(1X,42HDiagonal elements of the scattering matrix,/
     1(1X,I3,2(1PE15.7),I4,2(1PE15.7)))
98702 FORMAT(1X,4HRow ,I4,42H of scattering matrix, real elements over ,
     19Himaginary)

C***Current storage in MAT:
C***1st ICT columns: RE(S).
C***2nd ICT columns: IMAG(S).
C***MAT2: reactance matrix.

      DO 98703 I=1,ICT,4
         IEND=MIN(ICT,I+3)
         WRITE(6,98704)(J,J=I,IEND)
         WRITE(15,98704)(J,J=I,IEND)
        DO 98703 K=ITEMPM,ITEMP
           WRITE(6,98705)(MAT(J,K),J=I,IEND)
           WRITE(6,98706)(MAT(J,K+ICT),J=I,IEND)
           WRITE(15,98705)(MAT(J,K),J=I,IEND)
           WRITE(15,98706)(MAT(J,K+ICT),J=I,IEND)
98704 FORMAT(1X,6HCol ->,4(5X,I5,6X))
98705 FORMAT(1X,5HReal ,2X,4(1PE15.8,1X))
98706 FORMAT(1X,5HImag.,2X,4(1PE15.8,1X),/)
98703 CONTINUE

C***Calculate and print out state-to-state cross sections if desired.
C***NVIB is set arithmetically equal to NVIBX to prevent compiler
C***warnings on certain machines.

      NVIB=NVIBX
      IF (LGS(3).AND.NVIB.GE.2) THEN

      DO 216 K=ITEMPM,ITEMP
       DO 98600 I=1,ICT
          ISJ2(I,1)=4
          ISJ2(I,2)=7
          U(I,1)=MAT(I,K)**2+MAT(I,K+ICT)**2
98600 CONTINUE

       INAN=MIN0(3,NANX)
       IF(INAN.EQ.3)THEN
      WRITE(6,98736)ISI(K,1),ISI(K,2),
     1     (JIN(K,MM),MM=1,INAN),L(K)
      ELSE IF(INAN.EQ.1)THEN
      WRITE(6,98737)ISI(K,1),ISI(K,2),JIN(K,1),L(K)
      ELSE
      WRITE(6,98738)NANX
      END IF
98736 FORMAT(1X,17HInitial state V1=,I2,4H V2=,I2,4H J1=,I3,
     1       4H J2=,I3,5H J12=,I4,3H L=,I4)
98737 FORMAT(1X,17HInitial state V1=,I2,4H V2=,I2,4H J1=,I3,
     1       3H L=,I4)
98738 FORMAT(/1X,47HThe value chosen for NANX is incompatible with ,
     1      28Hthe option LGS(3).  NANX is ,I3,20H.  Try NANX = 1 or 3,
     2       9H instead.)


      CALL SUMS(U,AFMT,AHMT,U(1,2),ICT,JIN,ID,ISI,ISJ2)
  216 CONTINUE
      END IF

      IF(LTASY)WRITE(6,615)
  615 FORMAT(/1X,44HQuantities transformed into asymptotic basis,/)

      IF(.NOT.LCONV)GOTO 620

      DO 630 I=1,15
  630    LGS(I)=LAGS(I)

  620 IF(.NOT.LGS(2))GOTO 500
      IF(.NOT.LGS(2))GOTO 500
      GO TO (310,325,350),IOPT2
  310 IF(LEARLY)GO TO 314
      CALL TITLES(IS,2,EFACT,ID,NSECT,LGS,RABC)
      LEARLY=.TRUE.
  314 CONTINUE

C***Current storage in MAT:
C***1st ICT columns: RE(S).
C***2nd ICT columns: IMAG(S).
C***MAT2: reactance matrix.

      CALL PRNTSU(MAT,MAT(1,ICT+1),U,ID,LGS(3),ICT)
      GO TO 500
  325 ISM1=IS-1
      IF(.NOT.LPSINF)GO TO 883
      WRITE(6,330)
  330 FORMAT(1X,50H**************************************************)
      IF(LGS(1))WRITE(6,335)ISM1,RABC(ISM1)
      IF(.NOT.LGS(1))WRITE(6,340)ISM1
  335 FORMAT(1X,6HSector,2X,I4,3X,1HR,2X,E12.6,3X,
     119HEFACT not available)
  340 FORMAT(1X,6HSector,2X,I4)
  883 CONTINUE
      IF(INE.EQ.1)THEN
      WRITE(6,546)
  546 FORMAT(/1X,'From last asymptotic analysis:')
      CALL PRNTSU(SPRRE,SPRIM,U,ID,LGS(3),ICT)
      END IF
      CALL TITLES(IS,2,EFACT,ID,NSECT,LGS,RABC)
      LEARLY=.TRUE.
      CALL PRNTSU(MAT,MAT(1,ICT+1),U,ID,LGS(3),ICT)
      GO TO 500
  350 IF (LEARLY) GO TO 355
      CALL TITLES(IS,2,EFACT,ID,NSECT,LGS,RABC)
      LEARLY=.TRUE.
  355 CONTINUE
      CALL PRNTSU(MAT,MAT(1,ICT+1),U,ID,LGS(3),ICT)

C***Calculate extras.

  500 CALL SECOND(TIME1)

C***Print reactance matrix if desired.

C***Current storage in MAT:
C***1st ICT columns: RE(S).
C***2nd ICT columns: IMAG(S).
C***MAT2: reactance matrix.


      IF(.NOT.LGS(7))GO TO 800
                                                                        
      WRITE(6,750)
  750 FORMAT(1X,16HReactance matrix)
      CALL PRNTM2(MAT2,ICT,ICT,ID)
                                                                        
  800 CONTINUE

C***If no symmetrization of the reactance is required, then
C***PMAT can be equivalenced to RSCAT and then
C***EXSCAT will overwrite RSCAT, but all results will be the same.

      CALL EXSCAT(ID,ICT,IS,EFACT,LEARLY,PI,JIN,AKMT,MAT,MAT(1,ICT+1),U,
     1            ETA,LGS,JTOT,ETOT,ITPRNT,ITCOL,RABC,NSECT,
     2            MAT2,PMAT,PCDMT)
      CALL SECOND(TIME2)
      TIMC(8)=TIMC(8)+TIME2-TIME1
      IF(LSYM)RETURN

C***Calculate resymmetrized quantities or return.

      IF(.NOT.LGS(9))RETURN

C***Symmetrized reactance matrix.

      IF(ICT.GT.1)GO TO 805
      WRITE(6,993)
  993 FORMAT(/1X,42HFor the single open channel problem there ,
     148His no reason to symmetrize the reactance matrix./)
      RETURN

C***Store unsymmetrized reactance matrix.

C***Current storage in MAT:
C***1st ICT columns: RE(S).
C***2nd ICT columns: IMAG(S).
C***MAT2: reactance matrix.

  805 DO 807 I=1,ICT
       DO 807 J=1,ICT
         PMAT(J,I)=MAT2(J,I)
  807 CONTINUE

      LSYM=.TRUE.
      L1=IOPT3.EQ.1
      L2=IOPT3.EQ.2
      L3=IOPT3.EQ.3
      L4=IOPT3.EQ.4

C***Lower triangle symmetrized reactance matrix.

      IF(.NOT.(L1.OR.L4))GO TO 820
      MAT2(1,1)=PMAT(1,1)

      DO 813 I=2,ICT
         IM1=I-1
         MAT2(I,I)=PMAT(I,I)
        DO 813 J=1,IM1
           MAT2(I,J)=PMAT(I,J)
  813   MAT2(J,I)=MAT2(I,J)
         IF(.NOT.LGS(10)) GO TO 818
         WRITE(6,815)
  815    FORMAT(1X,43HLower triangle symmetrized reactance matrix)
         CALL PRNTM2(MAT2,ICT,ICT,ID)
  818 IF(LGS(13))WRITE(7,8000)((MAT2(I,J),I=1,ICT),J=1,ICT)

 8000 FORMAT(5F13.6)
      LSYM2=.TRUE.
      GO TO 121

C***Upper triangle symmetrized reactance matrix.

  820 IF(.NOT.(L2.OR.L4))GO TO 830

C***Current storage in MAT:
C***1st ICT columns: RE(S).
C***2nd ICT columns: IMAG(S).
C***MAT2: reactance matrix.

      MAT2(1,1)=PMAT(1,1)

      DO 823 I=2,ICT
         IM1=I-1
         MAT2(I,I)=PMAT(I,I)
        DO 823 J=1,IM1
           MAT2(J,I)=PMAT(J,I)
           MAT2(I,J)=MAT2(J,I)
  823   CONTINUE
         IF(.NOT.LGS(10))GO TO 828
         WRITE(6,825)
  825    FORMAT(1X,43HUpper triangle symmetrized reactance matrix)
         CALL PRNTM2(MAT2,ICT,ICT,ID)
  828 IF(L2)WRITE(7,8000)((MAT2(I,J),I=1,ICT),J=1,ICT)

      LSYM3=.TRUE.

      GO TO 121

C***Arithmetic mean symmetrized reactance matrix.

  830 IF(.NOT.(L3.OR.L4))RETURN

C***Current storage in MAT:
C***1st ICT columns: RE(S).
C***2nd ICT columns: IMAG(S).
C***MAT2: reactance matrix.

      MAT2(1,1)=PMAT(1,1)
      DO 833 I=2,ICT
         IM1=I-1
         MAT2(I,I)=PMAT(I,I)
        DO 833 J=1,IM1
           MAT2(I,J)=(PMAT(I,J)+PMAT(J,I))*0.5
  833   MAT2(J,I)=MAT2(I,J)
         IF(.NOT.LGS(10))GO TO 838
         WRITE(6,835)
  835    FORMAT(1X,44HArithmetic mean symmetrized reactance matrix)
         CALL PRNTM2(MAT2,ICT,ICT,ID)
  838 IF(L3.OR.L4)WRITE(7,8000)((MAT2(I,J),I=1,ICT),J=1,ICT)

      LSYM4=.TRUE.

      GO TO 121

C***Print scattering matrix and calculate extras.

C***Current storage in MAT:
C***1st ICT columns: RE(S).
C***2nd ICT columns: IMAG(S).
C***MAT2: reactance matrix.

 1000 IF(LGS(11)) CALL PRNTSU(MAT,MAT(1,ICT+1),U,ID,.TRUE.,ICT)
      CALL SECOND(TIME1)

      IF(LGS(12))CALL EXSCAT(ID,ICT,IS,EFACT,LEARLY,PI,JIN,AKMT,MAT,
     1                       MAT(1,ICT+1),U,ETA,LGS,JTOT,ETOT,ITPRNT,
     2                       ITCOL,RABC,NSECT,MAT2,MAT2,PCDMT)

      CALL SECOND(TIME2)
      TIMC(8)=TIMC(8)+TIME2-TIME1
      IF(LSYM4)RETURN
      IF(LSYM3)GO TO 830
      IF(LSYM2)GO TO 820
      RETURN
      END

      SUBROUTINE MATCH(ISI,EI,JIN,CENT,L,EVALI,
     1TMPEV1,TMPEV2,ID,R,NDIM,TMU,E,LP,JTOT,NOPEN,BPOT,UPCDMT,PCDMT,
     2TEMP4)

C***  This subroutine is for use with RMPROP: Version 2.1.2.
C***  MATCH is called by SUBROUTINE GNSCAT.
C***  This subroutine calculates the local wave vector squared and the
C***number of open channels there.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      INCLUDE 'parameter.inc'
      LOGICAL LP
      DIMENSION ISI(IDX,NVIBX),EI(IDX),JIN(IDX,NANX),CENT(IDX),
     1L(IDX),EVALI(IDX),TMPEV1(IDX),TMPEV2(IDX),
     2UPCDMT(IDX,IDX),BPOT(IDX,IDX,NVIB1X),PCDMT(NBARX),TEMP4(IDX,8)
      CALL POT(R,NDIM,ID,BPOT,UPCDMT)
      RI2=1D0/(R*R)

      DO 2097 I=1,ID
         UPCDMT(I,I)=UPCDMT(I,I)+CENT(I)*RI2+EI(I)-E
 2097 CONTINUE
  
      CALL RS(IDX,NDIM,UPCDMT,EVALI,1,UPCDMT,TMPEV1,TMPEV2,IERR)

         CALL EV2RSP(0,NDIM,0,NBARX,IDX,PCDMT,UPCDMT,TEMP4,TMPEV2,
     1EVALI,TMP,0,IERR)      

      IF(IERR.NE.0)WRITE(6,5)IERR

      DO 30 I=1,NDIM
   30    IF(EVALI(I).LT.0D0)NOPEN=I

    5 FORMAT(1X,15HIn MATCH IERR =,I7)

      RETURN
      END

      SUBROUTINE PRNTM2(A,NI,NJ,ID)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE

C***This subroutine is for use with RMPROP: Version 2.1.2.
C***This subroutine prints the elements of the NI rows and NJ columns
C***of array A.  A is dimensioned (IDX,IDX) in the calling program
C***dimension statement.

      INCLUDE 'parameter.inc'
      COMMON/PRNTCM/IUNIT,IFORRR
      DIMENSION A(IDX,IDX)
      IUNIT=IUNIT+1
      WRITE(6,60)IUNIT
   60 FORMAT(1X,15HWriting to UNIT,I5)
      JCOL=9
      JMIN=1
   20 JMAX=MIN0(JCOL,NI)
      IF(IFORRR.EQ.0)WRITE(6,30)(IM,IM=JMIN,JMAX)
   30 FORMAT(2X,3HM-N,9(5X,I4,5X))

      DO 50 J=1,NJ
        IF(IFORRR.NE.0)WRITE(IUNIT)J,(A(J,I),I=JMIN,JMAX)
        IF(IFORRR.EQ.0)WRITE(6,70)J,(A(J,I),I=JMIN,JMAX)
   70   FORMAT(1X,I4,1X,1P,9E14.6)
   50 CONTINUE

      IF(IFORRR.NE.0)WRITE(IUNIT)((A(J,I),J=1,I),I=1,NJ)
      IF(IFORRR.NE.0)RETURN
      IF(JMAX.EQ.NI)RETURN
      JMIN=JMAX+1
      JCOL=JCOL+9
      GO TO 20
      END

      SUBROUTINE PRNTSU(SRE,SIM,U,ID,LU,ICT)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C***  This subroutine is for use with RMPROP: Version 2.1.2.
C***  This subroutine is used to print the complex valued scattering
C***matrix from its component real and imaginary parts, SRE and SIM,
C***respectively and if desired to calculate and print the sums of the
C***squares of the absolute values of the elements of each row and
C***column as a check on unitarity.
C***  ID is the first dimension of the arrays SRE, SIM and U in calling
C***program dimension statement.
C***  If the logical variable LU is true the unitarity checks are made
C***and printed.
C***  ICT is the number of open channels.

      INCLUDE 'parameter.inc'
      COMMON/PRNTCM/IUNIT,IFORRR
      DIMENSION SRE(IDX,IDX),SIM(IDX,IDX),U(IDX,2)
      LOGICAL LU
      IUNIT=IUNIT+1
      WRITE(6,60)IUNIT
   60 FORMAT(1X,15HWriting to UNIT,I5)

C***Print scattering matrix.

      WRITE(6,10)
      WRITE(6,12)

      DO 15 J=1,ICT
       DO 15 I=J,ICT
          IF(IFORRR.NE.0)WRITE(IUNIT)I,J,SRE(I,J),SIM(I,J)
          IF(IFORRR.EQ.0)WRITE(6,13)I,J,SRE(I,J),SIM(I,J)
          IF(IFORRR.EQ.0)WRITE(77,13)I,J,SRE(I,J),SIM(I,J)
   15 CONTINUE

   10 FORMAT(1X,17HScattering matrix)
   12 FORMAT(1X,9HChannel I,5X,9HChannel J,5X,
     112HReal(S(I,J)),5X,12HImag(S(I,J)))
   13 FORMAT(1X,I5,9X,I5,8X,1PE13.6,4X,E13.6)
      IF(.NOT.LU)RETURN

C***Calculate unitarity checks.

      DO 25 J=1,ICT
         U(J,1)=0
        DO 25 I=1,ICT
   25 U(J,1)=U(J,1)+(SRE(J,I)**2+SIM(J,I)**2)

      DO 30 J=1,ICT
         U(J,2)=0
        DO 30 I=1,ICT
   30 U(J,2)=U(J,2)+(SRE(J,I)**2+SIM(J,I)**2)

      WRITE(6,35)
      WRITE(6,40)(U(I,1),I=1,ICT)
      WRITE(6,45)
      WRITE(6,40)(U(I,2),I=1,ICT)

   35 FORMAT(1X,16HUnitarity checks/
     11X,30HFor each row starting with I=1)
   45 FORMAT(1X,33HFor each column starting with J=1)
   40 FORMAT(10(1PE13.6))

      RETURN
      END

      SUBROUTINE PRSCAT(ID,LGS,IOPT2,EPSMAG,EPSPH,LGS1,IOPT3,LBGS,IND,
     1NIND)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      INTEGER FU7,FU10,FU11,FU16
      SAVE
      PARAMETER(FU7=7,FU10=10,FU11=11,FU16=16)

C***  This subroutine is for use with RMPROP: Version 2.1.2.
C***  LBGS contains the same information as LGS, except it pertains to
C***the scattering analsys performed at distances defined by RPSM in
C***RMPROP.  See GNSCAT for more information.

      DIMENSION LGS(15),LBGS(15),IND(10,2)
      LOGICAL LGS,LGS1,LBGS

      READ(5,6000) (LGS(I),I=1,15)
      READ(5,6000) (LBGS(I),I=1,15)
      READ(5,6001) IOPT2,IOPT3
      READ(5,6003) EPSMAG,EPSPH
      EPSMAG=ABS(EPSMAG)
      EPSPH=ABS(EPSPH)
      IF (EPSMAG.EQ.0.0.AND.EPSPH.EQ.0.0)GO TO 5
      READ(5,6001) NIND
      READ(5,6002) (IND(I,1),I=1,MIN0(NIND,10))
      READ(5,6002) (IND(I,2),I=1,MIN0(NIND,10))

 6000 FORMAT(20L1)
 6001 FORMAT(2I4)
 6002 FORMAT(10I4)
 6003 FORMAT(2G16.5)

C***Indicate convergence criterion.
C***The magnitudes of EPSMAG and EPSPH indicate whether:
C***  Do not test the S-matrix elements for convergence at all (both=0).
C***  Test just the magnitudes of the S-matrix elements (EPSMAG NE 0).
C***  Test the magnitudes and phases of S-matrix elements (BOTH NE 0).

    5 IF(EPSMAG.EQ.0.AND.EPSPH.EQ.0)WRITE(6,10)
      IF(EPSMAG.NE.0.AND.EPSPH.EQ.0)WRITE(6,11)
      IF(EPSMAG.NE.0.0.AND.EPSPH.NE.0.0)WRITE(6,12)
      IF(EPSMAG.EQ.0.0.AND.EPSPH.NE.0.0)WRITE(6,13)
      IF(EPSMAG.EQ.0.0.AND.EPSPH.NE.0.0)EPSMAG=1.0D-02
   10 FORMAT(/1X,50HEPSMAG=0 and EPSPH=0.  This means that neither the,
     119H magnitudes nor the,/1X,28Hphases of scattering matrix ,
     21X,44Helements will be tested for convergence with,/1X,8Hrespect ,
     319Hto increasing RMAX./)
   11 FORMAT(/1X,51HEPSMAG NE 0 and EPSPH=0.  This means that only the ,
     117Hmagnitudes of the,/1X,35Hscattering matrix elements will be ,
     235Htested for convergence with respect/1X,19Hto increasing RMAX./)
   12 FORMAT(/1X,48HEPSMAG NE 0 and EPSPH NE 0.  Therefore both the ,
     114Hmagnitudes and/1X,41Hphases of scattering matrix elements will,
     226H be tested for convergence/1X,26Hwith respect to increasing,
     36H RMAX./)
   13 FORMAT(/1X,44HEPSMAG=0 and EPSPH NE 0 is an invalid option,
     1/1X,54Hthe program will set EPSMAG to 1.0D-02 and leave EPSPH)
      LGS1=LGS(4).OR.LGS(5).OR.LGS(6).OR.LGS(7)
      IF(LGS(10).OR.LGS(13))OPEN(UNIT=FU7,FILE='fort.7',STATUS='NEW',
     1FORM='FORMATTED')
      IF(LGS(14))OPEN(UNIT=FU10,FILE='fort.10',STATUS='NEW',
     1FORM='FORMATTED')
      IF(LGS(15))OPEN(UNIT=FU11,FILE='fort.11',STATUS='NEW',
     1FORM='FORMATTED')
      IF(LGS(15))OPEN(UNIT=FU16,FILE='fort.16',STATUS='NEW',
     1FORM='FORMATTED')

C***Check consistency of input.
C***(If problems arise see subroutine GNSCAT for help).

      IF(LGS(2).AND.(IOPT2.LE.3).AND.(IOPT2.GE.1))GO TO 20

      WRITE(6,15)
   15 FORMAT(/////1X,45HBy setting LGS(2) true you requested that the,
     162H scattering matrix be printed.  But, by neglecting to properly,
     28H specify/1X,41HIOPT2, you did not specify how to print.  ,
     357HThe program will only print the scattering matrix in the ,
     423Hlast sector.  (IOPT2=3))

      IOPT2=3

   20 IF(LGS(9).AND.(IOPT3.GE.1).AND.(IOPT3.LE.4))RETURN
      IF(.NOT.LGS(9))GO TO 30
      WRITE(6,16)
   16 FORMAT(/////1X,41HBy setting LGS(9) true you requested that,
     137H the reactance matrix be symmetrized./1X,9H  But, by,
     262H neglecting to correctly specify IOPT3 you did not choose how.,
     3/1X,57H The program will assume arithmetic mean symmetrization.),
     411H  (IOPT3=3))

      IOPT3=3
      RETURN

   30 IF(LGS(10).OR.LGS(11).OR.LGS(12).OR.LGS(13)) GO TO 35

      RETURN

   35 WRITE(6,40)
   40 FORMAT(/////1X,46HYou did not specify that the reactance matrix ,
     161Hshould be symmetrized although you selected options requiring/
     11X,55Hthe symmetrized reactance matrix.  The program selects ,/1X,
     360Harithmetic mean symmetrization.  (LGS(9)=.TRUE. and IOPT3=3))

      LGS(9)=.TRUE.
      IOPT3=3

      IF(EPSMAG.NE.0.0.AND.EPSPH.NE.0.0) GO TO 45
      RETURN

   45 IF(NIND.GT.10) GO TO 55
      RETURN

   55 WRITE(6,60)
   60 FORMAT(//33HYou tried to read in indices for ,I4,12Helements of ,
     121Hthe scattering matrix,/34Hto be compared to previous values.,
     238H  This to too large.  The program will,/16Honly compare the,
     333H first 10 elements you selected./)

      NIND=10

      RETURN
      END

      SUBROUTINE RBES(N,Z,ZJN,ZJNP,ZYN,ZYNP)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE

C***  This subroutine is for use with RMPROP: Version 2.1.2.
C***  This subroutine calculates the regular Ricatti-Bessel function ZJN
C***and its derivative ZJNP and the irregular Ricatti-Bessel function
C***ZYN and its derivative ZYNP of order N for argument Z.  This is
C***a copy of Lights routine attributed to R. GORDON.

      DATA ZERO,HALF,ONE,TWO,THREE/0.0,0.5,1.0,2.0,3.0/

C***Evaluate trig functions.

      SZ=DSIN(Z)
      CZ=DCOS(Z)
      ZINV=ONE/Z
      AJ=SZ
      BJ=SZ*ZINV-CZ
      AY=-CZ
      BY=-SZ-CZ*ZINV
      IF(N-1)1,2,3

C***Functions of zero order.

    1 ZJN=AJ
      ZJNP=CZ
      ZYN=AY
      ZYNP=SZ
      RETURN

C***Functions of order one.

    2 ZJN=BJ
      ZJNP=AJ-ZINV*BJ
      ZYN=BY
      ZYNP=AY-ZINV*BY
      RETURN

C***Functions of order greater than one.

    3 XN=N
      DELF=ZINV+ZINV
      FACTOR=DELF+ZINV

C***Test to see if recurrence can be used.

      IF(Z.GT.XN)GO TO 100

C***In non classical region use recursion relation for irregular
C***solution and ascending power series for regular solution.
C***The coefficient, C, in front of power series is calculated during
C***forward recurrence.

      ZSQ=Z*Z
      TOP=XN+XN
      XJ=THREE
      C=ZSQ/THREE

C***Irregular solution.

   25 ZYN=BY*FACTOR-AY
      AY=BY
      BY=ZYN
      FACTOR=FACTOR+DELF
      XJ=XJ+TWO
      C=C*(Z/XJ)
      IF(XJ.LT.TOP)GO TO 25
      ZYNP=AY-ZINV*BY*XN

C***Regular solution.

      FACTOR=-HALF*ZSQ
      U=ONE
      TERM=ONE
      DU=ONE
      DTERM=ONE
      D2NP3=TOP+THREE
      DEN=D2NP3
      DFACT=ZERO
   35 DFACT=DFACT+ONE
      TERM=TERM*(FACTOR/(DFACT*DEN))
      U=U+TERM
      DEN=DEN+TWO
      DTERM=DTERM*(FACTOR/(DFACT*DEN))
      DU=DU+DTERM

C***Test convergence to single precision accuracy.

      IF(ABS(TERM).GT.1.0D-9)GO TO 35
      ZJN=U*C
      ZJNP=(XN+ONE)*ZJN*ZINV-(Z*DU/D2NP3)*C
      RETURN

C***For classical case use forward recursion for regular
C***and irregular solutions.

  100 CONST=ZINV*XN
      TOP=CONST+CONST
  200 AJ=FACTOR*BJ-AJ
      AY=FACTOR*BY-AY
      FACTOR=FACTOR+DELF
      IF(FACTOR.GT.TOP)GO TO 250
      BJ=FACTOR*AJ-BJ
      BY=FACTOR*AY-BY
      FACTOR=FACTOR+DELF
      IF(FACTOR.LT.TOP)GO TO 200
      ZJN=BJ
      ZJNP=AJ-CONST*BJ
      ZYN=BY
      ZYNP=AY-CONST*BY
      RETURN
  250 ZJN=AJ
      ZJNP=BJ-CONST*AJ
      ZYN=AY
      ZYNP=BY-CONST*AY
      END

      SUBROUTINE RPROP(PD,IS,ID,LPRA,LPRB,LR4MT,NPROP,KKS,NSECT,EVALI,
     1P1,P3INV,TAUI,TINVI,R4MT,TMPEV2,HPOS,INR1,LPSYM,TMP1,TMP2,
     $TMP3,EPS,NEWRED,EPSRED,RABC,LASY,ICT,R1MT,R1MTM1,R2MT,R2MTM1,
     $R3MT,R3MTM1,R4MTM1,TEMPR1,IPIV)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C***  This subroutine is for use with RMPROP: Version 2.1.2.
C***General information:
C***  PD is the number of propagated channels.
C***Note PD in this routine is equivalent to NRED in the calling program
C***  IS is the sector for which this routine calculates PMT"S, SRMT"S,
C***RMT"S.
C***  ID is the first dimension of TAUI, TMPSRI, SRMT"S, RMT"S in the
C***dimension statement.
C***  If LPRA is true SRMT"S are printed.
C***  If LPRB is true RMT"S are printed.
C***  If LR4MT is true (homogeneous option), only R4MT is calculated.
C***  LEREF is true at the reference energy.
C***  If (NPROP.EQ.1) the calculation of sector R matrices is greatly
C***simplified by symmetry arguments.
C***  PART1.  This calculates the diagonal elements of the diagonal
C***"(PD,PD)" matrices P1 and P3INV and stores them as the singly
C***dimensioned arrays P1(PD) and P3INV(PD).  For LAMBDA calculation
C***need eigenvalues stored in EVALI.  H is defined as R(LEFT)-R(RIGHT).
C***  PART2.  This uses TAUI and TINVI and P1 and P3INV to calculate the
C***PD,PD SRMT"S.  This calculation is not done in the first sector.
C***  PART3. The RMT"S are calculated using the SRMT"S and the previous
C***sector RMT"S from common LSTCM and then are stored in RCM.
C***There is a special definition for sector one.
C***
C*** NPROP = 2 means used modified equations with reduced operation
C*** count.  With these equations, the small R matrices are not
C*** explicitly formed and TINVI is not required.
C*** TMP2 is not required if NPROP = 2.
C***********************************************************************

      INCLUDE 'parameter.inc'
      COMMON/TIMCOM/TIMC(50)
      DIMENSION EVALI(IDX),P1(IDX),P3INV(IDX),TAUI(IDX,IDX),
     1TINVI(IDX,IDX),R4MT(IDX,IDX),TMPEV2(2*IDX),HPOS(NSECTX),LPSYM(8),
     2TMP1(IDX,IDX*2),TMP2(IDX,IDX),TMP3(IDX)
      DIMENSION R1MT(IDX,IDX),R2MT(IDX,IDX),R3MT(IDX,IDX),
     1TEMPR1(IDX,IDX)
      DIMENSION R1MTM1(IDX,IDX),R2MTM1(IDX,IDX),R3MTM1(IDX,IDX),
     1R4MTM1(IDX,IDX)
      INTEGER PD,NPROP
      INTEGER IPIV(IDX)
      DOUBLE PRECISION LAMBDA
      LOGICAL LPRA,LPRB,LR4MT,LASY,LPSYM
      H=-HPOS(IS)

C***Part 1.
C***Decide action for negative ,zero, positive eigenvalues.

      DO 10 I=1,PD
         IF(EVALI(I))20,30,40

C***Negative eigenvalues correspond to classically allowed channels.

   20 LAMBDA=-DSQRT(-EVALI(I))
      HL=H*LAMBDA
      P1(I)=DCOS(HL)
      P3INV(I)=-1.0D0/(LAMBDA*DSIN(HL))
      GO TO 10

C***Zero eigenvalues should not occur (no code for propagating).

   30 WRITE(6,32) IS,I
   32 FORMAT(1X,9HIn sector,I5,10Heigenvalue,I3,7His zero)
      STOP 13

C***Positive eigenvalues correspond to classically forbidden channels.

   40 LAMBDA=DSQRT(EVALI(I))
      HL=H*LAMBDA
      P1(I)=COSH(HL)
      P3INV(I)=1.0/(LAMBDA*SINH(HL))
   10 CONTINUE

C***Part 2.
C***For the first sector the Part 2 calculation is not necessary.

      IF((IS-INR1).EQ.1) GO TO 70

C***Fast equations:

      IF(NPROP.EQ.2)THEN
       CALL SECOND(T1)
       CALL DGEMM('N','N',PD,PD,PD,1.0D0,R4MT,IDX,TAUI,IDX,0.0D0,
     1TMP1(1,1+PD),IDX)
       CALL SECOND(T2)

       TIMC(18)=TIMC(18)+T2-T1
       DO 1051 I=1,PD
        TMP3(I)=P3INV(I)*P1(I)
 1051  CONTINUE

       DO 1052 I=1,PD
           CALL DAXPY(PD,TMP3(I),TAUI(1,I),1,TMP1(1,I+PD),1)
           CALL DCOPY(PD,TMP1(1,I+PD),1,TMP1(1,I),1)
           CALL DSCAL(PD,0.0D0,TMP1(1,I+PD),1)
 1052  CONTINUE

       DO 1054 I=1,PD
          CALL DAXPY(PD,P3INV(I),TAUI(1,I),1,TMP1(1,I+PD),1)
 1054  CONTINUE

C***TMP1(J,I+PD) now contains SR2.

       IF(LPRA)THEN
        WRITE(6,64)
        CALL PRNTM2(TMP1(1,1+PD),PD,PD,ID)
       END IF

C***Drop closed channels?
       IF(LASY.AND.PD.GT.ICT)THEN
        CALL DROP(ICT,PD,NEWRED,EPSRED,IDUM,DUM,IS,1,ID,TMP1(1,1+PD),
     $            DUM,RABC)
       END IF
       CALL SECOND(T1)
       IERR=0
       CALL MINV(TMP1,PD,IDX,TMPEV2,DET,EPS,PD,0)                       6M7R94
       
       CALL DGETRF(PD,PD,TMP1,IDX,IPIV,IERR)
       CALL SECOND(T2)
       TIMC(17)=TIMC(17)+T2-T1
       IF(IERR.NE.0)THEN
       WRITE(6,1056)    
 1056  FORMAT(/1X,'In RPROP, inversion after DROP says matrix is singula
     1r.')
       STOP 14
       END IF
       CALL DGETRS('N',PD,PD,TMP1,IDX,IPIV,TMP1(1,PD+1),IDX,IERR)

       DO 1057 I=1,PD
        DO 1058 J=1,PD
         R4MT(J,I)=-TMP1(J,I+PD)*P3INV(J)
 1058   CONTINUE
        R4MT(I,I)=R4MT(I,I)+TMP3(I)
 1057  CONTINUE

       IF(LPRB)THEN
        WRITE(6,98)
        CALL PRNTM2(R4MT,PD,PD,ID)
       END IF
       ELSE

C***The ELSE line immediately above is the end of the fast propagator.
C***Calculate SR1, SR2, SR3, SR4:  The DO-LOOP over 52 below gives the
C***sector SR2 and SR4 matrices according to equations (54) and (56)
C***of the chapter on RMPROP 2.0 in MOTECC-93: Modern Techniques in
C***Computational Chemistry, edited by Enrico Clementi.  Note that
C***P1(I) is the same as P4(I) by definition so to save space just use
C***P1(I).

       DO 9521 I=1,PD
          CALL DSCAL(PD,0.0D0,TMP1(1,PD+I),1)
 9521  CONTINUE
       DO 952 I=1,PD
          CALL DAXPY(PD,P3INV(I),TAUI(1,I),1,TMP1(1,I+PD),1) 
  952 TMP3(I)=P3INV(I)*P1(I)

C***TMP1(I,J+PD) now contains SR2.
C***TMP3 contains SR4.

      IF(LPRA)THEN
      WRITE(6,64)
   64 FORMAT(1X,3HSR2)
      CALL PRNTM2(TMP1(1,1+PD),PD,PD,ID)
      WRITE(6,66)
   66 FORMAT(1X,3HSR4)
      CALL PRNTM2(TMP3,1,PD,ID)
      END IF

C***Drop closed channels?

      IF(LASY.AND.PD.GT.ICT)THEN
       CALL DROP(ICT,PD,NEWRED,EPSRED,IDUM,DUM,IS,1,ID,TMP1(1,1+PD),
     $           DUM,RABC)
      END IF

C***Compute SR1.
         DO 1521 I=1,PD
            CALL DSCAL(PD,0.0D0,TMP2(1,I),1)
1521     CONTINUE
      DO 152 I=1,PD
         CALL DAXPY(PD,P1(I),TMP1(1,PD+I),1,TMP2(1,I),1)
  152 CONTINUE

      CALL SECOND(T1)

      IF(NPROP.EQ.1)THEN
       CALL DGEMM('N','T',PD,PD,PD,1.0D0,TMP2,IDX,TAUI,IDX,0.0D0,
     1TMP1,IDX)
      ELSE
       CALL DGEMM('N','N',PD,PD,PD,1.0D0,TMP2,IDX,TINVI,IDX,0.0D0,
     1TMP1,IDX)
      END IF
      CALL SECOND(T2)
      TIMC(18)=TIMC(18)+T2-T1

C***TMP1 now contains SR1.

      IF(LPRA)THEN
      WRITE(6,63)
   63 FORMAT(1X,3HSR1)
      CALL PRNTM2(TMP1,PD,PD,ID)
      END IF

      DO 53 I=1,PD
         CALL DAXPY(PD,1.0D0,R4MTM1(1,I),1,TMP1(1,I),1)
         CALL DCOPY(PD,TMP1(1,I),1,TEMPR1(1,I),1)
   53 CONTINUE
      DO 533 I=1,PD
       DO 533 J=1,PD
        TMP1(J,I+PD)=0.0D0
        IF(I.EQ.J)TMP1(J,I+PD)=1.0D0
 533  CONTINUE

      CALL SECOND(T1)

      IERR=0
      CALL MINV(TMP1,PD,IDX,TMPEV2,DET,EPS,PD,0)                        6M7R94
       IF(DET.EQ.0.D0)IERR=1                                            6M7R94
       CALL DGETRF(PD,PD,TMP1,IDX,IPIV,IERR)
      IF(IERR.EQ.0)GOTO 5341
       WRITE(6,1056)
       STOP 14
 5341 CONTINUE

       CALL DGETRS('N',PD,PD,TMP1,IDX,IPIV,TMP1(1,PD+1),IDX,IERR)

           DO 5344 I=1,PD
              CALL DSCAL(PD,0.0D0,TMP2(1,I),1)
 5344      CONTINUE
      DO 534 I=1,PD
         CALL DAXPY(PD,P3INV(I),TAUI(1,I),1,TMP2(1,I),1)
 534  CONTINUE

      CALL DGEMM('N','N',PD,PD,PD,1.0D0,TMP1(1,PD+1),IDX,TMP2,IDX,
     10.0D0,TMP1,IDX)


      DO 535 I=1,PD
         CALL DCOPY(PD,TMP1(1,I),1,TMP1(1,PD+I),1)
 535  CONTINUE

C***TMP1(I,PD+1) now contains matrix S(I-1,I)*SR2(I).

      CALL SECOND(T2)
      TIMC(17)=TIMC(17)+T2-T1

C***Compute SR3.

      IF(NPROP.EQ.1)THEN
       DO 59 I=1,PD
        DO 59 J=1,PD
         TMP2(J,I)=P3INV(J)*TAUI(I,J)
   59  CONTINUE
      ELSE
       DO 61 I=1,PD
        DO 61 J=1,PD
         TMP2(J,I)=P3INV(J)*TINVI(J,I)
   61  CONTINUE
      END IF

C***TMP2 now contains SR3.

      IF(LPRA)THEN
      WRITE(6,65)
   65 FORMAT(1X,3HSR3)
      CALL PRNTM2(TMP2,PD,PD,ID)
      END IF

      CALL SECOND(T1)
      CALL DGEMM('N','N',PD,PD,PD,1.0D0,TMP2,IDX,TMP1(1,PD+1),IDX,
     10.0D0,TMP1,IDX)

      CALL SECOND(T2)
      TIMC(18)=TIMC(18)+T2-T1
      DO 600 I=1,PD
       DO 601 J=1,PD
        R4MT(J,I)=-TMP1(J,I)
  601  CONTINUE
       R4MT(I,I)=TMP3(I)+R4MT(I,I)
  600 CONTINUE

C***Calculate R2MT(global R2(I)) from R2MTM1 (global R2(I-1)).
C***R2MT(I)=R2MTM1 * [inverse of (R4MT(I-1)+SR1(I))]*SR2(I).

      CALL DGEMM('N','N',PD,PD,PD,1.0D0,R2MTM1,IDX,TMP1(1,PD+1),IDX,
     10.0D0,R2MT,IDX)


C***R2MT now contains the actual R2MT.

C***Calculate R1MT(I) (global R1 matrix) from R1MTM1 (global R1(I-1)).
C***R1MT(I)=R1MTM1-R2MTM1*[inverse of (R4MT(I-1)+SR1(I))]*R3MTM1.
C***Calculate R3MT(I) (global R1 matrix) from R3MTM1 (global R1(I-1)).
C***R3MT(I)=SR3(I)*[inverse of (R4MT(I-1)+SR1(I))]*R3MTM1.
C***Note that we need to recalculate the inverse first.
C***We do this using the matrix TEMPR1.
                                                                        
      DO 929 I=1,PD
         CALL DCOPY(PD,TEMPR1(1,I),1,TMP1(1,I),1)
         CALL DCOPY(PD,R3MTM1(1,I),1,TMP1(1,I+PD),1)
 929  CONTINUE
       CALL MINV(TMP1,PD,IDX,TMPEV2,DET,EPS,PD,0)
       CALL DGETRF(PD,PD,TMP1,IDX,IPIV,IERR)

      IF(IERR.EQ.0)GO TO 9291
      WRITE(6,9292)IERR
 9292 FORMAT(/1X,'In RPROP, inversion says matrix is singular ',I5)
 9291 CONTINUE
       CALL DGETRS('N',PD,PD,TMP1,IDX,IPIV,TMP1(1,PD+1),IDX,IERR)

C***TMP1(1,PD+1) now contains precursor of R1MT and R3MT which are
C***S(I-1,I)*R1MT and S(I-1,I)*R3MT respectively.

      CALL DGEMM('N','N',PD,PD,PD,1.0D0,R2MTM1,IDX,TMP1(1,PD+1),IDX,
     10.0D0,TEMPR1,IDX)

         DO 9301 I=1,PD
            CALL DSCAL(PD,0.0D0,R1MT(1,I),1)
 9301    CONTINUE
      DO 930 I=1,PD
         CALL DAXPY(PD,1.0D0,R1MTM1(1,I),1,R1MT(1,I),1)
         CALL DAXPY(PD,-1.0D0,TEMPR1(1,I),1,R1MT(1,I),1)
 930  CONTINUE

      CALL DGEMM('N','N',PD,PD,PD,1.0D0,TMP2,IDX,TMP1(1,PD+1),IDX,
     10.0D0,R3MT,IDX)

      DO 928 I=1,PD
           CALL DCOPY(PD,R1MT(1,I),1,R1MTM1(1,I),1)
           CALL DCOPY(PD,R2MT(1,I),1,R2MTM1(1,I),1)
           CALL DCOPY(PD,R3MT(1,I),1,R3MTM1(1,I),1)
           CALL DCOPY(PD,R4MT(1,I),1,R4MTM1(1,I),1)
 928   CONTINUE

      IF(LPRB)THEN
          IF(.NOT.LR4MT)THEN
       WRITE(6,92)
   92 FORMAT(1X,4HR1MT)
      CALL PRNTM2(R1MT,PD,PD,ID)
       WRITE(6,94)
   94 FORMAT(1X,4HR2MT)
      CALL PRNTM2(R2MT,PD,PD,ID)
       WRITE(6,96)
   96 FORMAT(1X,4HR3MT)
      CALL PRNTM2(R3MT,PD,PD,ID)
          END IF
       WRITE(6,98)
   98 FORMAT(1X,4HR4MT)
      CALL PRNTM2(R4MT,PD,PD,ID)
      END IF
      END IF
      GO TO 80

C***PART3

   70 DO 73 I=1,PD
       DO 73 J=1,PD
          R1MT(J,I)=0.0D0
          R1MTM1(J,I)=0.0D0
          R2MT(J,I)=0.0D0
          R2MTM1(J,I)=0.0D0
          R3MT(J,I)=0.0D0
          R3MTM1(J,I)=0.0D0
          R4MT(J,I)=0.0D0
          R4MTM1(J,I)=0.0D0
   73 CONTINUE

      DO 733 I=1,PD
  733    R4MT(I,I)=P3INV(I)*P1(I)

      IF(LR4MT)THEN                                                     9M6R93
        IF(LPRB)THEN                                                    9M6R93
          WRITE(6,98)                                                   9M6R93
          CALL PRNTM2(R4MT,PD,PD,ID)                                    9M6R93
        ENDIF                                                           9M6R93
        RETURN                                                          9M6R93
      ENDIF                                                             9M6R93

      DO 75 I=1,PD
          R1MT(I,I)=P1(I)*P3INV(I)
          R1MTM1(I,I)=P1(I)*P3INV(I)
          RZ=P3INV(I)
          R2MT(I,I)=RZ
          R2MTM1(I,I)=RZ
          R3MT(I,I)=RZ
          R3MTM1(I,I)=RZ
          R4MTM1(I,I)=P3INV(I)*P1(I)
   75 CONTINUE


      RETURN
   80 CONTINUE

C***Periodically check symmetry of R4MT and print out sum of first row
C***and trace: this is not a necessary part of the computation but it
C***does make one feel more secure.

      IF(LPSYM(7))THEN
      CALL SECOND(TIMES1)
      IF(MOD(IS,5).NE.0)GOTO 5400
      SYMCK=0.
      SUMCK=0.

      DO 5401 I=1,PD
         SUMCK=SUMCK+R4MT(I,I)+R4MT(1,I)
        DO 5401 J=I,PD
           SYMTMP=MAX(ABS(R4MT(I,J)),ABS(R4MT(J,I)))
           SYMCK=ABS(R4MT(I,J)-R4MT(J,I))/SYMTMP
 5401 CONTINUE

      WRITE(6,5402)IS,SUMCK,SYMCK
 5402 FORMAT(1X,34HSUMCK and SYMCK in RPROP at sector,I5,1P,2E15.7)

      IF(SYMCK.GT.2.0D-4)STOP 133
      CALL SECOND(TIMES2)
      TIMC(15)=TIMC(15)+TIMES2-TIMES1
      END IF

 5400 CONTINUE

      RETURN
      END

      SUBROUTINE SUMS(P,IDX1,IDX2,S,ICH,JIN,ID,ISI,ISJ2)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C***  This subroutine is for use with RMPROP: Version 2.1.2.
C***  This subroutine takes 1 row (stored in P) of the transition
C***probability matrix, and sums the elements first by MJ'S and then by
C***jsums.  IDX1,IDX2,S are scratch arrays of length at least ICH, the
C***number of open channels.  JIN contains the internal rotational
C***quantum numbers for the two diatoms, and ID is JIN's first dimension
C***the array P is over written.

      INCLUDE 'parameter.inc'
      DIMENSION P(ICH),IDX1(ICH),IDX2(ICH),S(ICH),JIN(IDX,2)
      DIMENSION ISI(IDX,2),ISJ2(IDX,2)
      DATA ZERO/0.0D+0/

C***Sum over MJ'S.  The channels are assumed to be in order of
C***increasing eigenenergies.

      I1=1
      I2=1
    1 CONTINUE
      S(I1)=P(I2)
      IDX1(I1)=JIN(I2,1)
      IDX2(I1)=JIN(I2,2)
      ISJ2(I1,1)=ISI(I2,1)
      ISJ2(I1,2)=ISI(I2,2)
    2 I2=I2+1
      IF(I2.GT.ICH)GOTO 3
      IF(IDX1(I1).EQ.JIN(I2,1).AND.IDX2(I1).EQ.JIN(I2,2).AND.
     1ISJ2(I1,1).EQ.ISI(I2,1).AND.ISJ2(I1,2).EQ.ISI(I2,2))GO TO 4
      I1=I1+1
      GOTO 1
    4 S(I1)=S(I1)+P(I2)
      GOTO 2
    3 WRITE(6,5)
      DO 6 I=1,I1,7
      IE=MIN(I1,I+6)
       WRITE(6,7)(ISJ2(J,1),ISJ2(J,2),IDX1(J),IDX2(J),J=I,IE)
       WRITE(6,8)(S(J),J=I,IE)
    6 CONTINUE
    5 FORMAT(1X,29HProbabilities summed over MJS,
     134H Q.N. are in the order V1,V2,J1,J2)
    7 FORMAT(1X,5(3X,4I3))
    8 FORMAT(1X,5(1PE15.8))

C***Now sum over J1+J2.

      ISUMX=0
      DO 9 I=1,I1
         IDX1(I)=IDX1(I)+IDX2(I)+1
    9    ISUMX=MAX(ISUMX,IDX1(I))

      MAXV=0

      DO 20 I=1,I1
         MAXV=MAX(MAXV,ISJ2(I,1),ISJ2(I,2))
  20  CONTINUE
 
      MAXV=MAXV+1

      DO 21 IV1=1,MAXV
       DO 21 IV2=1,IV1
        DO 10 I=1,ISUMX
   10      P(I)=ZERO
       IVV=0
        DO 11 I=1,I1
          IF(IV1-1.EQ.ISJ2(I,1).AND.IV2-1.EQ.ISJ2(I,2))THEN
           P(IDX1(I))=P(IDX1(I))+S(I)
           IVV=IVV+1
          END IF
   11   CONTINUE
        IF(IVV.EQ.0)GO TO 21

C***Calculate average J'sum and rms deviation from average.

        SUM1=ZERO
        SUM2=ZERO
        SUM3=ZERO
       DO 30 I=1,ISUMX
         TEMPS=DBLE(I-1)
         SUM3=SUM3+P(I)
         SUM1=SUM1+TEMPS*P(I)
         SUM2=SUM2+TEMPS*TEMPS*P(I)
   30  CONTINUE
        SUM1=SUM1/SUM3
        SUM2=SUM2/SUM3
        AVE=SUM1
        RMS=DSQRT(ABS(SUM2-AVE*AVE))
        IVV1=IV1-1
        IVV2=IV2-1
        WRITE(6,12)AVE,RMS,IVV1,IVV2
   12  FORMAT(1X,43HProbabilities for specific JSUM. avg J'SUM ,1PE15.7,
     1/25H RMS deviation from avg. ,E15.7,5H V1'=,I2,5H V2'=,I2)
       DO 13 I=1,ISUMX,7
         IE=MIN(ISUMX,I+6)
         WRITE(6,14)(J,J=I-1,IE-1)
         WRITE(6,15)(P(J),J=I,IE)
   13  CONTINUE
   21 CONTINUE

   14 FORMAT(1X,4HJSUM,1X,7(5X,I5,5X))
   15 FORMAT(1X,4HProb,1X,7(1PE15.8))

      RETURN
      END

      SUBROUTINE TAUMTS(IS,ND,PD,NRED,LPRINT,ID,ISTART,NPROP,KS,EFCNI,
     1TAUI,TINVI,TMPTAU,EFCNM1,INR1,LDWTT,LEREF,EPS,IPIV)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE

C***  This subroutine is for use with RMPROP: Version 2.1.2.
C***  This subroutine calculates the (PD,PD) matrices TAUI and TINVI:
C***If ISTART equals 1 this subroutine calculates the matrices
C***TAUI(PD,PD) and TINVI(PD,PD).  If ISTART equals 2 only TINVI
C***is calculated.
C***  IS is the number of the sector for which calculate.
C***  ND and PD are NDIM and PDIM in calling program.
C***  NRED is (as in the calling program) the number of channels
C***propagated in sector IS.
C***  If LPRINT is true the subroutine calls PRNTM2 and TAUI and TINVI
C***are printed for IS.GE.2.
C***  ID is the first dimension of EFCNM1, EFCNI, TAUI and TINVI in COMMON
C***dimension statement.
C***  If (NPROP=1) the transpose of matrix TAUI is used instead of the
C***inverse in calculations and thus TINVI is unnecessary.
C***   The calculation uses EFCNI and EFCNM1.  TAUI and TINVI are
C***defined so that the two dimensional arrays can be used in matrix
C***manipulations.

      INCLUDE 'parameter.inc'
      COMMON/TIMCOM/TIMC(50)
      DIMENSION EFCNI(IDX,IDX),TAUI(IDX,IDX),TINVI(IDX,IDX),
     1TMPTAU(IDX*2),EFCNM1(IDX,IDX)
      LOGICAL LPRINT,LIJ,LDWTT,LEREF
      INTEGER PD,NPROP
      INTEGER IPIV(IDX)
      IF(IS.EQ.1.AND.LEREF)THEN

       DO 857 I=1,ND
        DO 857 J=1,ND
         EFCNM1(I,J)=EFCNI(J,I)
  857  CONTINUE
      END IF

      GO TO (1,12,4),ISTART

C***For first sector special definition.

    1 IF((IS-INR1).GT.1) GO TO 9

      DO 2 I=1,PD
       DO 32 J=1,PD
   32   TAUI(J,I)=0.0
    2 TAUI(I,I)=1.0

      IF((NPROP.EQ.1).AND.(INR1.GT.0))GOTO 4
      IF(NPROP.EQ.1)RETURN
      IF(NPROP.EQ.2)RETURN

      DO 3 I=1,PD
        DO 33 J=I,PD
   33    TINVI(J,I)=0.0
    3 TINVI(I,I)=1.0

      IF(INR1.GT.0)GOTO 4
      RETURN

C***For use at other than reference energy.

    4 CONTINUE
      RETURN

C***Calculate TAUI(recall that EFCNM1 holds transposed matrix).
C***Use non square portions of EFCNM1 and EFCNI.

    9 CONTINUE
      CALL SECOND(TIMEM1)

      CALL DGEMM('N','N',PD,ND,PD,1.0D0,EFCNM1,IDX,EFCNI,IDX,
     10.0D0,TAUI,IDX)

      DO 57 I=1,ND
       DO 57 J=1,ND
        EFCNM1(I,J)=EFCNI(J,I)
   57 CONTINUE
      CALL SECOND(TIMEM2)
      TIMC(18)=TIMC(18)+TIMEM2-TIMEM1

C***Calculate TINVI.

   12 IF(NPROP.EQ.1)GO TO 25
      IF(NPROP.EQ.2)RETURN

      DO 959 IKR=1,NRED
        DO 959 IKS=1,NRED
          TINVI(IKS,IKR)=TAUI(IKS,IKR)
  959 CONTINUE
      CALL SECOND(TIMGL1)

      JRANK=0
      IERR = 0
      CALL MINV(TINVI,NRED,IDX,TMPTAU,DET,EPS,0,1)                      6M7R94
      IF(DET.EQ.0.D0)IERR=1                                             6M7R94
      CALL DGETRF(NRED,NRED,TINVI,IDX,IPIV,IERR)                        4M26R94

      IF (IERR.NE.0)THEN                                                4M26R94
      WRITE(6,9592)IERR
 9592 FORMAT(/1X,'In TAUMTS inversion says matrix is singular ')
      STOP 111
      ENDIF                                                             4M26R94
C      JRANK=NRED                                                       4M26R94
      CALL DGETRI(NRED,TINVI,IDX,IPIV,TMPTAU,IDX,IERR)

C      DET=TMPTAU(1)                                                    4M26R94
C      IF(DET.NE.0D0)JRANK=NRED                                         4M26R94
      IF(IERR.EQ.0)JRANK=NRED                                           4M26R94
      CALL SECOND(TIMGL2)
      TIMC(17)=TIMC(17)+TIMGL2-TIMGL1

C***Check accuracy.

      IF(JRANK.EQ.NRED) GO TO 25
      WRITE(6,22) JRANK,IS,NRED
   22 FORMAT(2X,9HJRANK.EQ.,I4,9Hin sector,I5,14Hbut should.EQ.,I4)
      STOP 111
   25 CONTINUE

      IF(.NOT.LPRINT)RETURN

C***Option to print.

      WRITE(6,40)
   40 FORMAT(2X,11HTAUI matrix)
      CALL PRNTM2(TAUI,PD,PD,ID)
      IF(NPROP.EQ.1) RETURN

      WRITE(6,50)
   50 FORMAT(2X,12HTINVI matrix)
      CALL PRNTM2(TINVI,NRED,NRED,ID)

      RETURN
      END

      SUBROUTINE TDUMP(I,ID,TAUE,TINVE,LNOINV)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C***  This subroutine is for use with RMPROP: Version 2.1.2.
      INCLUDE 'parameter.inc'
      DIMENSION TAUE(IDX,IDX,NSAVEX),TINVE(IDX,IDX,NSAVEX)
      LOGICAL LNOINV
      IF(I.EQ.2)GO TO 2
      WRITE(8)TAUE
    2 IF(.NOT.LNOINV)WRITE(8)TINVE
      RETURN
      END

      SUBROUTINE TITLES(IS,IO,EFACT,ID,NSECT,LGS,RABC)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE

C***  This subroutine is for use with RMPROP: Version 2.1.2.
C***  If IO equals 1 this subroutine prints only a brief description
C***of the output for each sector.
C***  If IO equals 2 for a particular sector is the subroutine prints
C***the first few lines of output as defined by logical variables in LGS.

      INCLUDE 'parameter.inc'
      COMMON/LCM/LEFACT,LBES,LCONV,LDUM1,LDUM2,LR4MT,LDUM3,LSTOP2
      DIMENSION LGS(15),RABC(NSECTX)
      LOGICAL LDUM1,LDUM2,LDUM3
      LOGICAL LCONV,LSTOP2,LR4MT,LBES,LGS,LEFACT
      GO TO (100,200),IO

C***If only a brief description of output is desired, print this.

  100 WRITE(6,1)
      WRITE(6,3)
      WRITE(6,4)
      IF(LBES)WRITE(6,5)
    1 FORMAT(/1X,50HThe output for each sector has the following form:/
     13X,55Hthe integer after #SECTOR# is the number of the sector ,
     214Hfor which the ,/3X,25Hpropagator was calculated)
    3 FORMAT(3X,49HThe number after #R# is the center of the sector ,
     115Hin atomic units)
    4 FORMAT(3X,49HThe number after EFACT is the sum of the absolute,14H
     1 values of the/3X,40Hoff diagonal potential elements linking ,32H
     2channel 1 to all other channels,/3X,73HThis value is not available
     3 if the large RABC region has not been reached,/3X,
     449Hor if the D matrix has not yet been diagonalized.)
    5 FORMAT(3X,49HSince asymptotic matching is to Bessel functions,,21H
     1 2.0*MU*VCENT(ICT) is/,3X,30Hsubtracted from the numerator,,
     236H where VCENT(ICT) is the centrifugal,/3X,
     332Hpotential in the ICT-th channel.)
      RETURN

C***For a particular sector print the following.

  200 CONTINUE
      IF(LCONV)WRITE(6,120)
      IF(LSTOP2)WRITE(6,125)
  120 FORMAT(1X,32H*****Calculations converged*****)
  125 FORMAT(1X,29H*****Last sector allowed*****)
      IF(LGS(1))GO TO 140
      WRITE(6,130)IS
      RETURN
  140 IF(LEFACT)WRITE(6,145)IS,RABC(IS),EFACT
      IF(.NOT.LEFACT)WRITE(6,147)IS,RABC(IS)
  130 FORMAT(1X,6HSector,2X,I4)
  145 FORMAT(1X,6HSector,2X,I4,3X,1HR,2X,E12.6,3X,5HEFACT,2X,E12.6)
  147 FORMAT(1X,6HSector,2X,I4,3X,1HR,2X,E12.6,3X,
     119HEFACT NOT AVAILABLE)

      RETURN
      END

      SUBROUTINE TLOAD(ID,IS,TAUE,TINVE,LNOINV)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      INCLUDE 'parameter.inc'

C***The subroutine is for use with RMPROP: Version 2.1.2.

      DIMENSION TAUE(IDX,IDX,NSAVEX),TINVE(IDX,IDX,NSAVEX)
      LOGICAL LNOINV
      READ(8)TAUE
    8 IF(.NOT.LNOINV)READ(8)TINVE

      RETURN
      END

      SUBROUTINE DROP(ICT,NRED,NEWRED,EPSRED,NDR,EPSDR,IS,ISTART,ID,
     1SR2,R4MT,RABC)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C***The subroutine is for use with RMPROP: Version 2.1.2

C***  When ISTART equals 1 this subroutine is used to check whether a
C***particular closed channel is sufficiently uncoupled from the
C***remaining closed channels and ICT open channels that it can be
C***dropped and the current number of channels propagated, NRED,
C***reduced to a new value, NEWRED.  The criterion states that a
C***closed channel should be dropped when the absolute values of all
C***the OFF DIAGONAL elements of the matrix SR2 for it are              5M31R94
C***less than EPSRED.                                                   5M31R94
C***FORMERLY, all the elements of SR2 involving this channel were       5M31R94
C***compared with EPSRED.  This changed in RMPROP2.1.                   5M31R94
C***  When ISTART equals 2 the call to this subroutine, in sector IS,
C***immediately preceeds the call to subroutine GNSCAT and the
C***subroutine checks whether particular closed channels are
C***effectively uncoupled from the remaining channels and can be
C***neglected in the asymptotic analysis.  When the absolute value of
C***all the off diagonal elements of the matrix R4MT for a closed
C***channel are less than EPSDR the channel is neglected.  On input
C***the variable NDR is the number of channels currently propagated.
C***On output (input to GNSCAT) it is the number of channels required
C***in the asymptotic analysis.
C***  For both of the above options the checks start with the highest,
C***most closed channel propagated and proceed until the first
C***channel which fails to satisfy the criterion is encountered.

      INCLUDE 'parameter.inc'
      DIMENSION SR2(IDX,IDX),R4MT(IDX,IDX)
      GO TO (100,200),ISTART

C***Check all elements of SR2 corresponding to the most closed channel
C***to see if this channel can be dropped.
100   NREDM1=NRED-1                                                     5M31R94
      DO 10 J=1,NREDM1                                                  5M31R94
      A=ABS(SR2(NRED,J))
      IF(A.GT.EPSRED)GO TO 25
   10 CONTINUE

      DO 15 I=1,NREDM1
        B=ABS(SR2(I,NRED))
        IF(B.GT.EPSRED)GO TO 25
   15 CONTINUE

      NEWRED=NREDM1
      WRITE(6,20)IS,RABC,NRED
   20 FORMAT(/1X,12HAfter sector,I6,2X,10Hwhere R is,2X,1PE13.6,2X
     1,7Hchannel,I3,2X,10His dropped)
   25 RETURN

C***Check which closed channels can be ignored in the asymptotic
C***analysis.

  200 J=NDR
   35 JM1=J-1

      DO 40 I=1,JM1
        A=ABS(R4MT(I,J))
        B=ABS(R4MT(J,I))
        IF(A.GT.EPSDR)GO TO 50
        IF(B.GT.EPSDR)GO TO 50
   40 CONTINUE
      J=JM1
      IF(J.GT.ICT)GO TO 35
   50 NDR=J

      RETURN
      END
