      DOUBLE PRECISION FUNCTION EIGEN(IV,J)
      SAVE

C***This subroutine is for use with RMPROP: Version 2.1.2.
C***EIGEN is called by PREPOT (from Schwenke-Truhlar 3-D HF-HF
C***potential subroutine, in module 'stpot.f').
C***Calculate energy levels of HF using constants from D.U. Webb &
C***K.N. Rao, J. Mol. Spec, Vol 28, Page 121 (1968). IV is the
C***vibrational quantum number, and J is the rotational quantum
C***number.

      DATA Y10,Y20,Y30,Y40,Y50,Y01,Y11,Y21,Y31,Y02,Y12,Y22,Y03/
     14138.32D+0,-89.88D+0,0.90D+0,-1.10D-2,-6.7D-4,20.9557D+0,
     2-0.798D+0,1.27D-2,-4.4D-4,-2.151D-3,6.8D-5,-2.9D-6,1.59D-7/
      DATA HALF,WAVN/0.5D+0,4.556335D-6/

C***All constants are in wave numbers.

      FV=FLOAT(IV)+HALF
      FV2=FV*FV
      FV3=FV*FV2
      FV4=FV*FV3
      FV5=FV*FV4
      FJ=J*(J+1)
      FJ2=FJ*FJ
      FJ3=FJ*FJ2

      EIGEN=Y10*FV+Y20*FV2+Y30*FV3+Y40*FV4+Y50*FV5+Y01*FJ+Y11*FJ*FV+
     1Y21*FV2*FJ+Y31*FV3*FJ+Y02*FJ2+Y12*FV*FJ2+Y22*FV2*FJ2+Y03*FJ3

C***Convert to A.U.

      EIGEN=EIGEN*WAVN
      RETURN
      END

C***Calculate multipole moments for Hydrogen Fluoride.

      DOUBLE PRECISION FUNCTION DIPOLE(R)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE

C***This subroutine is for use with RMPROP: Version 2.1.2.
C***DIPOLE is called by COEFJF (from Schwenke-Truhlar 3-D HF-HF
C***potential subroutine, in module 'stpot.f').
C***R is bond length in bohr, dipole moment is returned in A.U.

      DIPOLE=R*EXP(-1.1257D0*R)*
     1(2.3707D0-R*(2.2827D0-R*1.4832D0))
      RETURN
      END

      DOUBLE PRECISION FUNCTION QUAD(R)

C***This subroutine is for use with RMPROP: Version 2.1.2.
C***QUAD is called by COEFJF (from Schwenke-Truhlar 3-D HF-HF
C***potential subroutine, in module 'stpot.f').
C***R is bond length in bohr, quadrupole moment is returned in A.U.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      QUAD=(R**3)*EXP(-1.8149D0*R)*
     1(10.455D0-R*(10.666D0-R*5.1793D0))
      RETURN
      END
