      SUBROUTINE PREPOT(LSTAP,NDIM,JIN,ID,L,JTOT,B,IS,EI,EFCN)

C***This subroutine reads in data, sets up the asymptotic eigenvectors
C***and defines the quantities needed by the potential subroutine.
C***This subroutine is for use with RMPROP: Version 2.1.2.
C***PREPOT is called once before the first call to POT.
C***PREPOT is called by PROGRAM RMPROP.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DOUBLE PRECISION MES
      DOUBLE PRECISION LL
      INTEGER FU4
      LOGICAL LSTAP,LHI,LLO,LSUM,LTR,LBN
      SAVE

C***PREPOT is called once before the first call to pot.

      PARAMETER(FU4=4)
      INCLUDE 'parameter.inc'
      COMMON/SUMCM/EDIFF(2),DUM1(2),ALL
      COMMON/APRXCM/P(2,2),S(2),Q(2),LL(2,2),IAP,LHI,LLO,LSUM,LTR,LBN
      DIMENSION JIN(IDX,NANX),L(IDX),B(IDX,IDX,NVIB1X),EI(IDX),
     1EFCN(IDX,IDX),IS(IDX,NVIBX)

C***Open FORTRAN unit 4.

      OPEN(UNIT=FU4,FILE='fort.4',FORM='formatted',STATUS='old')

C***Call HEADER to write out a description of the potential.

      CALL HEADER

C***Note that for electron-Hydrogen atom scattering we do not need to
C***use the array BPOT which ordinarily holds angular integrals
C***so we can initialize it to zero and forget about it.

      DO 11 K=1,NVIBX
         DO 10 I=1,ID
         DO 10 J=1,ID
            B(J,I,K)=0.0D0
   10    CONTINUE
   11 CONTINUE

C***Note that we do not need ISJ (ordinarily for internal vibrational
C***quantum numbers) so we can initialize this array to zero.

      DO 15 I=1,NVIBX
      DO 15 J=1,ID
         IS(J,I)=0.0D0
   15 CONTINUE

C***Note that we do not need EI (the internal state eigenenergy of the
C***isolated collision partners) so this becomes arbitrary.
C***We use it to allow for energy dependence of the channels.

      DO 20 I=1,ID
         AII=DBLE(I)
         EI(I)=0.5D0-0.5D0/(AII*AII)
   20 CONTINUE

C***Initialize asymptotic eigenfunctions.

      DO 25 I=1,ID
      DO 25 J=1,ID
         EFCN(J,I)=0.0D0
         EFCN(I,I)=1.0D0
   25 CONTINUE

C***Read in the necessary data from FORTRAN unit 4.
C***We have energy dependent potentials so read in the energy in the
C***potential data as well as from unit 5.

      READ(4,35)IAP
      READ(4,40)LHI,LLO,LSUM,LTR,LBN
      READ(4,45)LSTAP
      READ(4,65)ENER

C***The loop below allows for the fact that we have energy dependent
C***potentials.

      DO 30 I=1,ID
         EDIFF(I)=(0.5D0-0.5D0/(DBLE(I)*DBLE(I)))-ENER
   30 CONTINUE

C***The line below is for use by subroutine POT where the OAL is the
C***orbital angular momentum and 2.0D0 is twice the system reduced mass.

      OAL=1
      ALL=OAL*(OAL+1.0D0)/2.0D0

C***Read in messages from FORTRAN unit 4.

      READ(4,50)NLINE
      DO 55 I=1,NLINE
         READ(4,60)MES
         WRITE(6,60)MES
   55 CONTINUE

   35 FORMAT(I4)
   40 FORMAT(5L1)
   45 FORMAT(L1)
   50 FORMAT(I4)
   60 FORMAT(80A1)
   65 FORMAT(G15.6)
      RETURN
      END

      SUBROUTINE POT(SR,INDIM,ID,BPOT,A)

C***   This subroutine is for use with RMPROP: Version 2.1.2.
C***POT is called by PROGRAM RMPROP and by SUBROUTINE MATCH.
C***POT is only called by SUBROUTINE MATCH depending on input data.
C***This subroutine calculates the effective potential elements A(I,J)
C***at SR (R0 OR RABC(IS)) for all J and I.GE.J and stores them in
C***COMMON /PACKCM/.
C***INDIM is the dimension of the primitive basis set.  (It is the
C***same as NDIM of calling program).
C***ALL is defined as L*(L1)/(2.0*MUABC).
C***ICT is the number of open channels.
C***REQPOT is defined as the effective potential for LBESSL false
C***and as the real potential for LBESSL true for the highest open
C***channel.
C***IAP is an integer variable.  If IAP is less than zero the
C***effective potential is calculated in the static approximation,
C***If IAP is zero the high energy exchange approximation is used.
C***If IAP is greater than zero the semiclassical exchange
C***approximation is used.
C***
C***LHI,LLO,LSUM and LTR are logical variables.  For IAP greater
C***than or equal to zero LHI selects the expansion in higher wave
C***number, LLO selects the expansion in lower wave number, and
C***LSUM selects the summation approach to symmetrizing the exchange
C***approximation.
C***The logical variable LBN should only be true if IAP.EQ.ZERO
C***since then the BRANDSDEN NOBLE approximation, a modification
C***of the HEE approximation, is calculated.
C***For LTR true the triplet state approximation is calculated.  For
C***LTR false the singlet state approximation is calculated.
C***P,Q and LL are arrays used to store intermediate calculations
C***and must be dimensioned P(ID,ID),S(ID),Q(ID) and LL(ID,ID) where I
C***is the dimension described in calling program COMMON description.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      INCLUDE 'parameter.inc'
      COMMON/SUMCM/EDIFF(2),DUM1(2),ALL
      COMMON/APRXCM/P(2,2),S(2),Q(2),LL(2,2),IAP,LHI,LLO,LSUM,LTR,LBN
      DIMENSION BPOT(IDX,IDX,NVIB1X),A(IDX,IDX)
      LOGICAL LBESSL,LHI,LLO,LSUM,LTR,LIJ,LBN
      DOUBLE PRECISION LL
      SAVE

C***THE LINE BELOW IS A TEST OF LBESSL BY MJU 03-13-93

      LBESSL=.FALSE.

      NDIM=INDIM
      R=SR
      R2=R*R
      RINV=1.0/R
      ROOT2=SQRT(2.0)

C***Calculate the potential elements in the static approximation.

      A(1,1)=-(1.0+RINV)*EXP(-2.0*R)
      A(2,1)=2.0*ROOT2/9.0*(R+2.0/3.0)*EXP(-1.5*R)
      A(1,2)=2.0*ROOT2/9.0*(R+2.0/3.0)*EXP(-1.5*R)
      A(2,2)=-(RINV+0.75+0.25*R+0.125*R2)*EXP(-R)

C***Centrifugal potential.

      VCENT=ALL/R2

C***Specify approximation.

      IF(IAP)100,200,200

C***For static approximation.

  100 REQPOT=A(2,2)
      IF(.NOT.LBESSL)REQPOT=REQPOT+VCENT
      DO 115 I=1,NDIM
  115 A(I,I)=A(I,I)+VCENT
      RETURN

C***For exchange approximations.

  200 S(1)=EXP(-R)
      S(2)=(2.0-R)*EXP(-0.5*R)/(4.0*ROOT2)

C***For numerators.

      DO 250 J=1,NDIM
      DO 250 I=J,NDIM
  250 P(I,J)=S(I)*S(J)

C***For denominators.

      DO 260 I=1,NDIM
  260 Q(I)=(-EDIFF(I)-A(I,I))

C***High Energy Exchange approximation.

      IF(IAP.GT.0)GO TO 400
      FACT=2.0
      IF(LTR)FACT=-FACT

C***For BRANSDEN NOBLE approximation redefine denominators.

      IF(.NOT.LBN)GO TO 299
      DO 280 I=1,NDIM
      AI=I
  280 Q(I)=Q(I)+0.5/(AI*AI)

C***Diagonal elements in any high energy approximation.

  299 DO 300 I=1,NDIM
  300 LL(I,I)=P(I,I)*FACT/Q(I)
      IF(NDIM.EQ.1)GO TO 500

C***Off diagonal elements.

      IF(LSUM) GO TO 350

C***In expansion in higher or lower wave numbers.

      DO 320 J=1,NDIM
      JP1=J+1
      DO 320 I=JP1,NDIM
      LIJ=Q(I).GT.Q(J)
      IF(LHI.AND.LIJ)Z=Q(I)
      IF(LHI.AND..NOT.LIJ)Z=Q(J)
      IF(LLO.AND.LIJ)Z=Q(J)
      IF(LLO.AND..NOT.LIJ)Z=Q(I)
  320 LL(I,J)=FACT*P(I,J)/Z
      GO TO 500

C***Symmetrization by summation.

  350 DO 370 J=1,NDIM
      JP1=J+1
      DO 370 I=JP1,NDIM
  370 LL(I,J)=0.5*FACT*P(I,J)*(1.0/Q(I)+1.0/Q(J))
      GO TO 500

C***Semiclassical exchange approximation.

  400 FACT1=4.0
      FACT2=-8.0
      IF(LTR)FACT1=-FACT1
      IF(LTR)FACT2=-FACT2

C***Redefine denominators.

      DO 405 I=1,NDIM
  405 Q(I)=Q(I)+SQRT(Q(I)**2+FACT2*P(I,I))

C***Diagonal elements in any semiclassical exchange approximation.

      DO 410 I=1,NDIM
  410 LL(I,I)=FACT1*P(I,I)/Q(I)
      IF(NDIM.EQ.1)GO TO 500

C***Off diagonal elements.

      IF(LSUM)GO TO 450

C***For expansion in higher or lower order wave numbers.

      DO 420 J=1,NDIM
      JP1=J+1
      DO 420 I=JP1,NDIM
      LIJ=Q(I).GT.Q(J)
      IF(LHI.AND.LIJ)Z=Q(I)
      IF(LHI.AND..NOT.LIJ)Z=Q(J)
      IF(LLO.AND.LIJ)Z=Q(J)
      IF(LLO.AND..NOT.LIJ)Z=Q(I)
  420 LL(I,J)=FACT1*P(I,J)/Z
       GO TO 500

C***Symmetrize by summation.

  450 DO 470 J=1,NDIM
      JP1=J+1
      DO 470 I=JP1,NDIM
  470 LL(I,J)=0.5*FACT1*P(I,J)*(1.0/Q(I)+1.0/Q(J))

C***Calc effective potential elements.

  500 CONTINUE
      DO 510 I=1,NDIM
      DO 510 J=1,NDIM
  510 A(I,J)=A(I,J)+LL(I,J)
      REQPOT=A(2,2)
      IF(.NOT.LBESSL)REQPOT=REQPOT+VCENT
      RETURN
      END

      SUBROUTINE HEADER

C***This subroutine is for use with RMPROP: Version 2.1.2.
C***HEADER is called by SUBROUTINE PREPOT (electron-Hydrogren atom
C***potential subroutine in module 'ehydpot.f').

      WRITE(6,10)
   10 FORMAT(/1X,48HThis run tests electron Hydrogen atom scattering)
      RETURN
      END
