        SUBROUTINE POT(R,NDIM,ID,BPOT,UPCDMT)
        IMPLICIT DOUBLE PRECISION (A-H,O-Z)
        SAVE

C***This subroutine is for use with RMPROP: Version 2.1.2.
C***POT is called by PROGRAM RMPROP and by SUBROUTINE MATCH.
C***POT is only called by SUBROUTINE MATCH depending on input data.
C***This subroutine returns matrix elements of the potential matrix V  .
C***                                                                 ij
C***betweeen simultaneous eigenfunctions of the channel orbitaL
C***angular momentum and of the separated subsystems
C***at the specified input value of the radial separation R.

C***The file 'parameter.inc' below gives parameters for those arrays
C***needed within RMPROP itself.
C***The file 'expand.inc' below gives parameters for the individual
C***form of the interaction potential.

      INCLUDE 'parameter.inc'
      COMMON/OSCCOM/LHOSC,LSRIES
      COMMON/APRXCM/V0,ALPHA,BETA,MCBC,AMORSE,DMORSE,HOSCK,OMEGA
      PARAMETER (MAXPRM=40,IBDIM=MAXPRM*(MAXPRM+1)/2)
      PARAMETER (NMAX=12)
      DIMENSION XSQ1(MAXPRM,MAXPRM,NMAX)
      DIMENSION WV2(2,2)
      DIMENSION UPCDMT(IDX,2*IDX),BPOT(IDX,IDX,NVIB1X)
      COMMON/APCM/XSR1(MAXPRM,MAXPRM),XSR2(MAXPRM,MAXPRM),
     1XSR3(MAXPRM,MAXPRM),XSQ(MAXPRM,MAXPRM,2)
      DOUBLE PRECISION MCBC
      LOGICAL LHOSC,LSRIES
      DATA WV2/9.929272D-01,-1.187247D-01,1.187247D-01,9.929272D-01/


C***This individual form of the potential is for the collinear collision
C***of an atom A and a vibrating diatom BC, where the interaction potential
C***is given by V = V0 * EXP (-ALPHA * (X - Y))
C***where ALPHA is a constant, Y is the bond length of BC, and X is the
C***radial separation of the atom and the diatom.  
C***The diatom may be represented by either a morse oscillator or a
C***harmonic oscillator.
C***note that this system is in reduced dimensions.
C***For a complete discussion of the system, see A. P. Clark and 
C***A. S. Dickinson, J. Phys. B. Atom. Molec. Phys., Vol. 6, January 1973.
C***
C***The lines below calculate the interaction potential of the form
C***(EXP(GAMMA*X)) between harmonic oscillator wave functions
C***using the analytical expression of Sharp and Rapp,
C***J. Chem. Phys. 38, 2641 (63).
C***On return the (I,J) element of EXP(GAMMA*X) is stored in XSR1(I+1,J+1).

      GAMMA1=BETA*MCBC
      NDM1=NDIM-1
      CALL EXPSR(NDM1,ALPHA,GAMMA1,XSR1,MAXPRM,MAXPRM)


C***The line below calculates the interaction potential of the form
C***(X**P) between harmonic oscillator wave functions.

      IF(LHOSC.AND.LSRIES) CALL XMAT(NMAX,NDIM,XSQ1,MAXPRM,MAXPRM,NMAX,
     1ALPHA)
      IF(LHOSC)GOTO 131

C***The section of code below calculates the interaction potential
C***(EXP(GAMMA*X)) between morse oscillator wave functions.

      GAMMA2=-AMORSE*2.0D0
      GAMMA3=-AMORSE
      CALL EXPSR(NDM1,ALPHA,GAMMA2,XSR2,MAXPRM,MAXPRM)
      CALL EXPSR(NDM1,ALPHA,GAMMA3,XSR3,MAXPRM,MAXPRM)
      DO 120 J=1,NDIM
      DO 120 I=1,NDIM
         IF(J.GT.I)GOTO 120
         DEL=0.0D0
         IF(I.EQ.J)DEL=1.0D0
         XSR2(I,J)=DMORSE*(XSR2(I,J)-2.0D0*XSR3(I,J)+DEL)
  120 CONTINUE
      CALL XMAT(2,NDM1,XSQ,MAXPRM,MAXPRM,2,ALPHA)
      HK=-HOSCK/2.0D0
      DO 130 J=1,NDIM
      DO 130 I=1,NDIM
         IF(J.GT.I)GOTO 130
         XSR2(I,J)=XSR2(I,J)+HK*XSQ(I,J,2)
  130 CONTINUE
  131 CONTINUE
      V1=V0*EXP(-BETA*R)
      IF(.NOT.LHOSC)GO TO 170

C***Potential matrix for harmonic oscillator basis.

      DO 151 I=1,NDIM
      DO 151 J=1,NDIM
         UPCDMT(I,J)=V1*XSR1(I,J)
  151 CONTINUE
      RETURN

C***Potential matrix for Morse oscillator basis.

  170 DO 191 J=1,NDIM
      DO 191 I=1,NDIM
         BPOT(I,J,1)=V1*XSR1(I,J)
         UPCDMT(I,J)=BPOT(I,J,1)+XSR2(I,J)
  191 CONTINUE
      RETURN
      END
      SUBROUTINE EINT(NDIM,ID,EI,IS,OMEGA)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE

C***This suboroutine is for RMPROP: Version 2.1.2.
C***EINT is called by SUBROUTINE PREPOT (collinear atom-vibrating diatom
C***potential routine, in module 'preheh2.f').
C***This subroutine assigns the first ndim vibrational energy levels
C***of a harmonic oscillator of frequency OMEGA and stores them in EI.

      INCLUDE 'parameter.inc'
      DIMENSION EI(IDX),IS(IDX,NVIBX)

C***OMEGA (IN ATOMIC UNITS) FOR THE HYDROGEN MOLECULE

      DO 10 I=1,NDIM
         AI=I
   10 EI(I)=(AI-0.5D0)*OMEGA
      RETURN
      END
      SUBROUTINE HEADER
      SAVE

C***This subroutine is for RMPROP: Version 2.1.2.
C***EINT is called by SUBROUTINE PREPOT (collinear atom-vibrating diatom
C***potential routine, in module 'preheh2.f').

      WRITE(6,10)
      WRITE(15,10)
   10 FORMAT(1X,39HCollinear Helium atom-hydrogen molecule/)
      RETURN
      END
      SUBROUTINE EXPSR(ND,ALPHA,GAMMA,Q,IR,JC)
      IMPLICIT DOUBLE PRECISION  (A-H,O-Z)
      SAVE

C***This subroutine is for use with RMPROP: 2.1.2.
C***EXPSR may be called by SUBROUTINE POT (collinear atom-vibrating diatom
C***potential subroutine in module 'potheh2.f').
C***This subroutine calculates EXP(GAMMA*X) between harmonic
C***oscillator wavefunctions N,M=0,1,...ND using the analytic
C***expression given by Sharp and Rapp, J. Chem. Phys. 38, 2641(63).
C***For an oscillator with force constant K equal TO MU*(OMEGA**2)
C***ALPHA is defined ALPHA=SQRT(HBAR/(2.0*MU*OMEGA)).  The (I,J)
C***element of EXP(GAMMA*X) is stored in Q(I+1,J+1).
C***IR and JC are the first and second dimensions of Q in the calling
C***program DIMENSION statement.
C***F, BT, and TWO are temporary arrays and must be dimensioned at
C***least (ND+1), (2*ND+1), and (ND+1) respectively.

      COMMON/EXPCM/F(41),BT(81),TWO(41)
      DIMENSION Q(IR,JC)
      IF(ND.GT.40)GOTO 90
      BETA=GAMMA*ALPHA/DSQRT(2.0D0)
      NDP1=ND+1

C***Calculate factorials.  Store J factorial in F(J+1).

      F(1)=1.0D0
      F(2)=1.0D0
      IF(ND.LT.2)GO TO 11
      DO 10 I=2,ND
        IP1=I+1
        AI=I
   10 F(IP1)=F(I)*AI

C***Calculate powers of BETA.  Store BETA**M in BT(M+1).

   11 BT(1)=1
      BT(2)=BETA
      MEND=2*ND+1
      IF(MEND.LT.3)GO TO 21
      DO 20 M=3,MEND
        MM1=M-1
   20 BT(M)=BT(MM1)*BETA

C***Calculate powers of two.  Store 2**M in TWO(M+1).

   21 TWO(1)=1.0D0
      TWO(2)=2.0D0
      IF(NDP1.LT.3)GO TO 31
      DO 30 I=3,NDP1
      IM1=I-1
   30 TWO(I)=TWO(IM1)*2.0D0

C***Calculate all elements (M,N) for N.GE.M.

   31 DO 50 I=0,ND
      DO 50 J=I,ND
         M=I+1
         N=J+1
         JI=J-I+1
         Q(M,N)=0.0D0
        DO 40 L=0,I
           L1=L+1
           L2=I-L+1
           L3=JI+L
           L4=2*L+1
           DEN=F(L2)*F(L3)*F(L1)
   40   Q(M,N)=TWO(L1)*BT(L4)/DEN+Q(M,N)
         A1=BT(3)
         A2=TWO(JI)*F(N)*F(M)
         Q(M,N)=EXP(A1)*DSQRT(A2)*BT(JI)*Q(M,N)
   50 Q(N,M)=Q(M,N)
      RETURN
   90 WRITE(6,65)ND
   65 FORMAT(1X,25HIn subroutine EXPSR ND = ,I3,42H is greater than 40 t        
     1he maximum dimension.)
      STOP 'in module expsr.f'
      END
