      SUBROUTINE FUN1(R,R1,COSC,FN,NPTS)

C***This subroutine is for use with RMPROP: Version 2.1.2.
C***FUN1 is called by SUBROUTINE COEF (from generalized atom-diatom
C***potential routine, in module 'vgr2.f').
C***This subroutine will calculate He-I2 interaction potential from
C***pairwise approximation.
C***
C***Parameters and details published in Chem. Phys. Lett, Vol. 98, p. 217 (1983)
C***
C***   Parameter List:
C***
C***R is the center-of-mass separation of the He and I2.
C***
C***R1 is the bond length of the I2.
C***
C***COSC is the cosine of the orientation angle chi.
C***
C***FN is the interaction potential.
C***
C***NPTS is the number of points at which the potential should be evaluated.
C***

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE

      DIMENSION COSC(1),FN(1)
      T=R*R+R1*R1/4D0
      TEMP=R*R1
      DO 2 I=1,NPTS
      C=TEMP*COSC(I)
      SR1=SQRT(T+C)
      SR2=SQRT(T-C)
      F1=REPUL(SR1)
      F2=REPUL(SR2)
      F3=DISP(SR1)
      F4=DISP(SR2)
      FN(I)=F1+F2-F3-F4

C***Diagnostic write out.

C     WRITE(6,'(1X,1P4E15.8)')R,R1,COSC(I),FN(I)

    2 CONTINUE

C***Diagnostic write out.

C     WRITE(6,1)R,R1,FN,SR1,SR2,F1,F2,F3,F4
C   1 FORMAT(1X,1P,9E15.8)

      RETURN
      END

      FUNCTION DISP(R)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)

C***This function calculates the dispersion interaction.

      COMMON/DISPCM/D6,D4,D2,C6,C8,C10
      R2=R*R
      R4=R2*R2
      R6=R4*R2
      DISP=C6/(R6+D6)+C8/(R4+D4)**2+C10/(R2+D2)**5
      RETURN
      END

      FUNCTION REPUL(R)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)

C***This function calculates the repulsive wall.

      COMMON/REPCOM/A,B
      EX=EXP(-R*B)
      REPUL=A*EX/R
      RETURN
      END

      BLOCK DATA HEI2
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      COMMON/REPCOM/A,B
      COMMON/DISPCM/D6,D4,D2,C6,C8,C10
      DATA A,B/1.19D+2,1.57D+0/
      DATA D2,D4,D6/2.89D+0,8.3521D+0,24.137569D+0/
      DATA C6,C8,C10/1.97D+1,3.62D+2,7.623D+3/
      END
      DOUBLE PRECISION FUNCTION EIGEN(NV,NJ)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE

C***This subroutine is for use with RMPROP: Version 2.1.2.
C***EIGEN is called by SUBROUTINE PREPOT (with generalized atom-vibrating
C***diatom potential routine, in module 'vgr2.f').
C***TEMP3 IS 4*DE

      DATA OMEGA/9.7734228672D-04/,HALF/0.5D+0/,BE/1.70279D-7/
      DATA TEMP3/3.410477D-1/
      TEMP1=(DBLE(NV)+HALF)*OMEGA
      TEMP2=TEMP1*TEMP1/TEMP3
      EIGEN=TEMP1-TEMP2+DBLE(NJ*(NJ+1))*BE
      RETURN
      END
