      SUBROUTINE FUN1(R,R1,R2,C1,S1,C2,S2,CP,SP,V,NPTS)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C***
C***This file is for use with RMPROP: Version 2.1.2.
C***FUN1 is called by SUBROUTINE POT (general 3-D diatom-diatom potential
C***routine, in module 'vgr3.f').
C***Calculate interaction potential for Alexander and DePristo
C***HF-HF potential energy surface, JCP 65, 5009 (1976).
C***
C***    Parameter List:
C***
C***R:     Center-of-mass separation of the two diatoms.
C***
C***R1:    Not used for rigid rotors, normally the bond length of monomer 1.
C***
C***R2:    Not used for rigid rotors, normally the bond length of monomer 2.
C***
C***C1:    The cosine of THETA1.
C***
C***S1:    The sine of THETA1.
C***
C***C2:    The cosine of THETA2.
C***
C***S2:    The sine of THETA2.
C***
C***CP:    The cosine of PHI.
C***
C***SP:    The sine of PHI.
C***
C***V:     Value of the potential at the specified coordinates.
C***
C***NPTS:  The number of different values of the coordinates at which
C***       to determine the potential.
C***
      INCLUDE 'parameter.inc'
      INCLUDE 'expand.inc'

      DIMENSION C1(NQAMAX**3),S1(NQAMAX**3),C2(NQAMAX**3),S2(NQAMAX**3),
     1 CP(NQAMAX**3),SP(NQAMAX**3),V(NQAMAX**3),TEMPP(NQAMAX**3)
      PARAMETER (ZERO=0D0,HALF=0.5D0,ONE=1.0D0,TWO=2.0D0,THREE=3.0D0)

C***Constants for YL1L2L'S.
C***D1 is 1/SQRT((4*PI)**3).
C***D2 is 3/SQRT((4*PI)**3).
C***D3 is SQRT(30)/(2*SQRT((4*PI)**3)).
C***D4 is 3*SQRT(7)/SQRT((4*PI)**3).

      PARAMETER (D1=2.2448390265645820D-02,D2=6.7345170796937462D-02,
     $D3=6.1477448640868021D-02,D4=0.1781785739298661D0)

      DATA C000A,C000B/4.8604841D+3,-3.5856030D+1/
      DATA C011A,C011B/-2.9162905D+2,0.97209683D+0/
      DATA C112A,C112B,C112C/-0.78086467D+0,-7.1712061D-2,-8.3393159D+0/
      DATA C123A,C123B,C123C/-6.6931257D+2,1.5936013D+2,2.3298452D+1/
      DATA EX1,EX2,EX3,EX4/-1.1D+0,-0.7885D+0,-0.475D+0,-2.04D+0/

      EXP0=EXP(-R)
      EXP1=EXP(EX1*R)
      EXP3=EXP(EX3*R)
      RI=ONE/R

      A000=C000A*EXP0*EXP0+C000B*EXP1

      RI3=RI**3
      A112=C112A*EXP0+C112B*EXP3+C112C*RI3

      EXP3=EXP3*EXP3
      EXP3=EXP3*EXP3
      EXP0=EXP(EX2*R)
      A011=C011A*EXP3+C011B*EXP0
      A101=-A011

      RI4=RI3*RI
      EXP0=EXP(EX4*R)
      A123=(C123A*RI+C123B)*EXP0+C123C*RI4
      A213=-A123

C***Loop over angles--calculate YL1L2L'S.

      DO 20 I=1,NPTS
      Y101=D2*C1(I)
      Y011=D2*C2(I)
      TEMPP(I)=S1(I)*S2(I)*CP(I)
      Y112=D3*(TWO*C1(I)*C2(I)-TEMPP(I))
      Y123=D4*(HALF*C1(I)*(THREE*C2(I)*C2(I)-ONE)-TEMPP(I)*C2(I))
      Y213=D4*(HALF*C2(I)*(THREE*C1(I)*C1(I)-ONE)-TEMPP(I)*C1(I))

C***Potential.

      V(I)=D1*A000+A011*(Y011-Y101)+A112*Y112+A123*Y123+A213*Y213
  20  CONTINUE
      RETURN
      END

      DOUBLE PRECISION FUNCTION EIGEN(IV,IJ)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C***This function is for use with RMPROP: Version 2.1.2.
C***EIGEN is called by SUBROUTINE PREPOT (general 3-D vibrating diatom-
C***vibrating diatom potential routine, in module 'prevgr3.f').
C***Calculate rotational energy levels using formula given by
C***Alexander and DePristo.

      DATA B0,D0/9.36764D-5,9.6457587D-9/
      XJ=DBLE(IJ*(IJ+1))
      EIGEN=XJ*(B0-XJ*D0)
      RETURN
      END
      SUBROUTINE HEADER
      SAVE

C***HEADER is called by SUBROUTINE PREPOT (general 3-D vibrating diatom-
C***vibrating diatom potential routine, in module 'prevgr3.f').

      IDUM=1
      WRITE(6,5)
    5 FORMAT(/1X,20HHF-HF 3D scattering./
     +1X,33HLaunay expansion of the potential/)
      RETURN
      END

