      SUBROUTINE POT(SR,NDIM,ID,B,UPCDMT)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C***This subroutine is for use with RMPROP: Version 2.1.2.
C***POT is called by PROGRAM RMPROP and by SUBROUTINE MATCH.
C***POT is only called by SUBROUTINE MATCH depending on input data.
C***This subroutine calculates the effective potential elements A(I,J)
C***at SR (R0 or RABC(IS)) for all J and I.GE.J and stores them in
C***COMMON /PACKCM/.
C***This subroutine is specifically applicable to collinear atom
C***molecule collisions for which the model potential is approximated
C***by the expression for the potential surface of H-F H-F interaction
C***as given in Poulsen et al JCP VOL 68 PAGE 5121(1978)
C***and two isolated morse oscillators and for
C***which the primitive basis set expansion of Light and Walker
C***uses asymptotic harmonic oscillator wavefunctions.
C***NDIM is the dimension of the primitive basis set.
C***For LFIRST TRUE a brief description of the particular approximation
C***is written and sector and energy independent quantities are
C***calculated.
C***V0 is that constant which scales the potential.  (All scattering
C***information should be independent of this.  It is chosen to give
C***reasonable turning points.)
C***ALPHA is defined for a harmonic oscillator as the
c***SQRT(1/(2.0*MU*OMEGA)) where MU is the reduced mass and OMEGA is
C***the oscillator frequency. ALPHA is needed to evaluate the matrix
C***elements for the asymptotic expansion in harmonic oscillator
C***wavefunctions.
C***If LHOSC is TRUE the molecule is treated as a harmonic
C***oscillator.  If LHOSC is FALSE the molecule is treated as a
C***Morse oscillator and the constants AMORSE, DMORSE, and HOSCK
C***are also necessary.  AMORSE and DMORSE define the Morse
C***potential and HOSCK is the force constant of the oscillators
C***of the asymptotic harmonic oscillator basis.
C*** XSR2 and XSR3 must be dimensioned (MAXOS1,MAXOS1) where MAXOS1 is
C***MAXOS+1, where MAXOS is the maximum number of QUANTA used in the
C***harmonic oscillator basis. XSQ1 must be dimensioned (MAXOS1,MAXOS1
C***and XSQ (MAXOS1,MAXOS1,2)

      COMMON/APRXCM/ALPHA,AMORSE,DMORSE,HOSCK,OMEGA,XMU,DGEN
     1,GO,GT,T
      COMMON/APCM/XSR2(11,11),XSQ1(11,11,20),IMP(10),RIMP(9),IMPN,NPOWER
     1,XEX(11,11),PX,PX1,PX2,PX3,PX4,PX5,PX6,PX7,PX8,PX9,DPMD,DPMDS,QPMD
      INCLUDE 'parameter.inc'
      COMMON/OSCCOM/LHOSC
      COMMON/VIBCOM/IS(15,2)
      DIMENSION XSR3(11,11),Z1(11,11)
      DIMENSION B(IDX,IDX,NVIB1X),UPCDMT(IDX,IDX),A(50,50)
      DIMENSION VOO(15,15),BK(49,49),Z(20,20),ZI(11,11),ZT(11,11)
      LOGICAL LSTAP,LHOSC,LSRIES,LTEMP,LTEMP1,LOG1

C***In each sector calculate the following.

   99 R=SR
      LOG1=.TRUE.
      IF(NPOWER.EQ.IMPN)GOTO 131
      IF(R.GE.RIMP(NPOWER))NPOWER=NPOWER+1
  131 CALL GHFHF8(R,VOO,LOG1,IMP(NPOWER),GO,GT,T)
      DO 151 I=1,NDIM
      L=1
      K1=1
      J=1
      M1=IS(I,1)
      M3=IS(I,2)
    8 M2=IS(L,1)
      M4=IS(K1,2)
      LTEMP=M1.EQ.M2
      LTEMP1=M3.EQ.M4
      SUM=0.0D+0
      DO 14 N=1,IMP(NPOWER)
      DO 14 N1=1,IMP(NPOWER)
   14 SUM=SUM+VOO(N,N1)*XSQ1(M1,M2,N)*XSQ1(M3,M4,N1)
      PTEMP=0.0D0
      QTEMP=0.0D0
      IF(LTEMP)PTEMP=XSR2(M3,M4)
      IF(LTEMP1)QTEMP=XSR2(M1,M2)
      IF(LTEMP.AND.LTEMP1)GOTO12
      IF(LTEMP.AND..NOT.LTEMP1)GOTO15
      IF(LTEMP1)GOTO29
      IF(.NOT.LTEMP.AND..NOT.LTEMP1)BK(I,J)=0.0D0
      GOTO 77
   15 BK(I,J)=PTEMP
      GOTO 77
   12 BK(I,J)=PTEMP+QTEMP
      GOTO 77
   29 BK(I,J)=QTEMP
   77 A(I,J)=BK(I,J)+SUM
      L=L+1
      K1=K1+1
      J=J+1
      IF(J.LE.I) GOTO 8
  151 CONTINUE
      KPACK=0
      DO 212 I=1,NDIM
      DO 212 J=1,NDIM
      UPCDMT(J,I)=A(J,I)
  212 CONTINUE
      DO 213 I=1,NDIM
      DO 213 J=I,NDIM
  213 UPCDMT(I,J)=UPCDMT(J,I)
      RETURN
      END
      SUBROUTINE HEADER
      SAVE

C***This subroutine for use with RMPROP: Version 2.1.2.
C***HEADER is called by SUBROUTINE PREPOT (Poulsen-Billing-Steinfeld HF-HF
C***potential subroutine, in module 'prehfhfpbs.f').

      WRITE(6,10)
      WRITE(15,10)
   10 FORMAT(1X,77HCollinear HF-HF. IS(I) is the vibrational quanta of t
     1he first HF molecule + 1,/1X,65Hand JS(I) is the vibrational quant
     2a of the second HF molecule +1.)
      RETURN
      END
      SUBROUTINE EINT(NDIM,ID,EI,IS,JS,OMEGA,IMPN,IMP,RIMP)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE

C***This subroutine is for use with RMPROP: Version 2.1.2.
C***EINT is called by SUBROUTINE PREPOT (Poulsen-Billing-Steinfeld HF-HF
C***potential subroutine, in module 'prehfhfpbs.f').
C***This subroutine assigns the first NDIM vibrational energy levels
C***of a harmonic oscillator of frequency OMEGA and stores them in EI.

C***Omega (in atomic units) for the Hydrogen molecule.

      COMMON/VIBCOM/IST(15),JST(15)
      DIMENSION EI(ID),IS(ID),JS(ID),IMP(10),RIMP(9)
      READ(4,15) (IS(I),I=1,NDIM)
      READ(4,15) (JS(I),I=1,NDIM)
      READ(4,15) IMPN
      READ(4,15)(IMP(I),I=1,IMPN)
      READ(4,25)(RIMP(I),I=1,IMPN-1)
   25 FORMAT(6G15.7)
      WRITE(6,9)
      WRITE(6,11) (IS(I),JS(I),I=1,NDIM)
    9 FORMAT(1X,'The channels in the diatom oscillators are')
   11 FORMAT(1X,'(IS(I),JS(I),I=1,NDIM)'//(11X,12(1H(,I2,1H,,I2,1H)
     1,1H,)))
   15 FORMAT(10I5)
      OMEGA1 = OMEGA
      OMEGA2 = OMEGA + 1D-9
      DO 10 I=1,NDIM
       IST(I)=IS(I)
       JST(I)=JS(I)
         AI= FLOAT(IS(I))
         BI= FLOAT(JS(I))
         EI(I)=(AI-.5D0)*OMEGA1+(BI-.5D0)*OMEGA2
   10 CONTINUE
      RETURN
      END
      SUBROUTINE XMATMO(IP,IK,Q,IF,IS,IT,EI,IC1,IC2,ID,A)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE

C***This subroutine is for use with RMPROP: Version 2.1.2.
C***XMATMO is called by SUBROUTINE POT (Poulsen-Billing-Steinfeld HF-HF
C***potential subroutine, in module 'pothfhfpbs.f').

      DIMENSION Q(IF,IS,IT),EI(ID),IC1(ID),IC2(ID),XSR1(20,20,20),E(20)
     1,E1(20),TMMEL(8000)

C***ARITHMETIC TRAP

      IF((IP.LE.20).OR.(IK.LE.20))GOTO 9
      WRITE(6,15)
   15 FORMAT(1X,54Htoo big a basis, or too many powers required in XMATM
     1O)
      STOP 'STOP in XMATMO in pothfhfpbs.f'
    9 MMEL=1
      DO 459 J=1,2666
      READ(4,11)TMMEL(MMEL),TMMEL(MMEL+1),TMMEL(MMEL+2)
  459 MMEL=MMEL+3
      READ(4,460)TMMEL(7999),TMMEL(8000)
  460 FORMAT(2F20.12)
      MMEL=1
      DO 10 K=1,20
      DO 10 J=1,20
      DO 10 I=1,20
      XSR1(I,J,K)=TMMEL(MMEL)
   10 MMEL=MMEL+1
      READ(4,11)E
      READ(4,12,END=66)ISIZE
   11 FORMAT(3F20.12)
   12 FORMAT(I5)
   13 FORMAT(3I5,F20.12)
      WRITE(6,67)ISIZE
   67 FORMAT(1X,47HMORSE OSC. BASIS EXPANDED IN H.O. BASIS OF SIZE,I3)
      GOTO 68
   66 WRITE(5,69)
   69 FORMAT(1X,51HTHERE IS NO ISIZE PARAMETER ON FOR067, SO ISIZE=20?)
   68 CONTINUE
      DO 50 I=1,20
   50 E1(I)=E(I)*A
      WRITE(6,23)A
   23 FORMAT(/1X,24HDEGENERACY FACTOR E2=E1*,1PE20.14)
      DO 933 I=1,15
      EI(I)=E(IC1(I))+E1(IC2(I))
  933 CONTINUE
      DO 20 I=1,IK
      DO 20 J=1,IK
      DO 20 K=1,IP
   20 Q(I,J,K)=XSR1(I,J,K)
      RETURN
      END
      SUBROUTINE GHFHF8 (R,V,LOG1,IMAX,GO,GT,T)

C***This subroutine is for use with RMPROP: Version 2.1.2.
C***GHFHF8 is called by SUBROUTINE POT (Poulsen-Billing-Steinfeld HF-HF
C***potential subroutine, in module 'pothfhfpbs.f').
C***This subroutine calculates the interaction potential for two HF
C***molecules using the fit given in Poulsen et al, JCP Vol 68 page
C***5121 (1978). A Taylor series in the two vibrational coordinates
C***is used, and V(I,J) contains the I-1th derivative of the potential
C***wrt the 1st HF molecule's vibrational coordinate, and the J-1th
C***derivative of the potential wrt the 2nd HF molecule's vibrational
C***coordinate in the cofiguration defined by R = center of mass
C***separation, GO = GAMMA1, GT = GAMMA2, and T = PHI2 - PHI1, where
C***GAMMA1, etc. are defined in Poulsen et al. Each V(I,J) is divided
C***by the appropriate factorial. Atomic units are used.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      DIMENSION V(15,15),BR1(16),CR1(16),RHI(15),CE(35),IP(15),BR2(16),
     1CR2(16),IPS(16),IPF(25),CE1(35),I1B(309),I2B(309),I1C(309),
     2I2C(309),RHC(15),CRF(16),BRF(16),CEF(71),RHFI(15),RFHI(15),
     3IR(309),ICC2(5),ICC1(5),CEC(309),CEH(309),CET(35),CER(35)
      COMMON /GHFHF4/CE,IP,IPF,ICC2,ICC1,CEC,I1C,I1B,I2B,IR,CEH,CE1,CEF
     1,CER,CET
      LOGICAL LOG1
      IF(LOG1)GOTO 1
      B1=DCOS(GO)*.95D0
      B2=-.95D0*DCOS(GT)
      CF1=(.95D0*DSIN(GO))**2
      CF2=(.95D0*DSIN(GT))**2
      CR2(1)=1D0
      CR2(2)=-.9025D0*(DSIN(GO)*DSIN(GT)*DCOS(T)+DCOS(GO)*DCOS(GT))
      DO 4 I=3,16
    4 CR2(I)=CR2(I-1)*CR2(2)
      VC1=EXP(.89999D0*3.7966D0)
      VC2=VC1*VC1
      RETURN
    1 CONTINUE
      IF(IMAX.LE.11)GOTO 18
      WRITE(6,212)IMAX
  212 FORMAT(/1X,7HIMAX = ,I5,1X,38His too big and is reset to 11 in GHF
     1HF/)
      IMAX=11
   18 RH1=R*R+R*3.4661366D0*(B1+B2)+5.42136394709913D0+6.00705146492978D
     10*CR2(2)
      DO 74 I=1,15
      DO 74 J=1,15
   74 V(I,J)=0D0
      CFF1=CF1*1.50176286623245D0
      CFF2=CF2*1.50176286623245D0
      RHF=R+1.7330683D0*B1+CFF1/R
      RFH=R+1.7330683D0*B2+CFF2/R
      VHF1=EXP(-.89999D0*(RHF))
      VHF2=VHF1*VHF1
      VFH1=EXP(-.89999D0*(RFH))
      VFH2=VFH1*VFH1
      RHFI(1)=1D0/RHF
      RFHI(1)=1D0/RFH
      CRF(1)=1D0
      CRF(2)=.5D0*CF1/R
      BRF(1)=1D0
      BRF(2)=B1+CRF(2)*3.4661366D0
      RH2=SQRT(RH1)
      RHI(1)=RH2**(-4.0958D0)
      RHC(1)=1D0/RH2
      V(1,1)=.280202929198681D0*RHI(1)
     1 +.188889570596142D0*(RHC(1)-RHFI(1)-RFHI(1)+1D0/R)
     2 +130.6625637D0*EXP(-2.2131D0*R)+.474701976D0*R**(-3.6131D0)
     3 -48.57127105D0*R**(-6)+2.78752752D-3*(VC2*(VHF2+VFH2)-2D0*VC1
     4 *(VFH1+VHF1))
      BR1(1)=1D0
      BR1(2)=R*B1+1.7330683D0*(CR2(2)+.9025D0)
      IC1=1
      DO 2 I=2,IMAX
         RHI(I)=RHI(I-1)/RH1
         RHC(I)=RHC(I-1)/RH1
         RHFI(I)=RHFI(I-1)/RHF
         RFHI(I)=RFHI(I-1)/RFH
         CRF(I+1)=CRF(I)*CRF(2)
         BRF(I+1)=BRF(I)*BRF(2)
         BR1(I+1)=BR1(I)*BR1(2)
         IC2=1
         IC3=I
         K=I+IP(I-1)
        DO 3 J=IP(I-1),I
           K1=K-J
           V(I,1)=V(I,1)+CE1(IC1)*BR1(IC3)*RHI(K1)
     1    -CE(IC1)*BR1(IC3)*RHC(K1)+(CET(IC1)*VHF2+CER(IC1)*VHF1
     2    -CEF(IC1)*RHFI(K1))*CRF(IC2)*BRF(IC3)
           IC1=IC1+1
           IC2=IC2+1
    3   IC3=IC3-2
    2 CONTINUE
      BR2(1)=1D0
      BR2(2)=R*B2+1.7330683D0*(CR2(2)+.9025D0)
      CRF(2)=.5D0*CF2/R
      BRF(2)=B2+CRF(2)*3.4661366D0
      IC1=1
      DO 12 I=2,IMAX
         BR2(I+1)=BR2(I)*BR2(2)
         CRF(I+1)=CRF(I)*CRF(2)
         BRF(I+1)=BRF(I)*BRF(2)
         IC2=1
         IC3=I
         K=I+IP(I-1)
        DO 13 J=IP(I-1),I
           K1=K-J
           V(1,I)=V(1,I)+CE1(IC1)*BR2(IC3)*RHI(K1)
     1    -CE(IC1)*BR2(IC3)*RHC(K1)+(CET(IC1)*VFH2+CER(IC1)*VFH1
     2    -CEF(IC1)*RFHI(K1))*CRF(IC2)*BRF(IC3)
           IC1=IC1+1
           IC2=IC2+1
   13   IC3=IC3-2
   12 CONTINUE
      IC1=1D0
      IC2=1D0
      IC3=1D0
      IMAX1=INT(IMAX/2)+1
      DO 15 I=2,IMAX1
         DO 17 J=I,IMAX-I+1
            DO 16 K=1,IPF(IC1)
               A=CEH(IC2)*CR2(I1C(IC2))*RHI(IR(IC2))
               AC=CEC(IC2)*CR2(I1C(IC2))*RHC(IR(IC2))
               V(I,J)=V(I,J)+(A-AC)*BR1(I1B(IC2))*BR2(I2B(IC2))
               IF(I.EQ.J)GOTO 16
               V(J,I)=V(J,I)+(A-AC)*BR1(I2B(IC2))*BR2(I1B(IC2))
   16       IC2=IC2+1
   17    IC1=IC1+1
         IC2=ICC2(IC3)
         IC1=ICC1(IC3)
         IC3=IC3+1
15    CONTINUE
      RETURN
      END
      BLOCK DATA HFHF
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE

C***Array I2C(309) used to be between CET(35) and CEF(71).

      DIMENSION CE(35),IP(15),CEH(309),CE1(35),
     1 IPF(25),I1B(309),I2B(309),I1C(309),CER(35),CET(35),
     2 CEF(71),IR(309),CEC(309),ICC2(5),ICC1(5)

C***The common block below used to have IP, CE,...

      COMMON /GHFHF4/CE,IP,IPF,ICC2,ICC1,CEC,I1C,I1B,I2B,IR,CEH,CE1,CEF
     1,CER,CET

      DATA IP/2,2,3,3,4,4,5,5,6,6,7,7,8,8,9/
      DATA CE/+.18888957D0, -.283334355D0, +8.5236418D-2, +.472223925D0,
     1 -.255709255D0, -8.263918714D-1, +.639273139D0, -5.76944D-2,
     2 +1.487505369D0, -1.491637289D0, +.288472003D0, -2.727093176D0,
     3 +3.356183988D0, -1.009652016D0, +4.3390996D-2, +5.064601612D0,
     4 -7.383604773D0, +3.028956049D0, -.303736981D0, -9.496128022D0,
     5 +15.99781034D0, -8.329629136D0, +1.366816418D0, -3.426532758D-2,
     6 +17.93713071D0, -34.28102216D0, +21.65703575D0, -5.011660199D0,
     7 +.308387953D0, -34.08054836D0, +72.8471721D0, -54.14258937D0,
     8 +16.28789564D0, -1.696133747D0, +2.783201281D-2/
      DATA IPF/2, 3, 4, 5, 6, 7, 8, 9, 10, 6, 7, 10, 11, 14, 15, 18, 10,
     1 13, 16, 19, 22, 18, 21, 27, 28/
      DATA ICC2/55,136,216,282,0/
      DATA ICC1/10,17,22,25,0/
      DATA (CEC(I), I=1, 72)/-.5666687D0, +.1888896D0, +1.416672D0,
     1 -.2557092D0, -.5666687D0, -3.305567D0,
     2 +1.278546D0, +1.416672D0, -.2557092D0, +7.437527D0, -4.474912D0,
     3 -3.305567D0, +.288472D0, +1.278546D0, -16.36256D0, +13.42474D0,
     4 +7.437527D0, -4.474912D0, -2.019304D0, +.2884720D0, +35.45221D0,
     5 -36.91802D0, -16.36256D0, +9.086868D0, +13.42474D0,
     6 -2.019304D0, -.303737D0,
     7  -75.96902D0, +95.98686D0, +35.45221D0, -33.31852D0, -36.91802D0,
     8 +2.733633D0, +9.0868682D0, -.303737D0, +161.4342D0, -239.9672D0,
     9 -75.96902D0, +108.2852D0, +95.98687D0, -15.03498D0, -33.31852D0,
     1 +2.733633D0, +.308388D0, -340.8055D0, +582.7774D0, +161.4342D0,
     2 -324.8555D0, -239.9672D0, +65.15158D0, +108.2852D0,
     3 -15.03498D0, -3.392267D0,
     4 +.308388D0, -4.958351D0, +.6392731D0, +2.833344D0,
     5 +.6392731D0, -.2833344D0, -.1153888D0, +14.87505D0, -4.474912D0,
     6 -9.916702D0, -1.491637D0, +1.278546D0, +1.416672D0, +.576944D0,
     7 -40.9064D0, +20.1371D0, +29.75011D0, +3.356184D0, -1.009652D0/
      DATA (CEC(I), I=73, 156)/  -8.949824D0, -4.958351D0, -2.019304D0,
     1 +.6392731D0, +.130173D0,  +106.3566D0, -73.83605D0, -81.8128D0,
     2 -7.383605D0, +9.086868D0, +40.27421D0, +14.87505D0, +6.057912D0,
     3 -2.019304D0, -4.474912D0, -.9112109D0, -265.8916D0, +239.9672D0,
     4 +212.7133D0, +15.99781D0, -49.97777D0, -147.6721D0, -40.9064D0,
     5 -16.65926D0, +1.366816D0, +18.17374D0, +20.1371D0,  +4.100449D0,
     6 -1.009652D0, -.1370613D0, +645.7367D0, -719.9015D0, -531.7832D0,
     7 -34.28102D0, +216.5704D0, +479.9343D0, +106.3566D0, +43.31407D0,
     8 -15.03498D0, -99.95555D0, -73.83605D0, -15.03498D0, +2.733633D0,
     9 +9.086868D0, +1.233552D0, -1533.625D0, +2039.721D0, +1291.473D0,
     1 +72.84717D0, -812.1388D0, -1439.803D0, -265.8916D0, -108.2852D0,
     2 +97.72737D0, +433.1407D0, +239.9672D0, +48.86369D0, -30.06996D0,
     3 -1.696134D0, -49.97778D0, -6.784535D0, +1.366816D0, +.1391601D0,
     4 -54.54186D0, +44.62516D0, +13.42474D0, +13.42474D0, -4.474912D0,
     5 -9.916702D0, -4.038608D0, -4.474912D0, +.4722239D0, +.576944D0,
     6 +177.261D0,  -73.83605D0, -163.6256D0, -36.91802D0, +40.27421D0,
     7 +44.62516D0, +18.17374D0, +13.42474D0, +3.028956D0, -4.474912D0,
     8 -.9112109D0/
      DATA (CEC(I),I=157,237)/   -3.305567D0, -4.038608D0, -531.7832D0,
     1 +319.9562D0, +531.7832D0, +95.98686D0, -221.5081D0, -163.6256D0,
     2 -66.63703D0, -33.31852D0, -36.918D0,   +9.086868D0, +40.27421D0,
     3 +8.200898D0, +14.87505D0, +18.17374D0, -1.491637D0, -.9112109D0,
     4 +1506.719D0, -1199.836D0, -1595.35D0,  -239.9672D0, +216.5704D0,
     5 +959.8686D0, +531.7832D0, +216.5704D0, +95.98686D0, -99.95555D0,
     6 -221.5081D0, -45.10494D0, -54.54186D0, -66.63703D0, -5.01166D0,
     7 +9.086868D0, +1.233552D0, +13.42474D0, +8.200898D0, -4089.666D0,
     8 +4079.442D0, +4520.157D0, +582.7774D0, -1082.852D0, -3599.507D0,
     9 -1595.35D0,  -649.7111D0, -239.9672D0, +65.15158D0,
     1 +649.7111D0, +959.8686D0, +195.4547D0, +177.261D0,  +216.5704D0,
     2 -15.03498D0, -99.95555D0, -13.56907D0, -73.83605D0,
     3 -45.10494D0, +3.028956D0, +1.233552D0, -664.729D0,  +709.0442D0,
     4 +239.9672D0, +239.9672D0, -147.6721D0, -245.4384D0, -99.9555D0,
     5 -147.6721D0, -8.329629D0, -8.329629D0, +20.13710D0, +4.100449D0,
     6 +29.75011D0, +36.34747D0, +20.1371D0,  +4.100449D0, -1.136289D0,
     7 -2.019304D0, +2260.078D0, -1199.836D0, -2658.916D0, -719.9015D0/
      DATA (CEC(I),I=238,309)/   +959.8686D0, +1063.566D0, +433.1407D0,
     1 +479.9343D0, +108.2852D0, +21.65704D0, -33.31852D0, -221.5081D0,
     2 -45.10494D0, -163.6256D0, -199.9111D0, -73.83605D0, -15.03498D0,
     3 +13.42474D0, +8.200898D0, +10.2266D0,  +18.17374D0, -7156.915D0,
     4 +5099.302D0, +9040.314D0, +2039.721D0, -812.1388D0, -4799.343D0,
     5 -3988.374D0, -1624.278D0, -1439.803D0, -54.14259D0, +433.1407D0,
     6 +1439.803D0, +293.1821D0, +709.0442D0, +866.2814D0, +239.9672D0,
     7 +48.86369D0, +16.2879D0,  -49.97777D0, -6.784535D0, -147.6721D0,
     8 -90.20988D0, -46.0197D0,  -99.95555D0, -6.784535D0, +3.775707D0,
     9 +4.100449D0, -8588.298D0, +11300.39D0, +4079.442D0, +4079.442D0,
     1 -3599.507D0, -5317.832D0, -2165.704D0, -3599.507D0, -324.8555D0,
     2 -324.8555D0, +959.8686D0, +195.4547D0, +1063.566D0, +1299.422D0,
     3 +959.8686D0, +195.4547D0, +108.2852D0, +108.2852D0, -73.83605D0,
     4 -45.10494D0, -87.94875D0, -199.9111D0, -16.28288D0, -73.83605D0,
     5 -45.10494D0, +2.04532D0,  +6.057912D0, +1.480262D0/
      DATA I1C/1,2,1,1,2,1,1,2,2,1,1,2,1,2,1,1,2,2,1,2,1,1,2,1,2,2,1,
     X 1,1,2,1,2,1,2,2,1,1,2,1,2,1,2,2,1,1,1,2,1,2,1,2,2,1,2,
     X 1,1,2,1,3,1,1,1,2,1,2,3,1,1,1,2,1,1,2,3,1,3,1,1,1,2,1,1,2,3,1,2,
     X 3,1,1,1,2,1,1,2,3,1,1,2,3,1,3,1,1,1,2,1,1,2,3,1,1,2,3,1,2,3,1,
     X 1,1,2,1,1,2,3,1,1,2,3,1,2,1,3,1,3,1,1,2,1,1,2,3,1,2,4,2,
     X 1,1,2,1,2,3,1,2,1,3,1,4,2,1,1,2,1,2,3,1,1,2,2,3,1,4,2,4,2,
     X 1,1,2,1,1,2,3,1,2,2,3,1,4,2,1,3,1,4,2,1,1,2,1,1,2,3,1,2,1,
     X 2,3,1,4,2,2,3,1,4,2,4,2,1,2,1,1,2,3,1,2,1,1,3,1,4,2,3,1,5,3,
     X 1,1,2,1,2,3,1,2,1,1,2,3,1,4,2,3,1,4,2,5,3,
     X 1,1,2,1,1,2,3,1,2,1,2,3,1,4,2,3,1,1,3,1,4,2,5,3,1,5,3,
     X 1,2,1,1,2,3,1,2,1,1,3,1,4,2,3,1,2,2,4,2,5,3,1,4,2,6,4,2/
      DATA I1B/2,1,2,2,1,2,2,1,1,2,2,1,2,1,2,2,1,1,2,1,2,2,1,2,1,1,2,
     X 2,2,1,2,1,2,1,1,2,2,1,2,1,2,1,1,2,2,2,1,2,1,2,1,1,2,1,
     X 3,3,2,1,1,1,3,3,2,1,2,1,1,3,3,2,1,1,2,1,1,1,1,
     X 3,3,2,1,3,2,1,1,2,1,1,3,3,2,1,3,2,1,1,3,2,1,1,1,1,
     X 3,3,2,1,3,2,1,1,3,2,1,1,2,1,1,3,3,2,1,3,2,1,1,3,2,1,1,2,3,1,
     X 1,1,1,4,3,2,4,3,2,2,1,1,1,4,4,3,2,3,2,2,1,4,2,2,1,1,
     X 4,4,3,2,3,2,2,4,1,3,2,2,1,1,1,1,4,4,3,2,4,3,2,2,1,
     X 3,2,2,1,1,4,2,2,1,1,4,4,3,2,4,3,2,2,1,4,3,2,2,1,1,
     X 3,2,2,1,1,1,1,5,4,3,5,4,3,3,2,5,1,3,3,2,2,1,1,1,1,
     X 5,5,4,3,4,3,3,2,5,1,4,3,3,2,2,1,1,2,2,1,1,
     X 5,5,4,3,5,4,3,3,2,1,4,3,3,2,2,1,1,5,3,3,2,2,1,1,1,1,1,
     X 6,5,4,6,5,4,4,3,2,6,4,4,3,3,2,2,1,5,3,3,2,2,2,1,1,1,1,1/
      DATA I2B/2,1,3,1,2,4,2,3,1,5,3,4,1,2,6,4,5,3,2,1,
     X 7,5,6,3,4,2,1,8,6,7,4,5,2,3,1,9,7,8,5,6,3,4,2,1,
     X 10,8,9,6,7,4,5,3,2,1,3,1,2,3,1,1,4,2,3,4,1,2,2,
     X 5,3,4,5,3,2,3,3,1,1,6,4,5,6,2,3,4,4,1,2,2,7,5,6,7,3,4,5,5,1,2,3,
     X 3,1,1,8,6,7,8,4,5,6,6,2,3,4,4,1,2,2,
     X 9,7,8,9,5,6,7,7,3,4,5,5,2,1,3,3,1,1,4,3,4,2,1,2,2,3,1,1,
     X 5,3,4,5,2,3,3,4,1,1,1,2,2,6,4,5,6,3,4,4,2,5,1,2,2,3,3,1,1,
     X 7,5,6,7,3,4,5,5,6,2,3,3,4,4,1,1,1,2,2,
     X 8,6,7,8,4,5,6,6,7,2,3,4,4,5,5,1,2,2,3,3,1,1,
     X 5,4,5,3,2,3,3,4,1,5,1,1,2,2,3,3,1,1,6,4,5,6,3,4,4,5,2,6,
     X 1,2,2,3,3,4,4,1,1,2,2,
     X 7,5,6,7,3,4,5,5,6,7,2,3,3,4,4,5,5,1,1,1,2,2,3,3,3,1,1,
     X 6,5,6,4,3,4,4,5,6,2,2,2,3,3,4,4,5,1,1,1,2,2,2,3,3,1,1,1/
      DATA IR/3,2,4,3,3,5,4,4,3,6,5,5,4,4,7,6,6,5,5,4,8,7,7,6,6,5,5,9,
     X 8,8,7,7,6,6,5,10,9,9,8,8,7,7,6,6,11,10,10,9,9,8,8,7,7,6,5,4,4,4,
     X 3,3,6,5,5,5,4,4,4,7,6,6,6,5,5,5,5,4,4,8,7,7,7,6,6,6,6,5,5,5,9,8,
     X 8,8,7,7,7,7,6,6,6,6,5,5,10,9,9,9,8,8,8,8,7,7,7,7,6,6,6,11,10,10,
     X 10,9,9,9,9,8,8,8,8,7,7,7,7,6,6,7,6,6,6,5,5,5,5,4,4,8,7,7,7,6,6,6,
     X 6,6,5,5,5,5,9,8,8,8,7,7,7,7,7,6,6,6,6,6,5,5,10,9,9,9,8,8,8,8,8,
     X 7,7,7,7,7,7,6,6,6,6,11,10,10,10,9,9,9,9,9,8,8,8,8,8,8,7,7,7,7,
     X 7,6,6,9,8,8,8,7,7,7,7,7,7,6,6,6,6,6,6,5,5,10,9,9,9,8,8,8,8,8,8,7,
     X 7,7,7,7,7,7,6,6,6,6,11,10,10,10,9,9,9,9,9,9,8,8,8,8,8,8,8,8,7,7,
     X 7,7,7,7,7,6,6,11,10,10,10,9,9,9,9,9,9,8,8,8,8,8,8,8,8,7,7,7,7,7,
     X 7,7,6,6,6/
      DATA (CEH(I),I=1,95)/       6.995876D0, -1.147655D0, -28.31861D0,
     1  3.156889D0,  6.995876D0,  95.29967D0, -25.55754D0, -28.31861D0,
     2  3.156889D0, -288.1814D0,  129.0119D0,  95.29967D0, -5.766421D0,
     3 -25.55754D0,  812.4296D0, -520.1675D0, -288.1814D0,  129.0119D0,
     4  58.21663D0, -5.766421D0, -2179.45D0,   1833.044D0,  812.4296D0,
     5 -352.0884D0, -520.1675D0,  58.21663D0,  8.756752D0,  5634.129D0,
     6 -5900.862D0, -2179.45D0,   1654.322D0,  1833.044D0, -105.9199D0,
     7 -352.0884D0,  8.756752D0, -14152.79D0,  17796.8D0,   5634.129D0,
     8 -6656.91D0,  -5900.862D0,  746.513D0,   1654.322D0, -105.9199D0,
     9 -11.94909D0,  34746.36D0, -51091.57D0, -14152.79D0,  24092.42D0,
     1  17796.8D0,  -4005.241D0, -6656.91D0,   746.513D0,   168.432D0,
     2 -11.94909D0,  142.9495D0, -12.77877D0, -56.63722D0, -12.77877D0,
     3  3.497939D0,  1.424546D0, -576.3627D0,  129.0119D0,  285.8990D0,
     4  43.00396D0, -25.55754D0, -28.31861D0, -11.53284D0,  2031.074D0,
     5 -780.2512D0, -1152.726D0, -130.0419D0,  29.10832D0,  258.0238D0,
     6  142.9495D0,  58.21663D0, -12.77877D0, -2.602097D0, -6538.352D0,
     7  3666.088D0,  4062.148D0,  366.6088D0, -352.0884D0, -1560.502D0,
     8 -576.3627D0, -234.7256D0,  58.21663D0,  129.0119D0,  26.27025D0,
     9  19719.45D0, -14752.16D0, -13076.7D0,  -983.477D0,   2481.483D0,
     1  7332.177D0,  2031.074D0/
      DATA (CEH(I),I=96,185)/     827.1613D0, -52.95994D0, -704.1769D0,
     1 -780.2511D0, -158.8799D0,  29.10831D0,  3.951484D0, -56611.16D0,
     2  53390.42D0,  39438.9D0,   2542.4D0,   -13313.82D0, -29504.31D0,
     3 -6538.35D0,  -2662.764D0,  746.5129D0,  4962.967D0,  3666.088D0,
     4  746.5129D0, -105.9199D0, -352.0884D0, -47.79637D0,  156358.6D0,
     5 -178820.5D0, -113222.3D0, -6386.447D0,  60231.06D0,  106780.8D0,
     6  19719.45D0,  8030.81D0,  -6007.861D0, -26627.64D0, -14752.16D0,
     7 -3003.931D0,  1493.026D0,  84.21601D0,  2481.484D0,  336.864D0,
     8 -52.95994D0, -5.392028D0,  2708.098D0, -1729.088D0, -520.1676D0,
     9 -520.1676D0,  129.0119D0,  285.899D0,   116.4332D0,  129.0119D0,
     1 -9.439535D0, -11.53284D0, -10897.25D0,  3666.088D0,  8124.296D0,
     2  1833.044D0, -1560.502D0, -1729.088D0, -704.1769D0, -520.1676D0,
     3 -117.3628D0,  129.0119D0,  26.27025D0,  95.29965D0,  116.4332D0,
     4  39438.9D0,  -19669.54D0, -32691.76D0, -5900.862D0,  10998.26D0,
     5  8124.296D0,  3308.644D0,  1654.322D0,  1833.043D0, -352.0884D0,
     6 -1560.502D0, -317.7597D0, -576.3627D0, -704.1769D0,  43.00396D0,
     7  26.27025D0, -132092.7D0,  88984.04D0,  118316.7D0,  17796.81D0,
     8 -13313.82D0, -59008.62D0, -32691.76D0, -13313.82D0, -5900.862D0,
     9  4962.967D0,  10998.26D0/
      DATA (CEH(I),I=186,274)/     2239.539D0,  2708.098D0,  3308.644D0,
     1  248.8376D0, -352.08835D0, -47.79637D0, -520.1676D0, -317.7597D0,
     2  416956.3D0, -357641.D0,   -396278.1D0, -51091.58D0,  80308.1D0,
     3  266952D0,    118316.7D0,   48184.85D0,  17796.81D0, -4005.241D0,
     4 -39941.46D0, -59008.62D0,  -12015.72D0, -10897.25D0, -13313.82D0,
     5  746.5129D0,  4962.967D0,   673.728D0,   36666.088D0, 2239.539D0,
     6 -117.3628D0, -47.79637D0,   49298.63D0, -43589.01D0, -14752.16D0,
     7 -14752.16D0,  7332.177D0,   12186.44D0,  4962.967D0,  7332.177D0,
     8  413.5806D0,  413.5806D0,  -780.2511D0, -158.8799D0, -1152.726D0,
     9 -1408.353D0, -780.2511D0,  -158.8799D0,  32.75926D0,  58.21663D0,
     1 -198139D0,    88984.04D0,   197194.5D0,  53390.42D0, -59008.62D0,
     2 -65383.5D0,  -26627.64D0,  -29504.31D0, -6656.912D0, -1331.382D0,
     3  1654.322D0,  10998.26D0,   2239.539D0,  8124.296D0,  9925.934D0,
     4  3666.089D0,  746.5129D0,  -520.1676D0, -317.7597D0, -396.2495D0,
     5 -704.1769D0,  726973.5D0,  -447051.3D0, -792556.3D0, -178820.5D0,
     6  60231.06D0,  355936.1D0,   295791.8D0,  120462.1D0,  106780.8D0,
     7  4015.404D0, -26627.64D0,  -88512.94D0, -18023.58D0, -43589.01D0,
     8 -53255.28D0, -14752.16D0,  -3003.931D0, -1001.31D0,   2481.483D0,
     9  336.864D0/
      DATA(CEH(I),I=275,309)/     7332.177D0,  4479.078D0,  2284.958D0,
     1  4962.967D0,  336.864D0,
     2 -146.2971D0, -158.8799D0,  875608.2D0, -990695.2D0, -357641D0,
     3 -357641D0,    266952D0,    394389D0,    160616.2D0,  266952D0,
     4  24092.42D0,
     5  24092.42D0, -59008.62D0, -12015.72D0, -65383.5D0,  -79882.92D0,
     6 -59008.62D0, -12015.72D0, -6656.912D0, -6656.912D0,  3666.088D0,
     7  2239.539D0,  4366.808D0,  9925.934D0,  808.4733D0,  3666.088D0,
     8  2239.539D0, -79.2499D0,  -234.7256D0, -57.35563D0/
      DATA CE1/         -1.147655157D0,  3.497938154D0, -.517879389D0,
     1 -9.439535901D0,   3.156889184D0,  23.82491664D0, -12.77877173D0,
     2  .712273122D0,
     3 -57.63628534D0,   43.00397454D0, -5.766420742D0,  135.4049252D0,
     4 -130.0418688D0,
     5  29.10831527D0, -.867365787D0,   -311.3500849D0,  366.6088349D0,
     6-117.3627866D0,
     7  8.756751513D0,   704.2661084D0, -983.4770808D0,  413.5805919D0,
     8 -52.95995748D0,
     9  .987871029D0,  -1572.532317D0,   2542.400651D0, -1331.382098D0,
     1  248.8376562D0,
     2 -11.9490904D0,   3474.635959D0,  -6386.446874D0,  4015.404029D0,
     3 -1001.310287D0,
     4  84.2159942D0,  -1.078405408D0/
      DATA CEF/     -.1888896D0,  .1888896D0, -.1888896D0, -.1888896D0,
     1  .3777791D0,  .1888896D0, -.5666687D0,  .1888896D0, -.1888896D0,
     2  .7555583D0, -.5666687D0,  .1888896D0, -.9444478D0,  1.133337D0,
     3 -.1888896D0, -.1888896D0,  1.133337D0, -1.888896D0,  .7555583D0,
     4  .1888896D0, -1.322227D0,  2.833344D0, -1.888896D0,  .1888896D0,
     5 -.1888896D0,
     6  1.511116D0, -3.966681D0,  3.777791D0, -.9444478D0,  .1888896D0,
     7 -1.700006D0,  5.288908D0, -6.611135D0,  2.833344D0, -.1888896D0,
     8 -.1888896D0,  1.888896D0, -6.800024D0,  10.57782D0, -6.611135D0,
     9  1.133337D0,  .1888896D0, -2.077785D0,  8.500031D0, -15.8667D0,
     1 13.22227D0, -3.966681D0,  .1888896D0, -.1888896D0,  2.266675D0,
     2 -10.38893D0,  22.66675D0, -23.80008D0,  10.57782D0, -1.322227D0,
     3  .1888896D0, -2.455564D0,  12.46671D0, -31.16678D0,  39.66681D0,
     4 -23.80008D0,  5.288908D0, -.1888896D0, -.1888896D0,  2.644454D0,
     5 -14.73339D0,  41.5557D0,  -62.33356D0,  47.60017D0, -15.86672D0,
     6  1.51116D0/
      DATA CET/      -4.659832D0,   4.193802D0,   -4.659832D0,
     1 -2.516253D0,
     2  8.387604D0,   1.132301D0,  -7.548760D0,    4.193802D0,
     3  -.407624D0,
     4  4.529206D0,  -7.54876D0,    .1222858D0,   -2.0381198D0,
     5  6.7938082D0,
     6 -2.5162533D0, -3.144458D-2,  .733715D0,    -4.07624D0,
     7  4.5292055D0,
     8  7.074952D-3, -.22011205D0,  1.8342875D0,  -4.0762397D0,
     9  1.132301D0,
     1 -1.414974D-3,  5.659961D-2, -.6603362D0,    2.4457166D0,
     2 -2.03812D0,
     3  2.546926D-4, -1.2734771D-2, 1.9809864D-1, -1.1005602D0,
     4  1.8342875D0, -4.0762397D-1/
      DATA CER/.1529074D0, -6.880757D-2, 1.529074D-1, 2.064204D-2,
     1 -1.3761514D-1, -4.644408D-3,  6.192613D-2,  -6.880757D-2,
     2  8.359841D-4,  -1.8577631D-2, 6.192612D-2,  -1.253962D-4,
     3  4.179921D-3,  -2.7866447D-2, 2.0642042D-2,  1.612219D-5,
     4 -7.523773D-4,   8.359841D-3, -1.8577631D-2, -1.813726D-6,
     5  1.1285535D-4, -1.8809434D-3, 8.359841D-3,  -4.6444078D-3,
     6  1.813706D-7,  -1.4509812D-5, 3.3856604D-4, -2.5079245D-3,
     7  4.1799205D-3, -1.632318D-8,  1.6323357E-6, -5.078434D-5,
     8  5.6427674D-4, -1.8809434D-3, 8.359841D-4/
      END
