      SUBROUTINE PREPOT(LSTAP,NDIM,JIN,ID,L,JTOT,B,ISJ,EI,EFASY)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C***This subroutine is for use with RMPROP: Version 2.1.2.
C***PREPOT is called once before the first call to POT.
C***PREPOT is called by PROGRAM RMPROP.
C***
C***ON INPUT:
C***
C***LSTAP is a logical variable used by RMPROP.
C***NDIM is the number of channels.
C***ID is the first dimension of JIN and L.
C***L(I) is the orbital angular momentum in channel I.
C***JTOT is the total angular momentum.
C***
C***ON OUTPUT:
C***
C***JIN(I,1) is the internal angular momentum in channel I.
C***B is an array for use by pot.
C***
C***     Calculate matrix elements over vib. wave functions and
C*** eigen functions of J,L,JTOT and MTOT.
C***     The user must supply 1 subroutine and 1 function: FUN1 and EIGEN.
C***
C***     FUN1 has arguments R, R1, CCHI, V, NPTS.
C***
C***R is the center of mass of diatom - atom distance.
C***R1 is the diatom bond length.
C***CCHI is an array of cosines of the angle between SR and RVIB.
C***V is an output array of the interaction potential.
C***NPTS is the number of angles (cchi) at which to calculate the potential.
C***EIGEN has the arguments IV and J (the vibrational and rotational
C***quantum numbers), and should calculate the channel eigenenergies.
C***
C***      Data read in from various subroutines from FORTRAN UNIT 4:
C***
C***RE (E15.8 PREPOT): equiblibrium bond length of diatom
C***
C***NUMQ (I5 PREPOT): number of different orders of quadrature to
C***be used during the propagation.
C***
C***NQUAD (10I5 PREPOT): number of orders of the vibrational quadrature to
C***be used during the propagation.
C***
C***NQUADA (10I5 PREPOT): number of orders of the rotational quadrature to
C***be used during the propagation.
C***
C***RQUAD (9E15.8 PREPOT): values of SR at which one or both of the orders
C***of quadrature are to be changed during the propagation.
C***
C***LSTAP (L1 PREPOT): logical input variable determining whether RMPROP
C***will look for more than one potential approximation.
C***
C***NLINE (I5 PREPOT): input variable telling how many lines of character
C***data are to follow; this character data is written to FORTRAN UNIT 6
C***to help the user keep track of the individual run.
C***
C***MES (80A8 PREPOT): character data written to FORTRAN unit 6 to help
C***the user keep track of the individual run.
C***
C***IS (10I5 POT): input data array containing vibrational quantum numbers
C***for each channel of the input basis set.
C***
C***JIN (10I5 POT): input data array containing internal angular momentum
C***quantum numbers for each channel of the input basis set.
C***
C***IHOM,IVIB,IEIGN (3I5 POT): 
C***
C***IHOM is homonuclear/heteronuclear switch for diatom: IHOM = 0 for
C***homonuclear and IHOM = 1 for heteronuclear.
C***
C***IVIBJ = 0 means use J dependant vibrational states, IVIBJ .ne. 0 means
C***use J independent vibrational states.
C***
C***IEIGN = 0 means call EIGEN to get channel eigenenergies, IEIGN .ne. 0
C***means get them from WDATA.
C***
C***NUMT (I5 ANGINT AND POT): number of terms in the expansion of
C***the potential matrix in Legendre polynomials.
C***
C***    ADDITIONAL SUBROUTINES REQUIRED:
C***
C***FLAMB  : calculates Percival-Seaton coefficients.
C***GAUSSQ : calculates Gauss-Legendre weights and nodes (to determine
C***         the expansion coefficients of the potential in Legendre
C***         polynomials).
C***WDATA  : gets vibrational weights and nodes to calculate vibrational
C***         contribution to potential matrix elements.
C***
C***PREPOT must be called once before the first call to POT.
C***
C***
C***    MINIMUM DIMENSIONS:
C***
C*** XNODE(NQVMAX)                                                      6M2R94
C*** WEIGHT(NQVMAX,MAXJJ,MAXJJ,MXV2)                                    6M2R94
C*** IMU(NUMBT)
C*** VLAM(NQVMAX,NUMBT)
C*** Y(NQAMAX,NUMBT+2)
C*** TEMP(NUMBT)
C***
C***NQAMAX order of angular quadrature.
C***NQVMAX order of vibrational quadrature.
C***NUMBT number of (independent) terms in the potential expansion.
C***MAXV maximum vibrational quantum number + 1.
C***MAXJ maximum internal angular momemtum + 1.
C***MXV2 MAXV*(MAXV+1)/2.
C***
      INCLUDE 'parameter.inc'
      INCLUDE 'expand.inc'
      PARAMETER(MXV2=MAXV*(MAXV+1)/2)                                   6M2R94
      COMMON/VCCM/Y(NQAMAX,NUMBT+2)
      COMMON/PTIMCM/PTIME(10)
      COMMON/PRE1CM/RE,JTOTAL,NUMQ,NQUAD(10),NQUADA(10),RQUAD(10),MDIM
      COMMON/PRE2CM/XNODE(NQVMAX),WEIGHT(NQVMAX,MAXJJ,MAXJJ,MXV2),
     1ISJJ(IDX),JINN(IDX),MAXQN,NUMQSF,NUMT,
     1ISTM,IHOM,NV
      COMMON/LOGCM/LVIBJ
C***the lines below added by mju4-27-93
      COMMON/JHOMCM/IHOMM,JHOM
      COMMON/RECM/REE
C***the lines added by mju4-27-93 end here
      DIMENSION ISJ(IDX,NVIBX),EFASY(IDX,IDX),B(IDX*IDX*NVIB1X)
      DIMENSION EI(IDX),JIN(IDX,NANX),L(IDX),
     & EIGN(MAXV,MAXJJ)
      DIMENSION IMU(NUMBT)
      DIMENSION MES(10)
      DOUBLE PRECISION MES
      LOGICAL LVIBJ
      LOGICAL LSTAP
      DATA ONE/1.0D+0/HALF/0.5D+0/FOUR/4.0D+0/
      DATA IFS/-1/ZERO/0.0D+0/
      JTOTAL=JTOT

C***RE is the equilibrium displacement of the oscillators.

      READ(4,5)RE
C***line below added by mju4-28-93
      REE=RE
C***new lines end here mju4-28-93

C***NUMQ is the number of different orders of quadrature or different
C***potential expansions we will use.

      READ(4,25)NUMQ
      RQUAD(1)=ZERO

C***NQUAD(I) is the number of points used in the vib. quadrature for R
C***less than RQUAD(I), and NQUADA(I) is the number of points used
C***in the angular quadrature. RQUAD(I) is not needed if NUMQ is one.

      READ(4,25)(NQUAD(I),I=1,NUMQ)
      READ(4,25)(NQUADA(I),I=1,NUMQ)
      IF(NUMQ.GT.1)READ(4,5)(RQUAD(I),I=1,NUMQ-1)

C***LSTAP is FALSE if RMPROP will call PREPOT to define the next potential.

      READ(4,26)LSTAP
      MDIM=IDX*IDX*NVIB1X

C***Possibly read some text and write it to the output.
C***NLINE is the number of lines of text.

      READ(4,25)NLINE
      IF(NLINE.EQ.0)RETURN
      DO 3 I=1,NLINE
         READ(4,66)MES
    3 WRITE(6,44)MES
   66 FORMAT(80A8)
   44 FORMAT(1X,80A8)
      ICALL=0
      DO 65 I=1,10
   65    PTIME(I)=ZERO

C***Do things which need be done only once.

      NUMQSF=1
      NUMQM1=NUMQ-1
      SRH=SQRT(HALF)

C***Read in vibrational channels.

      READ(4,55)(ISJ(IJ,1),IJ=1,NDIM)

C***Read in rotational channels.

      READ(4,55)(JIN(IJ,1),IJ=1,NDIM)

C***Read in homo-heteronuclear switch. IHOM=0 for HOMO, 1 for hetero.
C***IVIBJ ZERO means use j-dependent vib states, non zero use j-indep.
C***vib states.
C***LVIBJ = .TRUE.  means IVIBJ zero (j-dependent vibrational states).
C***LVIBJ = .FALSE. means IVIBJ non-zero (j-independent vibrational states).
C***IEIGN 0 means call EIGEN to get channel eigenenergies, non zero
C***means get them from WDATA.

      READ(4,55)IHOM,IVIBJ,IEIGN
C***Line below added by mju4-28-93
      IHOMM=IHOM
C**new lines end here mju4-28-93
      LVIBJ=IVIBJ.EQ.0
      IHDIV=2
      IF(IHOM.EQ.1)IHDIV=1
      IF(IHOM.EQ.0)IHOM=2
      IF(IHOM.NE.1.AND.IHOM.NE.2)
     1 STOP 'IHOM must be 1 or 2 in SUBROUTINE PREPOT in prevgr2.f'

C***Create channel index for weights.
C***The (I) of INDEX(I) corresponds to the element I in
C***a conventional symmetric matrix.  The value stored in this position
C***is what the index would be in a packed matrix.  Note that since
C***the matrix is symmetric (with respect to a plane from upper left
C***to lower right) some of the values in index occur in more than one
C***of the (I). For example INDEX(2)=INDEX(MAXQN+1).

      MAXQN=0
      MJ=0
      MJMIN=JIN(1,1)
      DO 31 I=1,NDIM
      MJ=MAX0(JIN(I,1),MJ)
      MJMIN=MIN0(JIN(I,1),MJMIN)
   31 MAXQN=MAX0(ISJ(I,1),MAXQN)
      MAXQN=MAXQN+1
      MJ=MJ+1
      IF(IHOM.EQ.1)GOTO 881
      MJ=(MJ-1-MJMIN)/2+1
  881 ICHANN=MAXQN*(MAXQN+1)/2                                          6M2R94


      IF(ICHANN.GE.MXV2)                                                6M2R94
     & STOP 'Channel indices in SUBROUTINE PREPOT in prevgr2.f'         6M2R94

C***Get weights and nodes.

      NQUADV=NQUAD(NUMQSF)
      RQ=RQUAD(NUMQSF)
      IF(IVIBJ.NE.0)MJ=1
      IF(MJ.GT.MAXJJ.OR.MAXQN.GT.MAXV) THEN
         WRITE(6,998) MAXJJ,MJ,MAXV,MAXQN
998   FORMAT(1X,'MAXJJ= ',I4,' BUT MUST BE GREATER THAN ',I4,' OR',/,
     &  1X,'MAXV= ',I4,' BUT MUST BE GREATER THAN ',I4,'.')
      STOP 'Dimensions for weights in SUBROUTINE PREPOT in prevgr2.f'
      ENDIF
      CALL WEIGH
      REWIND(UNIT=1)
      NV=MAXQN                                                          6M2R94
      CALL WDATA(EIGN,XNODE,WEIGHT,NQUADV,MJ,NV,MAXV,NQVMAX,MAXJJ,1)    6M2R94

      DO 64 I1=1,NQUADV
   64    XNODE(I1)=XNODE(I1)+RE

C***Write things.
 
   55 FORMAT(10I5)
      NQADAG=NQUADA(NUMQSF)
      ISTART=1
      WRITE(6,15)RE,NQUADV,NQADAG
   15 FORMAT(/1X,4HRE =,1PE15.8/1X,13HInitially use,I4,40H point quadrat
     +ure for vib. integrals and,I5,39H point quadrature for angular int
     +egrals)

      WRITE(6,444)(I,ISJ(I,1),JIN(I,1),L(I),I=1,NDIM)
  444 FORMAT(/1X,37HChannel labels in the order (#,N,J,L)/(
     11X,8(1H(,I3,3(1H,,I3),1H),:1H,)))
      IF(IVIBJ.EQ.0)WRITE(6,1)
    1 FORMAT(/1X,76HThe matrix elements over vibrational eigenfunctions
     +include vib-rot coupling )
      IF(IVIBJ.NE.0)WRITE(6,2)
    2 FORMAT(/1X,83HThe matrix elements over vibrational eigenfunctions
     +do not include vib-rot coupling )

C***Calculate channel eigen energies.

      IF(IEIGN.EQ.0)THEN                                                8M8R93

         WRITE(6,9910)
9910     FORMAT(/1X,'Calling function eigen to get channel ',           8M9R93
     &    'eigenenergies')                                              8M9R93

         DO 36 I=1,NDIM
36       EI(I)=EIGEN(ISJ(I,1),JIN(I,1))
      ELSE                                                              8M8R93

         DO 884 I=1,NDIM
            I1=ISJ(I,1)+1
            I2=(JIN(I,1)/IHOM)+1
            EI(I)=EIGN(I1,I2)                                           8M9R93
884      CONTINUE                                                       8M9R93
         WRITE(6,9911)
9911     FORMAT(/1X,'Getting eigenenergies from WDATA')                 8M9R93

         WRITE(6,511)(EI(I),I=1,NDIM)
      ENDIF                                                             8M8R93
      CONTINUE
511   FORMAT(1X,1P,10E12.5)

C***Order channels by energy.

    4 CONTINUE
      ISWIT=0
      DO 555 I=2,NDIM
      IM1=I-1
      IF(EI(I).GE.EI(IM1))GOTO 555
      ISWIT=ISWIT+1
      ETM=EI(IM1)
      EI(IM1)=EI(I)
      EI(I)=ETM
      DO 6 J=1,NVIBX
      ITM=ISJ(IM1,J)
      ISJ(IM1,J)=ISJ(I,J)
    6 ISJ(I,J)=ITM
      DO 7 J=1,NANX
      ITM=JIN(IM1,J)
      JIN(IM1,J)=JIN(I,J)
    7 JIN(I,J)=ITM
      ITM=L(IM1)
      L(IM1)=L(I)
      L(I)=ITM
  555 CONTINUE
      IF(ISWIT.NE.0)GOTO 4

C***Write out reordered channels.

      WRITE(6,8)
    8 FORMAT(1X,28HChannels reordered by energy)
      WRITE(6,444)(I,ISJ(I,1),JIN(I,1),L(I),I=1,NDIM)

C***Copy vibrational and rotational channels into COMMON.

      DO 8885 J=1,IDX
           ISJJ(J)=ISJ(J,1)
           JINN(J)=JIN(J,1)
 8885 CONTINUE

C***Get potential expansion and calculate angular integrals.

      CALL ANGINT(IHOM,JIN,L,NDIM,NUMT,IMU,B,MDIM,ID,ISJ,JTOT,ISTM,
     1NUMBT)                                                            8M9R93

C***Calculate quantites needed for projection of potential expansion
C***coefficients.

      CALL EXPGET(Y,NQAMAX,NUMBT+2,NQADAG,IHOM,NUMT)                    8M9R93

C***Set asymptotic basis set.

      DO 37 I=1,NDIM
         DO 38 J=1,NDIM
   38    EFASY(J,I)=ZERO
   37 EFASY(I,I)=ONE
    5 FORMAT(9E15.8)
   25 FORMAT(10I5)
   26 FORMAT(L1)
      RETURN
      END
