      SUBROUTINE PREPOT(LSTAP,NDIM,JIN,ID,L,JTOT,B,IS,EI,EFASY)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
      LOGICAL LSTAP,LVIBJ
      CHARACTER*80 MES                                                  7M28R93
      INCLUDE 'parameter.inc'
      INCLUDE 'expand.inc'
C***
C***  This subroutine is used with RMPROP: Version 2.1.2.
C***  PREPOT is called by PROGRAM RMPROP.
C***  It calculates matrix elements over vibrational wave functions and
C***  eigenfunctions of J, L, JTOT and MTOT.  (It can also handle rigid rotors.)
C***
C***   Input Parameters:
C***
C***ON INPUT:
C***
C***LSTAP is a logical variable used by RMPROP.
C***NDIM is the number of channels.
C***ID is the first dimension of JIN and L.
C***L(I) is the orbital angular momentum in channel I.
C***JTOT is the total angular momentum.
C***
C***ON OUTPUT:
C***
C***JIN(I,1) is the internal angular momentum in channel I.
C***B is an array for use by pot.
C***
C***     The user must supply 1 subroutine and 1 function: FUN1 and EIGEN.
C***
C***     FUN1 has arguments R, R1, R2, C1, S1, C2, S2, CP, SP, V, NPTS.
C***
C***R is the center of mass of diatom - diatom distance.
C***R1 is the bond length of diatom 1.
C***R2 is the bond length of diatom 2.
C***C1 is the cosine of THETA1.
C***S1 is the sine of THETA1.
C***C2 is the cosine of THETA2.
C***S2 is the sine of THETA2.
C***CP is the cosine of (PHI2-PHI1).
C***SP is the sine of (PHI2-PHI1).
C***V is an output array of the interaction potential.
C***NPTS is the number of angles at which to calculate the potential.
C***
C***EIGEN has the arguments IV and J (the vibrational and rotational
C***quantum numbers), and should calculate the channel eigenenergies.
C***
C***      Data read in from various subroutines from FORTRAN UNIT 4:
C***
C***RE (E15.8 PREPOT): equiblibrium bond length of diatom
C***
C***NUMQ (I5 PREPOT): number of different orders of quadrature to
C***be used during the propagation.
C***
C***NQUAD (10I5 PREPOT): number of orders of the vibrational quadrature to
C***be used during the propagation.
C***
C***NQUADA (10I5 PREPOT): number of orders of the rotational quadrature to
C***be used during the propagation.
C***
C***RQUAD (9E15.8 PREPOT): values of SR at which one or both of the orders
C***of quadrature are to be changed during the propagation.
C***
C***LSTAP (L1 PREPOT): logical input variable determining whether RMPROP
C***will look for more than one potential approximation.
C***
C***NLINE (I5 PREPOT): input variable telling how many lines of character
C***data are to follow; this character data is written to FORTRAN UNIT 6
C***to help the user keep track of the individual run.
C***
C***MES (80A8 PREPOT): character data written to FORTRAN unit 6 to help
C***the user keep track of the individual run.
C***
C***IS(I,1) (10I5 POT): input data array containing vibrational quantum numbers
C***for the first monomer for each channel of the input basis set.
C***
C***IS(I,1) (10I5 POT): input data array containing vibrational quantum numbers
C***for the second monomer for each channel of the input basis set.
C***
C***JIN(I,1) (10I5 POT): input data array containing internal angular momentum
C***quantum numbers for the first monomer for each channel of the input basis 
C***set.
C***
C***JIN(I,2) (10I5 POT): input data array containing internal angular momentum
C***quantum numbers for the second monomer for each channel of the input basis 
C***set.
C***
C***JIN(I,1) (10I5 POT): input data array containing the sum of the angular
C***momentum quantum numbers for the  for each channel of the input basis set.
C***
C***IETA is the exchange operator with eigenvalue (-1)**IETA.
C***
C***IVIBJ = 0 means use j-dependent vibrational states, non-zero means use
C***j-independent vibrational states.
C***
C**ISYMU = 0 means use exchange symmetry, non-zero means don't use it.
C***
C***ICALC = 0 means calculate angular integrals, write them to FORTRAN unit 2
C***and continue. ICALC = 1 means calculate angular integrals, write them to
C***FORTRAN unit 2 and stop.  ICALC = 2 means read angular integrals and
C***continue.
C***
C***NUMT (I5 ANGINT AND POT): number of terms in the expansion of
C***the potential matrix in Launay polynomials.
C***
C***    ADDITIONAL SUBROUTINES REQUIRED:
C***
C***FCOEF/FCOEF5  : calculates angular integrals for Launay functions
C***                for zero or non-zero total angular momentum.
C***GAUSSQ : calculates Gauss-Legendre weights and nodes (to determine
C***         the expansion coefficients of the potential in Launay 
C***         polynomials).
C***WDATA  : gets vibrational weights and nodes to calculate vibrational
C***         contribution to potential matrix elements.
C***
C***PREPOT must be called once before the first call to POT.
C***
C***    MINIMUM DIMENSIONS:
C*** INDEX(NBARR)
C*** IQ1(NUMBT)
C*** IQ2(NUMBT)
C*** IMU(NUMBT)
C*** XNODE(NQVMAX)
C*** WV1(NQVMAX**2)
C*** WV2(NQVMAX**2)
C*** IW1(NQVMAX**2)
C*** IW2(NQVMAX**2)
C*** WEIGHT(NQVMAX,MAXJJ,MAXJJ,NBARR)
C*** VLAM(NQVMAX**2,NUMBT)
C*** UA(NQAMAX)
C*** SA(NQAMAX)
C*** UB(NQAMAX)
C*** SB(NQAMAX)
C*** TEMP(NUMBT)
C***
C***NQAMAX maximum value of order of angular quadrature.
C***NQVMAX maximum value of order of vibrational quadrature.
C***NUMBT maximum number of terms in the potential expansion.
C***MAXV maximum vibrational quantum number + 1.
C***MAXJJ maximum internal angular momemtum quantum number + 1.
C***MXV2 = MAXV*(MAXV+1)/2.                                             6M3R94
      PARAMETER(MXV2=MAXV*(MAXV+1)/2)                                   6M3R94
      COMMON/PRE2CM/INDEX(MXV2),ISJ(IDX,2),JINJ(IDX,3),LJ(IDX),         6M3R94
     1IQ1(NUMBT),IQ2(NUMBT),IMU(NUMBT)
      COMMON/PRE3CM/EIJ(IDX),RQ,XNODE(NQVMAX),
     1              WEIGHT(NQVMAX,MAXJJ,MAXJJ,MXV2),WV1(NQVMAX**2),     6M3R94
     1              WV2(NQVMAX**2)
      COMMON/PRE4CM/NUMQSF,IETA,ISTM,IVIBJ,ISYMU,ICALC,ICALL,MJ,MAXQN,
     1              NUMT,NQADAG,NQUADV,NSQ,IW1(NQVMAX**2),
     2              IW2(NQVMAX**2)
      COMMON/TEMPCM/TEMPAR(IDX,IDX)
C***the lines below added by mju4-27-93
      COMMON/JHOMCM/IHOM,JHOM
      COMMON/RECM/REE
c***the lines added by mju4-27-93 end here
      DIMENSION B(IDX*IDX*NVIB1X),EI(IDX),IS(IDX,NVIBX),JIN(IDX,NANX),
     1          L(IDX)   
      DIMENSION UA(NQAMAX),SA(NQAMAX),UB(NQAMAX),SB(NQAMAX)
      DIMENSION EFASY(IDX,IDX)

C====MEANINGS OF ARRAYS:
C***
C***XNODE contains nodes for quadratures of potential over
C***vibrational basis functions.
C***
C***WEIGHT contains weights for quadratures of potential over
C***vibrational basis functions.
C***
C***INDEX is an integer array which contains the location of the I-J 
C***element of an array if stored in packed form, columnwise.
C***INDEX is used to locate weights for vibrational quadratures.
C***
C***IQ1 is an integer array containing the first index of the Launay functions
C***in which the interaction potential is expanded.
C***
C***IQ2 is an integer array containing the second index of the Launay functions
C***in which the interaction potential is expanded.
C***
C***IMU integer array containing the third index of the Launay functions
C***in which the interaction potential is expanded.
C***
C***VLAM is an array containing the expansion coefficients of the interaction
C***potential in Launay functions for all points in the vibrational
C***quadrature of each collision partner and for each of the Launay
C***functions in which the interaction potential is expanded.
C***
C***Y is an array containing the properly normalized Launay functions for
C***the expansion of the interaction potential at each of the angular
C***quadrature points (for the angles THETA1, THETA2, PHI, explained
C***below) and for each of the Launay functions in the expansion of the
C***interaction potential.
C***
C***Note that the last seven columns of the array Y are used to store the
C***nodes of the angular quadrature and the value of the interaction 
C***potential at each point for the vibrational quadrature and the nodes
C***of the angular quadrature.
C***
C***Note also THETA1 is the angle between the bond axis of
C***the first monomer and the center-of-mass separation vector;
C***THETA2 is the angle between the bond axis of the second monomer
C***and the center-of-mass separation vector;
C***and PHI is the azimuthal angle, i. e. the angle between the planes
C***defined by THETA1 (monomer 1 and c. m. separation vector) and THETA2
C***(monomer 2 and c. m. separation vector).
C***
C***UA is an array containing the cosine of THETA1 for each point of angular
C***quadrature.
C***
C***SA is an array containing the sine of THETA1 for each point of angular
C***quadrature.
C***
C***UB is an array containing the cosine of THETA2 for each point of angular
C***quadrature.
C***
C***SB is an array containing sine of THETA2 for each point of angular
C***quadrature.
C***
C***TEMP is an array used in calculation of elements of VLAM.
C***

      COMMON/VCCM/Y(NQAMAX**3,NUMBT+25)
      COMMON/PRPTCM/JTOTAL,NUMQ,NQUAD(10),NQUADA(10),RQUAD(10),RE
      COMMON/PTIMCM/PTIME(10)
      COMMON/LOGCM/LVIBJ
      DATA ONE/1.0D+0/HALF/0.5D+0/FOUR/4.0D+0/
      DATA IFS/-1/ZERO/0.0D+0/

      JTOTAL=JTOT

C***RE is the equilibrium displacement of the oscillators.

      READ(4,5)RE
      REE=RE

C***NUMQ is the number of different orders of quadrature or different
C***potential expansions we will use.

      READ(4,25)NUMQ
      RQUAD(1)=ZERO

C***NQUAD(I) is the number of points used in the vibrational quadrature for R
C***less than RQUAD(I), and NQUADA(I) is the number of points used
C***in the angular quadrature. RQUAD(I) is not needed if NUMQ is one.

      READ(4,25)(NQUAD(I),I=1,NUMQ)
      READ(4,25)(NQUADA(I),I=1,NUMQ)
      IF(NUMQ.GT.1)READ(4,5)(RQUAD(I),I=1,NUMQ-1)
      WRITE(6,25)(NQUAD(I),I=1,NUMQ)
      WRITE(6,25)(NQUADA(I),I=1,NUMQ)
      WRITE(6,5)(RQUAD(I),I=1,NUMQ-1)
      RQUAD(NUMQ)=ZERO

C***LSTAP is FALSE if RMPROP will call PREPOT to define the next potential.

      READ(4,26)LSTAP

C***Possibly read some text and write it to the output.

      READ(4,25)NLINE
      IF(NLINE.GT.0)THEN                                                7M28R93
         DO 3 I=1,NLINE                                                 7M28R93
            READ(4,67)MES                                               7M28R93
3        WRITE(6,66)MES                                                 7M28R93
67       FORMAT(A80)                                                    7M28R93
66       FORMAT(1X,A80)                                                 7M28R93
      ENDIF                                                             7M28R93

      DO 65 I=1,10
   65 PTIME(I)=ZERO

C***Do things which need be done only once.

      ICALL=1
      IBMX=IDX*IDX*NVIB1X
      NUMQSF=1
      SRH=SQRT(HALF)
      RQ=RQUAD(NUMQSF)
      NQUADV=NQUAD(NUMQSF)

C***Read in vibrational channels.

      READ(4,55)(IS(IJ,1),IJ=1,NDIM)
      WRITE(6,55)(IS(IJ,1),IJ=1,NDIM)
      READ(4,55)(IS(IJ,2),IJ=1,NDIM)
      WRITE(6,55)(IS(IJ,2),IJ=1,NDIM)

C***Read in rotational channels.

      READ(4,55)(JIN(IJ,1),IJ=1,NDIM)
      WRITE(6,55)(JIN(IJ,1),IJ=1,NDIM)
      READ(4,55)(JIN(IJ,2),IJ=1,NDIM)
      WRITE(6,55)(JIN(IJ,2),IJ=1,NDIM)
      READ(4,55)(JIN(IJ,3),IJ=1,NDIM)
      WRITE(6,55)(JIN(IJ,3),IJ=1,NDIM)
      JHOM=JIN(1,1)


C***Read in exchange parity.  Eigenvalue is (-1)**IETA.
C***If IETA positive, diatoms considered heteronuclear.
C***If IETA negative, diatoms considered homonuclear.
C***IVIBJ zero means use j-dependent vibrational states, non-zero use
C***j-independent vibrational states.
C***LVIBJ = .TRUE.  means IVIBJ zero (j-dependent vibrational states).
C***LVIBJ = .FALSE. means IVIBJ non-zero (j-independent vibrational states).
C***ISYMU zero means use exchange symmetry, non zero means don't use it.
C***ICALC 0 means calculate angular integrals, write them to FORTRAN unit 2 and
C***continue. ICALC 1 means calculate angular integrals, write them to FORTRAN
C***unit 2 and stop. ICALC 2 means read angular integrals and continue.

      READ(4,55)IETA,IVIBJ,ISYMU,ICALC
      WRITE(6,55)IETA,IVIBJ,ISYMU,ICALC
      LVIBJ=IVIBJ.EQ.0
      IF(IETA.LT.0) THEN                                                6M8R94
        IHOM=2                                                          6M8R94
        IETA=-IETA                                                      6M8R94
        WRITE(6,910)                                                    6M8R94
      ELSE                                                              6M8R94
        IHOM=1                                                          6M8R94
        WRITE(6,911)                                                    6M8R94
      ENDIF                                                             6M8R94
910   FORMAT(1X,'IHOM is 2, so diatoms are homonuclear.')               6M8R94
911   FORMAT(1X,'IHOM is 1, so diatoms are heteronuclear.')             6M8R94
C***Create channel index for weights.

      MAXQN=0
      MJ=0
      DO 31 I=1,NDIM
      MJ=MAX0(JIN(I,1),JIN(I,2),MJ)
   31 MAXQN=MAX0(IS(I,1),IS(I,2),MAXQN)
      MAXQN=MAXQN+1
      MJ=MJ+1
      ICHANN=1
      DO 30 I=1,MAXQN
      IM=I-1
      I1=I
      I2=MAXQN*IM+1
      DO 30 J=1,I
      JM=J-1
      J1=MAXQN*JM+I1
      J2=JM+I2
      INDEX(J1)=ICHANN
      INDEX(J2)=ICHANN
      IF(ICHANN.GE.50)STOP 'Channel Index ordering in prevgr3.f'
   30 ICHANN=ICHANN+1


C***Write things.

   55 FORMAT(10I5)

      NQADAG=NQUADA(NUMQSF)
      ISTART=1
      WRITE(6,15)RE,NQUADV,NQADAG
   15 FORMAT(/1X,4HRE =,1PE15.8/1X,13HInitially use,I4,40H point quadrat
     +ure for vib. integrals and,I5,39H point quadrature for angular int 
     +egrals)
      IPOS=1
      DO 64 I1=1,NQUADV
      DO 64 I2=1,NQUADV
      IW1(IPOS)=I1
      IW2(IPOS)=I2
   64 IPOS=IPOS+1
      NSQ=IPOS-1

      IF(ISYMU.EQ.0.AND.MOD(IETA,2).EQ.0)WRITE(6,75)
   75 FORMAT(/1X,114HThe channels are even eigenstates of exchange parit
     +y, and so if N1 & N2 and J1 & J2 are reversed, nothing changes.)
      IF(ISYMU.EQ.0.AND.MOD(IETA,2).NE.0)WRITE(6,76)
   76 FORMAT(/1X,119HThe channels are odd eigenstates of exchange parity
     +, and so if N1 & N2 and J1 & J2 are reversed, only the sign change
     +s.)
      WRITE(6,44)(I,IS(I,1),IS(I,2),JIN(I,1),JIN(I,2),JIN(I,3),L(I),
     +I=1,NDIM)
   44 FORMAT(/1X,49HChannel labels in the order (#,N1,N2,J1,J2,J12,L)/(
     11X,5(1H(,I3,6(1H,,I3),1H),:1H,)))
      IF(IVIBJ.EQ.0)WRITE(6,1)
    1 FORMAT(/1X,76HThe matrix elements over vibrational eigenfunctions
     +include vib-rot coupling )
      IF(IVIBJ.NE.0)WRITE(6,2)
    2 FORMAT(/1X,83HThe matrix elements over vibrational eigenfunctions
     +do not include vib-rot coupling )

C***Calculate channel eigenenergies.

      DO 36 I=1,NDIM
   36 EI(I)=EIGEN(IS(I,1),JIN(I,1))+EIGEN(IS(I,2),JIN(I,2))
C***Order channels by energy.

  114 CONTINUE
      ISWIT=0
      DO 115 I=2,NDIM
      IM1=I-1
      IF(EI(I).GE.EI(IM1))GOTO 115
      ISWIT=ISWIT+1
      ETM=EI(IM1)
      EI(IM1)=EI(I)
      EI(I)=ETM
      DO 116 J=1,NVIBX
      ITM=IS(IM1,J)
      IS(IM1,J)=IS(I,J)
  116 IS(I,J)=ITM
      DO 117 J=1,NANX
      ITM=JIN(IM1,J)
      JIN(IM1,J)=JIN(I,J)
  117 JIN(I,J)=ITM
      ITM=L(IM1)
      L(IM1)=L(I)
      L(I)=ITM
  115 CONTINUE
      IF(ISWIT.NE.0)GOTO 114

C***Copy re-ordered arrays into new arrays for common blocks.

      DO 551 IJ=1,NDIM
        ISJ(IJ,1)=IS(IJ,1)
        ISJ(IJ,2)=IS(IJ,2)
        JINJ(IJ,1)=JIN(IJ,1)
        JINJ(IJ,2)=JIN(IJ,2)
        JINJ(IJ,3)=JIN(IJ,3)
        EIJ(IJ)=EI(IJ)
        LJ(IJ)=L(IJ)
 551  CONTINUE

C***Write out reordered channels.

      WRITE(6,8)
    8 FORMAT(1X,28HChannels reordered by energy)
      WRITE(6,44)(I,IS(I,1),IS(I,2),JIN(I,1),JIN(I,2),JIN(I,3),L(I),
     +I=1,NDIM)

C***Get potential expansion and calculate angular integrals.

      CALL SECOND(TIME1)
      CALL ANGINT(IETA,JIN,L,NDIM,NUMT,IQ1,IQ2,IMU,B,IBMX,ID,NNUMT
     +,IS,ISYMU,JTOT,ISTM,ICALC)
      CALL SECOND(TIME2)
      PTIME(1)=PTIME(1)+TIME2-TIME1

C***Get weights and nodes.

      NQUADV=NQUAD(NUMQSF)
      RQ=RQUAD(NUMQSF)
      CALL SECOND(TIME1)
      IF(IVIBJ.NE.0)MJ=1
      IF(MJ.GT.15.OR.MAXQN*(MAXQN+1)/2.GT.20)
     1 STOP 'Dimensions on weights in prevgr3.f'
      CALL WEIGH
      REWIND(UNIT=1)
      NWD1=IDX                                                          4M12R94
      NWD2=NQVMAX                                                       4M12R94
      NWD3=MAXJJ                                                        4M12R94
      CALL WDATA(TEMPAR,XNODE,WEIGHT,NQUADV,MJ,MAXQN,NWD1,NWD2,NWD3,1)  4M12R94

      CALL SECOND(TIME2)
      PTIME(3)=TIME2-TIME1

C***Diagnostic write out.
C     PRINT*,'WEIGHTS'
C     DO 8001 I=1,MAXQN*(MAXQN+1)/2
C     DO 8001 I1=1,MJ
C     DO 8001 I2=1,MJ
C8001 WRITE(6,8002)(WEIGHT(I3,I2,I1,I),I3=1,NQUAD(NUMQSF))
C8002 FORMAT(1X,1P10E12.5)

C***Calculate quantities needed for projection of potential expansion
C***coefficients.

      CALL SECOND(TIME1)
      CALL EXPGET(Y,UA,SA,UB,SB,NQADAG,IQ1,IQ2,IMU,NUMT)

      CALL SECOND(TIME2)
      PTIME(2)=PTIME(2)+TIME2-TIME1

C***Set asymptotic basis set.

      DO 37 I=1,NDIM
      DO 38 J=1,NDIM
   38 EFASY(J,I)=ZERO
   37 EFASY(I,I)=ONE
      RETURN
    5 FORMAT(9E15.8)
   25 FORMAT(10I5)
   26 FORMAT(L1)
      END
