      SUBROUTINE WEIGH 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
      INTEGER VMX,FU1
      LOGICAL LRE,LVIBJ
      SAVE
      PARAMETER(FU1=1)

C***This subroutine is for use with RMPROP: Version 2.1.2.
C***WEIGH may be called by SUBROUTINE PREPOT (from Schwenke-Truhlar 3-D HF-HF
C***potential subroutine, in module 'stpot.f').
C***WEIGH may be called by SUBROUTINE PREPOT (from arbitrary 3-D atom-diatom
C***potential subroutine, in moduel 'prevgr2.f).
C***WEIGH may be called by SUBROUTINE PREPOT (from arbitrary 3-D diatom-diatom
C***potential subroutine, in moduel 'prevgr3.f).
C***Find eigen values and optimal weights for the integration over
C***vibrational wave functions for arbitrary vibrational potentials.
C***This subroutine allows vib-rot coupling.
C***
C***This is done by expanding the wave functions in terms of a
C***harmonic basis and doing all integrals in the harmonic basis. 
C***
C***The nodes can be found in any of four ways: 
C***Use semi-classical nodes.
C***Use scaled Gauss-Hermite nodes (scaled to be correct if the
C***    potential was harmonic).
C***Use Gaussian nodes for the weight function psi(IWGHT)**2.
C***Call user-supplied subroutine SDATA to supply nodes.
C***[Call SDATA(NPTS,XS), where NPTS is the # of nodes, and XS 
C***is an array containing the nodes.]
C 
C***The weights are to give integrals of powers exactly with the
C***weight function being the product of the two wave functions.
C 
C***The user must supply a function PTNTL(X) which calculates the 
C***potential at X=R-RE (in Hartree atomic units!)
C***The zero of energy is R=RE. 
C 
C***This program uses exclusively Hartree atomic units. 
C 
C***Other subroutines required: 
C*** VIBX (MODIFICATION OF MORSEX)
C*** RS (EISPACK)
C*** MXMPLY
C*** MXLNEQ
C*** GAUSSQ
C*** GTEN
C*** AITKNG
C 
C***The eigenenergies, nodes and weights are written to FORTRAN unit 1.
C***The information saved on FORTRAN unit 1 is as follows: 
C***
C***NSAVE,JSAVE,IHOM (1X,3I5)                                         
C***
C***EIG(I),I=1,NSAVE (1X,1P,6E21.14) (This happens JSAVE times).
C***
C***NPTS     (1X,I5) 
C***
C***XS(I),I=1,NPTS (1X,1P,6E21.14) (These are the nodes (R-RE)).
C***
C*** DO L=1,NSAVE*(NSAVE+1)/2 
C*** DO K=1,JSAVE 
C*** DO J=1,JSAVE 
C*** (WEIGHT(I,J,K,L),J=1,NPTS)    (1X,1P,6E21.14)
C***
C 
C***The lines NPTS through WEIGHT are repeated as many times 
C***as there are non-zero values of NPTS read in.
C***Use subroutine WDATA to retrieve the data written to FORTRAN unit 1. 
C 
      PARAMETER (NBMX=40,JMX=32,VMX=8,NDMX=30)
C***NBMX is the maximum number of harmonic oscillator basis functions.
C***JMX is the maximum # of J states weights and nodes are needed for.
C***VMX is the maximum # of V states weights and nodes are needed for.
C***NDMX is the maximum order of quadrature to calc. weights and nodes for.

      COMMON/PSIHCM/ZEFIND
      COMMON/EIGCOM/FK,RMS,OMEGA,HFK,CENT,RE
      COMMON/LOGCM/LVIBJ

C     DIMENSION H(40  ,40  ),EIG(40  ),Z(40  ,40  ,20 ),FV1(40  ),
C    1FV2(40  ),XI(40  ,40  ,3*10  )                                    
C    2,ZT(40  ,40  ,20 ),W(40  ),END(2),XMAT(30  ,30  ),                
C    3XNB(40  ,40  ,3*10  ),                                            
C    4TEMP(3*10  ),XUSE(30  ,30  +1),XS(30  ),AINT(3*10  ),             
C    5WEIGHT(30  ,20 ,20 ,10  *(10  +1)/2),NSCL(40  ) 
      COMMON/JHOMCM/IHOMM,JHOM
      COMMON/RECM/REE
      DIMENSION H(NBMX,NBMX),EIG(NBMX),Z(NBMX,NBMX,JMX),FV1(NBMX),
     1FV2(NBMX),XI(NBMX,NBMX,2*NDMX)
     2,ZT(NBMX,NBMX,JMX),W(NBMX),END(2),XMAT(NDMX,NDMX),
     3XNB(NBMX,NBMX,2*NDMX),
     4TEMP(2*NDMX),XUSE(NDMX,NDMX+1),XS(NDMX),AINT(2*NDMX),
     5WEIGHT(NDMX,JMX,JMX,VMX*(VMX+1)/2),NSCL(NBMX)


      DIMENSION BC(400),SIG(121,121)
      DIMENSION PCKED(820),SCRTCH(40,8)
      INTEGER INTSC(40)
C     DATA NBMX/40/,JMX,VMX,NDMX/30,8,30/ 
      DATA TWO/2.0D+0/ONE/1.0D+0/QUAR/0.25D+0/HALF/0.5D+0/ZERO/0.0D+0/
      DATA EPS/1.0D-14/SCALE/1.0D+10/                                   

C***OPEN FORTRAN unit 1 in preparation for writing

      OPEN(UNIT=FU1,FILE='fort.1',STATUS='UNKNOWN',FORM='FORMATTED')
 
C***OMEGA harmonic oscillator angular frequency.
C***RMS oscillator reduced mass.
C***RE potential minimum (equilibrium bond length of oscillator). 
C***OMEGGH frequency to use to find scaled Gauss-Hermite nodes.
C***If OMEGGH is zero, OMEGA is used instead.
C***LRE TRUE means calculate the value of the wave function at -RE.   
C***SCAL2 is the scale parameter for GAUSHM. Use 1.0 if no scaling 
C***is needed, otherwise increase it.

      READ(4,1)RMS,OMEGA,RE,OMEGGH,LRE,SCAL2                           
      IF(OMEGGH.EQ.ZERO)OMEGGH=OMEGA                                  
    1 FORMAT(4E15.7,L1,E15.7)                                           
      WRITE(6,222)
  222 FORMAT(/1X,49HCalculation of weights and nodes for vibrational ,
     111Hquadratures/1X,41Hof interaction potential matrix elements.)
      WRITE(6,2)RMS,OMEGA,RE
    2 FORMAT(1X,44HHarmonic osc. parameters in primitive basis:/1X, 
     113HReduced mass=,1PE15.7,19H Angular frequency=,E15.7,/1X,4H RE=,
     2E15.8)
      FK=RMS*OMEGA*OMEGA
      HFK=FK*HALF 
 
C***NQUAD order of integration used to evaluate all harmonic osc. 
C***matrix elements.
C***NBASIS number of states of the harmonic osc. to include in the
C***expansion.
C***NPTS is the maximum size of quadrature to be found.
C***IPRINT > 0 for various debug printing.
C***INODE determines the type of nodes used:
C***    = 1 use semi-classical nodes.
C***    = 2 use scaled Gauss-Hermite nodes.
C***    = 3 use Gaussian nodes for the weight function PSI(IWGHT)**2.
C***    = 4 call SDATA to get other nodes.
C***IWGHT runs from 1 upwards.
C***NINT and NL only have meaning when INODE=1. 
 
      READ(4,3)NQUAD,NBASIS,NPTS,IPRINT,INODE,IWGHT
      IF(NBASIS.GT.NBMX)STOP 'NBASIS > NBMX in WEIGH in weigh.f'
 
C***NINT is the number of intervals to be used by subroutine NODE.
C***NL is the order of Legendre interpolation used by NODE.
C***NSAVE is the maximum vibrational Q.N. + 1 for which weights and
C***nodes are to be saved on FORTRAN unit 1.   
C***
C***JSAVE is the maximum rotational quantum number+1 of J states in the 
C***calculation of the  
C***vibrational states. If no rotational-vibrational coupling is desired,
C***use JSAVE=0.
C***IHOM : 0 for heteronuclear diatoms, 1 for homonuclear diatoms with odd J, 
C***and 2 for homonuclear diatoms with even J.  
 
      READ(4,401)NINT,NL,NSAVE,JSAVE,IHOM                               
  401 FORMAT(5I5)       
      NPNTMX=NPTS
      IF(INODE.EQ.3)NPTS=2*NPTS 
      NDIM=NSAVE*(NSAVE+1)/2
  100 FORMAT(1X,3I5)
C***LINE BELOW TEST ADDED BY MJU3-17-93
      IF (LVIBJ.AND.(JSAVE.EQ.0))WRITE(6,101)
      IF((.NOT.LVIBJ).AND.(JSAVE.GE.1))WRITE(6,101)
  101 FORMAT(/1X,'In SUBROUTINE WEIGH the vib-rot coupling',
     1 ' flags are inconsistent')
      IF((.NOT.LVIBJ).AND.(JSAVE.GE.1))
     1 STOP 
      IF(LVIBJ.AND.(JSAVE.EQ.0))
     1 STOP 
C***NEW LINES END HERE
       IF(JSAVE.EQ.0)JSAVE=JSAVE+1                                        6M2R94
      IF(IHOM.EQ.0)WRITE(6,586)                                         
  586 FORMAT(1X,72HThe diatom is heteronuclear, so weights for all VJ st
     $ates will be found.)                                               
      IF(IHOM.NE.0)WRITE(6,585)                                         
  585 FORMAT(1X,72HThe diatom is homonuclear, so only weights for J even
     $/odd will be found.)                                               

C***The loop below is for simulation of a rigid rotor for which specialized
C***output is required.

      IF(NSAVE.EQ.0) THEN                                               6M2R94
         WRITE(6,589)
 589  FORMAT(/1X,'The diatom is represented as a rigid rotor and so ',
     1    'a specialized'/1X,'vibrational quadrature is performed ')
      WRITE(6,5089)
5089  FORMAT(1X,'Eigenvalues must be provided by FUNCTION EIGEN')
      WRITE(1,100)1,1
         WRITE(1,50)ZERO
         WRITE(1,590)1
         WRITE(1,50)ZERO
         WRITE(1,50)ONE
         RETURN
      END IF
 590  FORMAT(1X,2I5)
      IDIV=1
      IF(IHOM.NE.0)IDIV=2 
      NJDIM=JSAVE/IDIV
      IF(JSAVE.GT.JMX)STOP 'JSAVE > JMX in WEIGH in weigh.f'
      IF(NSAVE.GT.VMX)STOP 'NSAVE > VMX in WEIGH in weigh.f'            6M2R94
      WRITE(1,100)NSAVE,JSAVE,IHOM                                      
      NP1=NPTS+1 
    3 FORMAT(6I5) 
      WRITE(6,5)NQUAD,NBASIS
    5 FORMAT(/1X,34HOrder of Gauss-Hermite quadrature=,I5,25H Size of pr
     +imitive basis=,I5)
 
C***Calculate primitive basis functions at X=-RE.
 
      IF(.NOT.LRE)GOTO 587                                              
      ZETA=SQRT(RMS*OMEGA)                                              
      ZETARE=ZETA*RE                                                    
      ZETARE=ZETARE*ZETARE                                              
      DO 80 I=1,NBASIS                                                  
   80 W(I)=PSIHO(-RE,I,ZETA,NSCL(I),SCALE)                              
 
C***Set up Hamiltionian.
 
  587 CONTINUE                                                          
      JCOUNT=0                                                          
      JSTART=1                                                          
      IF(IHOM.EQ.1)JSTART=2                                             
      JSTEP=1                                                           
      IF(IHOM.NE.0)JSTEP=2                                              
      JEND=(JSAVE-1)*JSTEP+JSTART                                       
      IFIRST=1                                                          
      DO 13 JLOOP=JSTART,JEND,JSTEP                                     
      JUSE=JLOOP-1
      JCOUNT=JCOUNT+1                                                   
      IF(IPRINT.GE.1)WRITE(6,201)JUSE
  201 FORMAT(/1X,24HCentrifugal term uses J=,I5)
      CENT=JUSE*JLOOP 
      CENT=CENT*HALF/RMS
      INEW=0
      ICALC=0 
      DO 4 I=1,NBASIS 
      I1=I-1
      DO 14 J=1,I 
      J1=J-1
      CALL VIBX(1,I1,J1,NQUAD,H(J,I),IFIRST,ONE,FK,DUM,RMS,ICALC,INEW,
     +NBASIS,1,SCAL2)                                                   
      INEW=1
      IFIRST=2
   14 H(I,J)=H(J,I) 
      T=( FLOAT(I)-HALF)*OMEGA
    4 H(I,I)=H(I,I)+T 
      IF(IPRINT.LE.1)GOTO 15
      WRITE(6,6)
    6 FORMAT(/1X,18HHamiltonian matrix/)
      DO 7 I=1,NBASIS,10
      IS=I  
      IE=MIN0(IS+9,NBASIS)
      WRITE(6,9)(K,K=IS,IE) 
      DO 7 J=1,NBASIS 
    7 WRITE(6,8)J,(H(J,K),K=IS,IE)
    9 FORMAT(4X,10I12)
    8 FORMAT(1X,I3,1P,10E12.5) 
 
C***Diagonalize Hamiltonian.
C***Either Cray SCILIB version of EISPACK RS or EV2RSP is called
C***depending on the auxilliary files compiled.
C***Subroutine EV2RSP is an alternative routine based on Stephen Elbert's
C***EVVRSP.
 
   15 CONTINUE
      DO 155 III=1,NBMX
        DO 155 JJJ=1,NBMX
          Z(JJJ,III,JCOUNT)=H(JJJ,III)
  155 CONTINUE
      CALL RS(NBMX,NBASIS,Z(1,1,JCOUNT),EIG,1,Z(1,1,JCOUNT),FV1,FV2,
     1        IERR)           
      NLEN=(NBMX*NBMX+NBMX)/2
      CALL EV2RSP(0,NBASIS,NBASIS,NLEN,NBMX,PCKED,SCRTCH,INTSC,
     1            EIG,Z(1,1,JCOUNT),0,IERR)
      IF(IERR.EQ.0)GOTO 10
      WRITE(6,11)IERR 
   11 FORMAT(/1X,27HOn return from RS IERR was ,I7) 
      STOP 'Error in RS in WEIGH in weigh.f'  
   10 IF(IPRINT.GE.1)WRITE(6,12)(EIG(I),I=1,NBASIS)
   12 FORMAT(/1X,12HEIGEN VALUES//(1X,1P,6E21.14)) 
      WRITE(1,50)(EIG(I),I=1,NSAVE) 
   50 FORMAT(1X,1P,6E21.14)
 
C***Assign E for nodes - this is used only in the calculation of the  
C***semi-classical nodes.
 
      IF(JLOOP.EQ.JSTART)E=EIG(NSAVE)                                   
 
C***Calculate wave function at X=-RE.
 
      IF(.NOT.LRE)GOTO 588                                              
      DO 81 I1=1,NBASIS                                                 
      EIG(I1)=ZERO                                                      
      DO 83 I2=1,NBASIS                                                 
      TERM=W(I2)*Z(I2,I1,JCOUNT)                                        
      DO 9981 I3=1,NSCL(I2)                                             
 9981 TERM=TERM*SCALE                                                   
   83 EIG(I1)=EIG(I1)+TERM                                              
   81 EIG(I1)=EXP(LOG(ABS(EIG(I1)))-ZETARE*0.5)                         

      IF(IPRINT.GE.1)WRITE(6,82)(EIG(I1),I1=1,NBASIS)                                 
   82 FORMAT(/1X,31HValue of wave function at R=0.0//(1X,1P,6E21.14))    
 
C***Calculate transpose of eigen vectors.
 
  588 CONTINUE                                                          
      DO 21 I=1,NBASIS
      DO 21 J=1,NBASIS
   21 ZT(I,J,JCOUNT)=Z(J,I,JCOUNT)                                      
      IF(IPRINT.LE.2)GOTO 13
      WRITE(6,16) 
   16 FORMAT(/1X,13HEIGEN VECTORS/) 
      DO 17 I=1,NBASIS,10 
      IS=I  
      IE=MIN0(IS+9,NBASIS)
      WRITE(6,9)(K,K=IS,IE) 
      DO 17 J=1,NBASIS
   17 WRITE(6,8)J,(Z(J,K,JCOUNT),K=IS,IE)                               
 
C***Calculate matrix of integrals for right side of equation for
C***weights.
 
   13 CONTINUE
      ICALC=1 
      INEW=0
      DO 20 I=1,NBASIS
      I1=I-1
      DO 20 J=1,I 
      J1=J-1
      CALL VIBX(NPTS,I1,J1,NQUAD,TEMP,IFIRST,ONE,FK,DUM,RMS, 
     +ICALC,INEW,NBASIS,1,SCAL2)                                        
      INEW=1
      DO 20 K=1,NPTS 
      XI(I,J,K)=TEMP(K) 
   20 XI(J,I,K)=XI(I,J,K) 
      IF(IPRINT.LE.3)GOTO 33
      WRITE(6,34) 
   34 FORMAT(/1X,33HPrimitive matrix elements for <X>/) 
      DO 35 I=1,NBASIS,10 
      IS=I  
      IE=MIN0(I+9,NBASIS) 
      WRITE(6,9)(J,J=IS,IE) 
      DO 35 J=1,NBASIS
   35 WRITE(6,8)J,(XI(J,K,2),K=IS,IE) 
 
C***Transform from harmonic basis to vibrational basis with J=0.
 
   33 DO 26 K=1,NPTS 
      CALL MXMPLY(ZT,XI(1,1,K),XNB(1,1,K),NBASIS,NBASIS,NBASIS,NBMX,NBMX
     +,NBMX,W)
      CALL MXMPLY(XNB(1,1,K),Z,XNB(1,1,K),NBASIS,NBASIS,NBASIS,NBMX,NBMX
     +,NBMX,W)

   26 AINT(K)=XNB(IWGHT,IWGHT,K)                                    
      IF(IPRINT.LE.4)GOTO 36
      WRITE(6,37) 
   37 FORMAT(/1X,22HMatrix elements of <X>/)
      DO 38 I=1,NBASIS,10 
      IS=I  
      IE=MIN0(IS+9,NBASIS)
      WRITE(6,9)(K,K=IS,IE) 
      DO 38 J=1,NBASIS
   38 WRITE(6,8)J,(XNB(J,K,2),K=IS,IE)
 
C***NPTS is the order of the quadrature to be found.
C***NPTS <= 0 to stop run.
 
   36 READ(4,3)NPTS
      IF(NPTS.GT.NPNTMX)STOP 'NPTS too large in WEIGH in weigh.f'
      NP1=NPTS+1 
      IF(NPTS.LE.0) THEN
      RETURN
      END IF
      WRITE(1,100)NPTS 
 
C***Calculate nodes and matrix for left side of equation for weights.
 
      GOTO (51,52,53),INODE 
 
      CALL SDATA(NPTS,XS)                                            
      GOTO 54                                                           

C***Semi-classical nodes.
 
   51 CALL NODE(NINT,NPTS,NL,E,RMS,XS) 
      GOTO 54 
 
C***Scaled Gauss-Hermite nodes.
 
   52 CALL GAUSSQ(4,NPTS,ZERO,ZERO,0,END,EIG,XS,W) 
      WRITE(6,87)OMEGGH                                                
   87 FORMAT(1X,43HFrequency used to scale Gauss-Hermite nodes,1PE15.8) 
      SRALPI=RMS*OMEGGH                                                
      SRALPI=ONE/SQRT(SRALPI) 
      DO 55 I=1,NPTS 
   55 XS(I)=XS(I)*SRALPI
      GOTO 54 
 
C***Gaussian ground state nodes. If JSAVE >0, the nodes will depend on J, 
C***which we do not want, so use nodes from J=0 always.  
C***We need to supply 2*NPTS integrals. 

   53 CALL GGAUSX(NPTS,AINT,XS,0,RE,BC,SIG)
   54 IF(IPRINT.GE.1)THEN
      WRITE(6,24) 
   24 FORMAT(1X,5HNodes)
      DO 22 I=1,NPTS 
   22 WRITE(6,25)XS(I)
   25 FORMAT(1X,1P,6E21.14)
      END IF
 
C***Write nodes to FORTAN unit 1.
 
      WRITE(1,50)(XS(I),I=1,NPTS)
 
C***Loop over J'S.
 
      DO 200 JLOOP1=1,JSAVE 
      DO 200 JLOOP2=1,JSAVE 
      IF(IPRINT.GE.1)WRITE(6,205)JLOOP1,JLOOP2 
  205 FORMAT(/1X,2HJ1,I5,3H J2,I5)
 
C***Transform to current J basis.
 
C***IF(JLOOP1.EQ.1.AND.JLOOP2.EQ.1)GOTO 202                           

      DO 203 K=1,NPTS
      CALL MXMPLY(ZT(1,1,JLOOP1),XI(1,1,K),XNB(1,1,K),NBASIS,NBASIS,
     +NBASIS,NBMX,NBMX,NBMX,W)
  203 CALL MXMPLY(XNB(1,1,K),Z(1,1,JLOOP2),XNB(1,1,K),NBASIS,NBASIS,
     +NBASIS,NBMX,NBMX,NBMX,W)
  202 CONTINUE
 
C***Set up left side of equation.
 
      DO 23 I=1,NPTS 
      T=ONE 
      DO 23 J=1,NPTS 
      XMAT(J,I)=T 
   23 T=T*XS(I) 
      IF(IPRINT.LE.5)GOTO 39
      WRITE(6,40) 
   40 FORMAT(/1X,21HLeft side of equation/) 
      DO 41 I=1,NPTS,10
      IS=I  
      IE=MIN0(IS+9,NPTS) 
      WRITE(6,9)(K,K=IS,IE) 
      DO 41 J=1,NPTS 
   41 WRITE(6,8)J,(XMAT(J,K),K=IS,IE) 
 
C***Loop over pairs of wave functions and calculate weights for them. 
 
   39 IWS=0 
      DO 27 I=1,NSAVE 
      DO 27 J=1,I 
      IWS=IWS+1 
      DO 28 K=1,NPTS 
      DO 28 L=1,NPTS 
   28 XUSE(K,L)=XMAT(K,L) 
      DO 29 K=1,NPTS 
   29 XUSE(K,NP1)=XNB(I,J,K)
      CALL MXLNEQ(XUSE,NPTS,NDMX,DET,JRANK,EPS,W,-1)                 
      IF(IPRINT.LE.6)GOTO 5400                                           
      WRITE(6,30)I,J
   30 FORMAT(1X,30HWeights for the matrix element,I5,1H,,I5)
      WRITE(6,25)(XUSE(K,NP1),K=1,NPTS)
 5400 CONTINUE                                                            
 
C***Save weights in master array.
 
      DO 27 K=1,NPTS 
      WEIGHT(K,JLOOP1,JLOOP2,IWS)=XUSE(K,NP1) 
   27 CONTINUE

C***End loop over J states.
 
  200 CONTINUE

C***Write weights to FORTRAN unit 1.
 
      DO 800 K1=1,NDIM
      DO 800 K2=1,JSAVE 
      DO 800 K3=1,JSAVE 
  800 WRITE(1,50)(WEIGHT(K4,K3,K2,K1),K4=1,NPTS) 
 
C***GET NEXT VALUE OF NPTS.
 
      GOTO 36 
      END 

      FUNCTION FN(X,L,K)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
      COMMON/EIGCOM/FK,RMS,OMEGA,HFK,CENT,RE
      DATA ONE,TWO/1.0D+0,2.0D+0/HALF/0.5D+0/ 
      IF(L.GT.0)GOTO 1
      X2=X*X
      R=X+RE
      R2=R*R
      V1=HFK*X2 
      VCENT=CENT/R2 
      FN=PTNTL(X)-V1+VCENT

C***Diagnostic write out.
C     PRINT*,'VCENT,CENT,R,RE,X',VCENT,CENT,R,RE,X

      RETURN
    1 FN=X**(K-1) 
      RETURN
      END 

      SUBROUTINE NODE(NINT,NPOINT,NL,E,XMU,XNODE) 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
      SAVE
 
C***Program to find nodes semiclassically for integration of
C***vibrational wave functions. 
 
C***Read here is NINT, the number of divisions from R=RE to the
C***turning points, NPOINT the number of nodes to generate, and NL, 
C***the order of the Legendre interpolation.
 
C***User-supplied fucntion PTNTL(X) finds the potential at X=R-RE. 
C***It is assumed that POT(ZERO) is the minimum.
 
C***MXINT is the maximum number of intervals used.                       
C***MXINTR is the maximum number order of interpolation to be used.
C***PARAMETER (MXINT=900,MXINTR=20)                                   

      EXTERNAL WVEC,AITKNG,PTNTL
      COMMON/WVECM/FACT1,FACT2
      DIMENSION X(900),S(900),TEMP(20),XNODE(NPOINT)            
      DATA MXINT,MXINTR/900,20/
      DATA ZERO/0.0D+0/HALF/0.5D+0/TWO/2.0D+0/IFIRST/0/ 
      WRITE(6,96)E,XMU
   96 FORMAT(1X, 8HEnergy =,1PE15.8,14H Reduced mass=,E15.8)
   95 FORMAT(2E15.8)
      FACT1=E 
      FACT2=SQRT(TWO*XMU) 
      IPOINT=1
      WRITE(6,12)NINT,NPOINT,NL 
   12 FORMAT(1X,5HNINT=,I5,8H NPOINT=,I5,4H NL=,I5) 
    4 FORMAT(3I5) 
      IF(NINT.GT.MXINT)STOP 'NINT > MXINT in NODE in weigh.f'
      IF(NL.GT.MXINTR)STOP 'NL > MXINTR in NODE in weigh.f'
      NHALF=NPOINT/2
      NINT2=2*NINT+1
      N2=NHALF*2
      XPOINT=NPOINT 
      XPOINT=NPOINT+HALF
      IF(IFIRST.NE.0)GOTO 10
      IFIRST=1

C***Find turning points.

      CALL TP(E,R1,R2,IERR) 
      DR=R1/NINT
      NINTP=NINT+1
      X(NINTP)=ZERO 
      S(NINTP)=ZERO 
      NDIV=1
      IXM=NINTP 
      IX=IXM-1

C***Integrate from RE to turning point.

    1 CONTINUE
      X(IX)=X(IXM)+DR 
      CALL GTEN(X(IXM),X(IX),WVEC,S(IX),NDIV) 
      S(IX)=S(IX)+S(IXM)
      IXM=IXM-1 
      IX=IX-1 
      IF(IX.NE.0)GOTO 1 
      DR=R2/NINT
      IXM=NINTP 
      IX=IXM+1
      X(IXM)=ZERO 
      S(IXM)=ZERO 
      NDIV=1

C***Integrate from RE to turning point.

    5 CONTINUE
      X(IX)=X(IXM)+DR 
      CALL GTEN(X(IXM),X(IX),WVEC,S(IX),NDIV) 
      S(IX)=S(IX)+S(IXM)
      IXM=IX
      IX=IX+1 
      IF(IX.LE.NINT2)GOTO 5 

C***Diagnostic write out.

C     WRITE(6,6)
C     DO 7 I=1,NINT2  
C   7 WRITE(6,8)X(I),S(I) 
    8 FORMAT(25X,1P,2E15.8)
    6 FORMAT(26X,1HX,14X,1HS) 

C***Interpolate to get nodes in X space.
 
   10 DS=(S(NINT2)-S(1))/XPOINT 
      SMID=HALF*(S(NINT2)+S(1)) 
      S1=SMID- FLOAT(NHALF)*DS
      IF(N2.EQ.NPOINT)S1=S1+HALF*DS 
      IP=1  

C***Diagnostic write out.

C     WRITE(6,6)

   22 CONTINUE
      X1=AITKNG(S1,X,TEMP,S,NL,NINT2)
      XNODE(IPOINT)=X1
      IPOINT=IPOINT+1 

C***Diagnostic write out.

C     WRITE(6,8)X1,S1 

      S1=S1+DS
      IP=IP+1 
      IF(IP.LE.NPOINT)GOTO 22 
      RETURN
      END 

      FUNCTION WVEC(X)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
      SAVE
      EXTERNAL PTNTL

C***Calculate wave vector.

      COMMON/WVECM/FACT1,FACT2
      WVEC=FACT1-PTNTL(X) 
      WVEC=FACT2*SQRT(WVEC) 
      RETURN
      END 

      SUBROUTINE TP(E,X1,X2,IERR) 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
      SAVE
 
C***Find turning points.
C***Potential is assumed to be a minimum AT X=ZERO.
 
      DATA ZERO,XMIN,XMAX/0.0D+0,0.0D+0,1.0D+3/P1,P2,EPS/0.1D+0,
     10.2D+0,1.0D-14/ 
     1ONE/1.0D+0/ 
      IERR = 0
      VASYMP=PTNTL(XMAX)
      IF(E.GT.ZERO .AND. E.LT.VASYMP) GO TO 10
      IERR = 1
      WRITE(6,600) E,VASYMP 
      RETURN
   10 IFLG = 0
      ITP = 0 
      DX = -P1
   20 X = XMIN
      SGN = ONE 
   30 X = X + DX
   35 CONTINUE
      T = E - PTNTL(X)  
      IF(T*SGN.GT.ZERO) GO TO 30
      SGN = -SGN
      DX = -P2*DX 
      IF(ABS(DX).GT.EPS) GO TO 30 
      IF(ITP.EQ.1) GOTO 40
      ITP = 1 
      X1 = X
      DX = P1 
      GO TO 20
   40 X2 = X
      RETURN
  600 FORMAT(//39H Error in finding turning points for E=,1PE13.5,
     1    5X, 5HVMIN=,E13.5,5X,5HVMAX=,E13.5 )
      END 
      SUBROUTINE VIBX(NF,II1,JJ1,N,VBMT,IFIRST,DE,FK,RE,RMS,L,INEW, 
     1MAXL,IOSC,SCAL2)                                                  
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
      SAVE

C***Calculate vibrational matrix elements for oscillators by
C***numerical integration.  Weights and nodes are supplied by GAUSSH.  
C***NF is the number of functions to calculate matrix elements for.
C***II1 is the quantum number of the bra (0 up to MAXL-1).
C***JJ1 is the quantum number of the ket (0 up to MAXL-1).
C***N is the order of quadrature used.
C***VBMT is an array dimensioned at least NF which on output will 
C***contain the matrix elements.
C***IFIRST is 1 on first call to set up constants.
C***DE is the Morse oscillator well depth in atomic units.
C***FK equivalent harmonic oscillator force constant in atomic units.
C***RE is the equilibrium displacement of the oscillator.
C***RMS oscillator reduced mass in atomic units.
C***L is for use by function FN.
C***INEW = 0 means calculate the functions at the quadrature points. 
C***MAXL is the maximum Morse oscillator quantum number plus one
C***that will be needed.
C***IOSC=0 for Morse oscillators.
C***     1 for harmonic oscillators.
C***SCAL2 is scale parameter for weights.  Use to keep weights from    
C***underflowing.  Increase if MAXL is large and this program prints
C***a message that some weights are zero. Use 1.0 if no scaling is
C***necessary, otherwise increase SCAL2.                              
C*** 
C***A function FN(Y,L,K) must be supplied by the user and this
C***calculates the Kth (K=1,..,NF) function at R-RE=Y.
 
      DIMENSION VBMT(NF),W(100),X(100),FUNC(100,70),FVAL(100,50),B(100) 
      DATA ZERO,ONE,TWO/0.0D+0,1.0D+0,2.0D+0/SCALE/1.0D+10/HALF/0.5D+0/ 
      DATA NQSAVE/-1/NMAX,MXLMAX,NFMAX/100,70,50/
      IF(IFIRST.NE.1)GOTO 1 

C***Stop if dimensions are exceeded.

      IF(N.GT.NMAX.OR.MAXL.GT.MXLMAX.OR.NF.GT.NFMAX)GOTO 9 

C***Calculate useful constants.

      T=TWO*DE
      A=SQRT(FK/T)
      RKRW=SQRT(RMS*T)/A
      RK=TWO*RKRW 
      OMEGA=SQRT(FK/RMS)
      ZETA=SQRT(RMS*OMEGA)
      SRALPI=ONE/ZETA 
      SRALPL=LOG(SRALPI)
    1 JI1=II1+1 
      JF1=JJ1+1 
      IF(N.EQ.NQSAVE.AND.IFIRST.NE.1)GOTO 2 

C***Calculate weights and nodes, and oscillator functions at nodes.
C***GAUSHM is GAUSHM modified to scale weights by EXP(WMULT).

      IF(SCAL2.EQ.ZERO)SCAL2=ONE                                        
      CALL GAUSHM(N,B,X,W,SCAL2,WMULT)                                 

C***Scale nodes, and weights if necessary.
C***Work with the LOG of the weights until they are multiplied by the
C***wave functions.                                                   

      IZEROC=0                                                          
      DO 3 I=1,N
      IF(W(I).EQ.ZERO)IZEROC=IZEROC+1                                   
      W(I)=SLOG(W(I))-WMULT                                             
      IF(IOSC.EQ.1)GOTO 11
      X2=X(I)**2
      WL=W(I) 
      W(I)=WL+SRALPL+X2                                                
   11 X(I)=X(I)*SRALPI
      W(I)=HALF*W(I)                                                    

C***W(I) now contains the LOG of the square root of the Ith weight.

    3 CONTINUE

C***Some of the wavefunctions will be divided by SCALE**NSCALE.

      IF(IZEROC.EQ.0)GOTO 981                                           
      WRITE(6,982)IZEROC,SCAL2                                          
  982 FORMAT(/1X,25HIn VIBX, GAUSHM produced ,I5,14H zero weights.,    
     $/1X,26HTry increasing SCAL2 from ,1PE15.8)                        
  981 SLOGS=LOG(SCALE)                                                  
      DO 4 I=1,MAXL 
      IM=I-1
      SARG=RK- FLOAT(2*IM)
      DO 4 J=1,N
      IF(IOSC.EQ.0)FUNC(J,I)=PSIMO(X(J),I,RKRW,A,SARG,NSCALE,SCALE)     
      IF(IOSC.EQ.1)FUNC(J,I)=PSIHO(X(J),I,ZETA,NSCALE,SCALE)            

C***FUNC will contain the properly normalized wavefunction times the  
C***square root of the weight at that displacement.

      SIG=SIGN(ONE,FUNC(J,I))                                           
      FUNC(J,I)=EXP(LOG(ABS(FUNC(J,I)))+ FLOAT(NSCALE)*SLOGS+W(J))      
      FUNC(J,I)=SIGN(FUNC(J,I),SIG)                                     
    4 CONTINUE
      NQSAVE=N
    2 IF(INEW.NE.0)GOTO 5 

C***Calculate function for matrix elements.

      DO 6 K=1,NF 
      DO 6 I=1,N
    6 FVAL(I,K)=FN(X(I),L,K)
    5 CONTINUE

C***Perform integration.

      DO 7 K=1,NF 
      T=ZERO
      DO 8 I=1,N
    8 T=T+FVAL(I,K)*FUNC(I,JI1)*FUNC(I,JF1) 
    7 VBMT(K)=T 
      RETURN
    9 WRITE(6,10)N,NMAX,MAXL,MXLMAX,NF,NFMAX 
   10 FORMAT(1X,27HDimensions exceeded in VIBX/1X,2HN=,I5,6H NMAX=, 
     1I5,6H MAXL=,I5,8H MXLMAX=,I5,4H NF=,I5,7H NFMAX=,I5) 
      STOP 'In SUBROUTINE VIBX in module weigh.f'
      END 
      FUNCTION PSIMO(X,N,RKRW,A,SARG,NSCALE,SCALE)                      
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
 
C***Calculate normalized Morse oscillator wave function at R-RE=X.
C***N is the quantum number plus 1.
C***RKRW=SQRT(2*MU*D)/A, where D and A are the potential depth and
C***range parameters. 
C***SARG=2*(RKRW-(N-1)).

      DATA HALF/0.5D+0/TWO/2.0D+0/ONE/1.0D+0/THAV/1.5D+0/NOLD/-1/ 
      IF(NOLD.EQ.N)GOTO 1 

C***Calculate normalization.

      XN=N-1
      CONST=(RKRW-XN-HALF)*LOG(TWO*RKRW)+HALF*(LOG(A)+LOG(TWO*(RKRW-
     $XN)-ONE)-LOG(FACTOR(N-1))+GAMLOG(TWO*RKRW-XN))-GAMLOG(TWO*(RKRW-
     $XN))  
      NOLD=N
    1 CONTINUE

C***Calculate wave function.

      Z=RKRW*EXP(-A*X)
      Y=TWO*Z 
      XN=N-1
      X2=-Z-A*(RKRW-HALF-XN)*X+CONST

C***CONFLU calculates the regular confluent hypergeometric function 
C***which differs by a constant from the Laguarre polynomial.

      F1=CONFLU(N-1,SARG,Y,NSCALE,SCALE)                                
      F2=EXP(X2)
      PSIMO=F1*F2 
      IF(MOD(N,2).NE.0)PSIMO=-PSIMO 
      RETURN
      END 

      FUNCTION CONFLU(N,S,X,NSCALE,SCALE)                               
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
 
C***This calculates the regular confluent hypergeometric function 
C***M(-N,S,X).
 
      DATA ONE/1.0D+0/TWO/2.0D+0/ 
      NSCALE=0                                                          
      A=ONE 
      IF(N.EQ.0)CONFLU=A
      IF(N.EQ.0)RETURN
      B=ONE-X/S 
      IF(N.EQ.1)CONFLU=B
      IF(N.EQ.1)RETURN
      DO 1 I=2,N
      XI= FLOAT(1-I)
      F1=(TWO*XI-S+X)/(XI-S)
      F2=XI/(S-XI)
      C=F1*B+F2*A 
      A=B 
      IF(ABS(C).LT.SCALE)GOTO 1                                         
      C=C/SCALE                                                         
      A=A/SCALE                                                         
      NSCALE=NSCALE+1                                                   
    1 B=C 
      CONFLU=C
      RETURN
      END 

      FUNCTION GAMLOG(X)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
 
C***Calculate the LOG of the Gamma function.
C***This is accurate only for large X.
 
      DATA ZERO/0.0D+0/HALF/0.5D+0/ONE/1.0D+0/TWO/2.0D+0/ 
      DATA C1,C2,C3,C4/12.0D+0,360.0D+0,1260.0D+0,1680.0D+0/
      GAMLOG=ZERO 
      IF(X.LE.TWO)RETURN
      PI2=TWO*ACOS(-ONE)
      X2=X*X
      X3=X*X2 
      X5=X3*X2
      X7=X5*X2
      GAMLOG=(X-HALF)*LOG(X)-X+HALF*LOG(PI2)+ONE/(C1*X)-ONE/(C2*X3) 
     $+ONE/(C3*X5)-ONE/(C4*X7)
      RETURN
      END 

      FUNCTION FACTOR(N)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
 
C***Calculate factorial.
 
      DATA ONE/1.0D+0/
      IF(N.LE.1)FACTOR=ONE
      IF(N.LE.1)RETURN
      A=ONE 
      DO 1 I=2,N
      A=A*I 
    1 CONTINUE
      FACTOR=A
      RETURN
      END 
      FUNCTION SLOG(X)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
 
C***Calculate LOG(X). If X is zero, return a large negative number.

      DATA VLNN/-1.0D+10/ZERO/0.0D+0/ 
      SLOG=VLNN 
      IF(X.EQ.ZERO)RETURN 
      SLOG=LOG(X)
      RETURN
      END 

      FUNCTION PSIHO(X,N,ZEFIND,NSCALE,SCALE)                          
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
 
C***Calculate normalized Harmonic oscillator wave FUNCTION at X.
C***N is the quantum number + 1.

      DATA HALF,THREEQ,ONE,ZERO,IFIRST/0.5D+0,0.75D+0,1.0D+0,0.0D+0,0/
     1TWO/2.0D+0/ 
      IF(IFIRST.NE.0)GOTO 1 
      IFIRST=1
      PI=ACOS(-ONE) 
      PI=SQRT(PI) 
      PI=ONE/SQRT(PI) 
      NOLD=-1 
    1 IF(NOLD.EQ.N)GOTO 2 

C***Compute normalization.

      IF(MOD(N,2).EQ.0)IP=1 
      IF(MOD(N,2).EQ.1)IP=0 
      NM=N-1
      NMP=NM-IP 
      IPHAS=NMP/2 
      NOVR=33                                                           
      IF(NM.LE.NOVR)FACT=PI*SQRT(FACTOR(NM))/FACTOR(IPHAS)              
      IF(NM.GT.NOVR)FACT=PI*EXP(HALF*FCTORL(NM)-FCTORL(IPHAS))        
      EX= FLOAT(2*IP-NM)
      EX=HALF*EX
      FACT=FACT*(TWO**EX) 
      IF(MOD(IPHAS,2).NE.0)FACT=-FACT 
      F1=HALF+ FLOAT(IP)
    2 CONTINUE

C***Compute wave function.

      ZETA=ZEFIND*X
      ZETA2=ZETA*ZETA 

C***Don't include EXP(-ZETA**2) which is weight function for quadrature.

      PSIHO=FACT*CONFLU(IPHAS,F1,ZETA2,NSCALE,SCALE)                    
      IF(IP.EQ.1)PSIHO=PSIHO*ZETA 
      RETURN
      END 

      SUBROUTINE CLASS2( N, B, A, MUZERO)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
      DIMENSION A(N),B(N)
      DOUBLE PRECISION MUZERO
      DATA PI /3.141592653589793D0/

      NM1 = N - 1
   40 MUZERO =  SQRT(PI)
      DO 41 I = 1, NM1
         A(I) = 0.0D0
   41    B(I) =  SQRT( DBLE(I)/2.0D0  )                                
      A(N) = 0.0D0
      RETURN
      END
      SUBROUTINE GAUSHM(N, B, T, W,SCAL2,WMULT)                        
C***
C***   This routine and its subprograms were adapted from ones obtained
C***from Lawrence Berkeley laboratory.
C***      This set of routines computes the nodes X(I) and weights
C***   C(I) for Gauss-Hermite quadrature.
C***     These are used when one wishes to approximate
C***
C***            INTEGRAL (from A to B)  F(X) W(X) DX
C***
C***                         N
C***   by                   SUM C  F(X )
C***                        I=1  I    I
C***
C***   here W(X) is EXP(-X*X), and F(X) is the
C***   function to be integrated.
C***      Associated with the weight function W(X) is a set of
C***   orthogonal polynomials.  The nodes X(I) are just the zeroes
C***   of the proper N-th degree polynomial.
C***
C***Input Parameters:
C***   N        The number of points used for the quadrature.
C***   B        Double Precision scratch array of length N.
C***
C***Output Parameters (both arrays of length N):
C***
C***   T        will contain the desired nodes X(1),,,X(N).
C***   W        will contain the desired weights C(1),,,C(N).
C***
C***Subroutines required:
C***
C***  GBSLVE, CLASS2, and GBTQL2 are provided. Underflow may sometimes
C***   occur, but it is harmless if the underflow interrupts are
C***   turned off.
C***
C***..................................................................
C***
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
      SAVE
      DOUBLE PRECISION MUZERO
      DIMENSION  B(N),T(N),W(N)

      CALL CLASS2 (N,B,T,MUZERO)
  100 W(1) = SCAL2                                                      
      WMULT=2.0D+0*LOG(SCAL2)                                           
      DO 105 I = 2,N
  105    W(I) = 0.0D0
      CALL GBTQL2 (N,T,B,W,IERR)
      IF(IERR.NE.0)WRITE(6,999)IERR
999   FORMAT(I5)
      DO 110 I = 1, N
  110    W(I) = MUZERO * W(I) * W(I)
      RETURN
      END
      FUNCTION FCTORL(N) 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
 
C***Calculate the LOG of N factorial.
 
      DATA ZERO/0.0D+0/ 
      IF(N.LE.1)FCTORL=ZERO
      IF(N.LE.1)RETURN
      A=ZERO
      DO 1 I=2,N
      A=A+LOG( FLOAT(I))
    1 CONTINUE
      FCTORL=A 
      RETURN
      END 
      SUBROUTINE MXLNEQ(A,NN,IDA,DETT,JRANK,EPS,IN,MMM) 

C***Programmed by R. hotchkiss, U. COMP. CTR., U. OF MINN., Revised Oct. 1973
C***Modified for the VAX by Bruce Garrett, Nov. 1980 

      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
      SAVE
      DOUBLE PRECISION MACHEP 
      DIMENSION A(IDA, 31),IN(IDA)

      DATA ZERO,ONE/0.0D0,1.0D0/,MACHEP/1.D38/

      DATA INTMX /400000/ 

C***Initiate some local and output variables.

      JRANK = NN
      N = NN
      ID=IDA
      APS=EPS 
      OPS = EPS 

C***Error checking.

      IF(N.GT.0 .AND. N.LE.ID) GO TO 1
      WRITE(6,607)
      WRITE(6,600) N,ID 
      STOP 'In SUBROUTINE MXLNEQ in module weigh.f' 
    1 IF(ID.GE.N .AND. ID.LT.INTMX) GO TO 2 
      WRITE(6,607)
      WRITE(6,601) ID,N,INTMX 
      STOP 'In SUBROUTINE MXLNEQ in module weigh.f' 
    2 IF((ONE+OPS) .NE. ONE .AND. OPS.GE.ZERO) GO TO 3
      WRITE(6,607)
      WRITE(6,602) OPS
      STOP 'In SUBROUTINE MXLNEQ in module weigh.f' 
    3 MOD = MMM 
      MM = MMM
      NM = IABS(MM) 
      IF(NM.LT.INTMX) GO TO 4 
      WRITE(6,607)
      WRITE(6,603) MM,INTMX 
      STOP 'In SUBROUTINE MXLNEQ in module weigh.f' 
    4 NM = NN + NM
      NMIDA = NM*ID*2 
      IF(NMIDA.LT.INTMX) GO TO 5
      WRITE(6,607)
      WRITE(6,604) NMIDA,INTMX
      STOP 'In SUBROUTINE MXLNEQ in module weigh.f' 
    5 CONTINUE

C***End of error checking.
C***Continue to initialize.

      K1=1  
      NFLAG=0 
      DET=ONE 

C***MOD is
C***        = -1 DET only (this version does not have this option).
C***        >= 0 for inv, det and 0 or more sets of linear eqns. 
C***        < -1 for linear eqns only and det.
C***
C***Main Gauss-Jordan loop begins:
C***Search for largest pivot candidate in remaining lower right square
C***matrix.

      DO 75 K=1,N 
      PIV=ZERO
      L=K 
      DO 10 I=K,N 
      P=ABS(A(I,K)) 
      IF(PIV.GE.P) GO TO 10 
      PIV=P 
      L=I 
10    CONTINUE

C***Pivot with abs value PIV and subscripts L and M has been found.

      PIVOT=A(L,K)

C***Continue if PIV larger than user EPS.

      IF(PIV.GT.OPS) GO TO 20 
      IF(EPS.EQ.OPS)JRANK=K-1 

C***EPS test failed, check for zero pivot.

      IF(PIV.GT.ZERO) GO TO 15  

C***Pivot is zero, terminate program. (This program does not do DET only!)
      
      WRITE(6,607)
      WRITE(6,605) K  
      STOP 'In SUBROUTINE MXLNEQ in module weigh.f' 

C***Issue non-fatal message, PIV .LE. EPS 

   15 WRITE(6,607)
      WRITE(6,606) K,EPS

C***Set OPS to 0 so solution may continue after error message.

      OPS=ZERO
      PIV=PIVOT 

C***Calculate determinant and check for overflow.

   20 DET=PIVOT*DET                                                     
      IF(ABS(DET).LT.MACHEP) GO TO 25 
      WRITE(6,607)
      WRITE(6,608)K,DET 
      STOP 'In SUBROUTINE MXLNEQ in module weigh.f' 

C***Reset leading row DO index for LIN EQN ONLY case.

   25 IF(MOD.LT.0)K1=K

C***Save PIVOT index.

      IN(K)=L 

C***Check for row interchange.

      IF(L.EQ.K) GO TO 50 
      DET=-DET

C***Interchange row containing pivot and current row. 
C***Only partial rows need be exchanged for LIN EQN ONLY
C***since lower left partially formed triangle is not needed.

      DO 30 J=K1,NM 
      Z=A(L,J)
      A(L,J)=A(K,J) 
30    A(K,J)=Z

C***Pivot element is now on diagonal.
C***Save division time by using reciprocal of pivot.

50    PIVOT=ONE/PIVOT 

C***Pre-divide necessary portion of pivot row.

      DO 55 J=K1,NM 
55    A(K,J)=A(K,J)*PIVOT 

C***Set pivot element to zero so main reduction step doesnt operate on
C***pivot row.

      A(K,K)=ZERO 

C***Sweep through all or part of matrix using Kth row, pivot row, to
C***reduce the matrix.

      DO 70 I=K1,N
      Z=A(I,K)
      IF(Z.EQ.ZERO) GO TO 70

C***This check not only prevents operating on pivot row but catches 
C***other zeroes in pivot columns. These other zeroes would leave Jth
C***row unchanged in following loop so considerable time may be saved by
C***skipping operation.

      DO 65 J=K1,NM 
65    A(I,J)=A(I,J)-Z*A(K,J)

C***The inverse is created in place by substituting an identity matrix
C***col by col, since we are substituting the pivot row from off diagonal 0 
C***elements at this point, we now place -A(I,K)/A(K,K) at this point in 
C***the pivot column.

      A(I,K)=-Z*PIVOT 
70    CONTINUE

C***Similarly dividing pivot row by the pivot is equivalent to placing
C***ONE/A(K,K) at the pivot point for the inverse.

75    A(K,K)=PIVOT
      IF(N.EQ.1) GO TO 110
      IF(MOD.GE.0) GO TO 77 

C***Back substitution for LIN EQN ONLY case.

      K1=K1+1 
      DO 125 K=K1,NM  
      I=N 
      DO 125 L=2,N
      I1=I  
      I=I-1 
      Z=ZERO
      DO 120 J=I1,N 
120   Z=Z+A(I,J)*A(J,K) 
125   A(I,K)=A(I,K)-Z 
      GO TO 110 

C***Final reordering of matrix.

77    K=N 

C***Skip last step since no interchange could occur there.

      DO 105 J=2,N

C***Perform interchanges in exact reverse order of previous execution.

      K=K-1 

C***Row interchange during inversion implies column interchange here.

      M=IN(K) 
      IF(M.EQ.K) GO TO 105

C***Column interchange.

      DO 85 I=1,N 
      Z=A(I,K)
      A(I,K)=A(I,M) 
85    A(I,M)=Z
105   CONTINUE
110   DETT=DET
      RETURN
  600 FORMAT(11H ARG 2, N = ,I10/7X,4H ID=,I10/ 
     1       29H N must be .GE. 1 and .LE. ID)
  601 FORMAT(12H ARG 3, ID = ,I10 /9X,3H N=,I10/
     1       27H ID must be .GE. N and .LE. ,I10) 
  602 FORMAT(13H ARG 6, EPS = ,1PE13.5/ 
     1       33H EPS must be .GE. ZERO and finite)
  603 FORMAT(11H ARG 8, M = ,I10/ 
     1   20H ABS(M) must be .LE. ,I10 ) 
  604 FORMAT(7H Size = ,I10/
     1       36H Size = ID*(N+ABS(M))*2 must be .LE. ,I10)
  605 FORMAT(4H K =,I10/
     1       46H At step K a Gauss-Jordan pivot value was zero) 
  606 FORMAT(4H K = ,I10/6H EPS = ,1PE13.5/ 
     1   50H AT STEP K A GAUSS-JORDAN pivot value was .LE. EPS )
  607 FORMAT(15H *** MXLNEQ *** ) 
  608 FORMAT(4H K = ,I10/6H DET = ,1PE13.5/ 
     1        27H At step K DET is too large )
      END 
      SUBROUTINE MXMPLY(A,B,C,N1,N2,N3,IDA,IDB,IDC,TEMP)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z) 
      SAVE
      DIMENSION A(N1*IDA),B(N2*IDB),C(N3*IDC),TEMP(N3)
      DATA ZERO/0.0D0/
      DO 40 IC = 1,N1 
      DO 20 JC = 1,N3 
      NJB = (JC-1)*IDB
      SUM = ZERO
      DO 10 K = 1,N2  
      NJA = (K-1)*IDA + IC
   10 SUM = SUM + A(NJA)*B(NJB+K) 
   20 TEMP(JC) = SUM  
      DO 30 JC = 1,N3 
      NJC = (JC-1)*IDC + IC 
   30 C(NJC) = TEMP(JC) 
   40 CONTINUE
      RETURN
      END 
      DOUBLE PRECISION FUNCTION DGAMMA(Z)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)

C***   This is a procedure that evaluates GAMMA(Z) for
C***0 LT Z LE 3 to 16 significant figures.
C***It is based on a Chebyshev-type polynomial
C***approximation given in H. Werner and R. collinge, Math. Comput.
C***15 (1961), pp. 195-97.
C***Approximations to the GAMMA function, accurate up to 18 significant
C***digits, may be found in the paper quoted above.

      DIMENSION  A(18)

       A(1)=1.0D0
       A(2)=.4227843350984678D0
       A(3)=.4118403304263672D0
       A(4)=.0815769192502609D0
       A(5)=.0742490106800904D0
       A(6)=-.0002669810333484D0
       A(7)=.0111540360240344D0
       A(8)=-.0028525821446197D0
       A(9)=.0021036287024598D0
       A(10)=-.0009184843690991D0
       A(11)=.0004874227944768D0
       A(12)=-.0002347204018919D0
       A(13)=.0001115339519666D0
       A(14)=-.0000478747983834D0
       A(15)=.0000175102727179D0
       A(16)=-.0000049203750904D0
       A(17)=.0000009199156407D0
       A(18)=-.0000000839940496D0

      IF(Z.LE.1.0D0  ) GO TO 10
      IF(Z.LE.2.0D0  ) GO TO 20
      T=Z-2.0D0
      GO TO 30
10    T=Z
      GO TO 30
20    T=Z-1.0D0
30    P=A(18)
      DO 40 K1=1,17
      K=18-K1
      P=T*P+A(K)
40    CONTINUE

      IF(Z.GT.2.0D0  ) GO TO 50
      IF(Z.GT.1.0D0  ) GO TO 60
      DGAMMA=P/(Z*(Z+1.0D0  ))
      RETURN
60    DGAMMA=P/Z
      RETURN
50    DGAMMA=P
      RETURN
      END
      FUNCTION CLEB(JA,JB,JC,MA,MB,MC)                                  
      IMPLICIT DOUBLE PRECISION  (A-H,O-Z)                              

C***  This program was written by G. A. Parker 1/3/77.  For a               
C***description of the algorithm used see Klaus Schulten and R. G.        
C***Gordon JMP 16,1961,(1975).                                           
C***This program is most efficient when a series of Clebsch-
C***Gordan coefficients are desired.                                       

      DIMENSION F(500)                                                  
      DATA J2OLD,J3OLD,M1OLD,M2OLD/-1,-1,-1,-1/                     

C***Statement functions used in recurrence relations.

      A(SJ1) =DSQRT((SJ1-SJ2MJ3)*(SJ2J31-SJ1)*(SJ1-SM1))                
      B(XJ1) = -(2.0D0*XJ1+1)*(XJ2M-XJ3M-XJ1*(XJ1+1)*XM1)               

C***Check triangle inequalities.

      IF (IABS(MC) .GT. JC) GO TO 220                                   
      IF (IABS(MB) .GT. JB) GO TO 220                                   
      IF (IABS(MA) .GT. JA) GO TO 220                                   
      IF (MC .NE. MA+MB) GO TO 220                                      

C***Calculate maximum and minimum allowed values of J1.

      J1 = JA                                                           
      J2 = JB                                                           
      J3 = JC
      M1 = MA                                                           
      M2 = MB                                                           
      M3 = -MC
      JX = IABS(J2-J3)                                                  
      MX = IABS(M1)                                                     
      J1MAX = J2+J3                                                     
      J1MIN = MAX0(JX,MX)                                               
      IF (J1 .GT. J1MAX .OR. J1 .LT. J1MIN) GO TO 220                   

C***Check to see if the Clebsch-Gordan coefficient has already            
C***determined.                                                           

      IF (J2OLD .NE. J2) GO TO 100                                      
      IF (J3OLD .NE. J3) GO TO 100                                      
      IF (M1OLD .NE. M1) GO TO 100                                      
      IF (M2OLD .NE. M2) GO TO 100                                      
      GO TO 190                                                         

C***Coefficients have not been previously determined.

  100 J2OLD = J2                                                        
      J3OLD = J3                                                        
      M1OLD = M1                                                        
      M2OLD = M2                                                        

C***Determine constants for statement functions.

      SJ2MJ3 = DBLE(JX*JX)                                              
      SJ2J31 = DBLE((J1MAX+1)*(J1MAX+1))                                
      SM1 = DBLE(MX*MX)                                                 
      XJ2M = DBLE(J2*(J2+1)*M1)                                         
      XJ3M = DBLE(J3*(J3+1)*M1)                                         
      XM1 = DBLE(-M1-M2-M2)                                             
                                                                        

C***Determine where the middle coefficient is located and the
C***number of coefficients.

      NCOEF = J1MAX-J1MIN+1                                             
      MID = NCOEF/2+1                                                   
      IF (NCOEF .LE. 2) GO TO 200                                       

C***Set initial values for the coefficients F(1) and F(NCOEF).

      F(1) = 1.D0                                                       
                                                                        
      F(NCOEF) = 1.D0                                                   
                                                                        

C***Use equations 16 and 17 from the reference to determine
C***F(2) and F(NCOEF-1).

      IF (J1MIN .NE. 0) GO TO 110                                       
      XM = DBLE(2*M2)                                                   
      X = DBLE((2*J2+1)**2-1)                                           
      F(2) = -F(1)*XM/DSQRT(X)                                          
      GO TO 120                                                         
  110 XJ1 =  DBLE(J1MIN)                                                
      XJ1P1 =  DBLE(J1MIN+1)                                            
      SJ1P1 = XJ1P1*XJ1P1                                               
      F(2) = F(1)*B(XJ1)/(XJ1*A(SJ1P1))                                 
  120 G = F(2)                                                          
      N2 = NCOEF-1                                                      
      XJ1 =  DBLE(J1MAX)                                                
      SJ1 = XJ1*XJ1                                                     
      F(N2) = F(NCOEF)*B(XJ1)/((XJ1+1.0D0)*A(SJ1))                      
      MID1 = MID-1                                                      
      IF (NCOEF .EQ. 3) GO TO 140                                       

C***Start recursive evaluation of the coefficients using                  
C***equation 6'.                                                          

      DO 130 I = 2,MID1                                                 
      IP1 = I+1                                                         
      IM1 = I-1                                                         
      XJ1 =  DBLE(J1MIN+I-1)                                            
      XJ1P1 = XJ1+1.0D0                                                 
      SJ1 = XJ1*XJ1                                                     
      SJ1P1 = XJ1P1*XJ1P1                                               
      G = (B(XJ1)*F(I)-XJ1P1*A(SJ1)*F(IM1))/(XJ1*A(SJ1P1))              
      N2 = NCOEF-I+1                                                    
      IF (N2 .EQ. MID) GO TO 140                                        
      F(IP1) = G                                                        
      XJ1 =  DBLE(J1MAX-I+1)                                            
      XJ1P1 = XJ1+1.0D0                                                 
      IP1 = N2+1                                                        
      IM1 = N2-1                                                        
      SJ1 = XJ1*XJ1                                                     
      SJ1P1 = XJ1P1*XJ1P1                                               
  130 F(IM1) = (-XJ1*A(SJ1P1)*F(IP1)+B(XJ1)*F(N2))/(XJ1P1*A(SJ1))       

C***Match at the midpoint.

  140 IF (ABS(G) .GT. 1.D-8) GO TO 150                                  
                                                                        
      I = MID                                                           
      IM1 = MID1                                                        
      XJ1 =  DBLE(J1MIN+MID1)                                           
      XJ1P1 = XJ1+1.0D0                                                 
      SJ1 = XJ1*XJ1                                                     
      SJ1P1 = XJ1P1*XJ1P1                                               
      G = (B(XJ1)*F(I)-XJ1P1*A(SJ1)*F(IM1))/(XJ1*A(SJ1P1))              
      MID1 = MID                                                        
      MID = MID+1                                                       
  150 COEF = F(MID)/G                                                   
      DO 160 I = 1,MID1                                                 
  160 F(I) = COEF*F(I)                                                  

C***Find magnitude of the normalization coefficient.

      SUM = 0.0D0                                                       
      X =  DBLE(J1MIN*2-1)                                              
      DO 170 I = 1,NCOEF                                                
      X = X+2.0D0                                                       
  170 SUM = SUM+X*F(I)*F(I)                                             
      COEF =DSQRT(1.0D0/SUM)                                            
                                                                        
C***Determine sign of the normalization coefficient.

      SIG = 1.0D0                                                       
      J = J2-J3-M1                                                      
      IF ((J/2)*2 .NE. J) SIG = -1.0D0                                  
      COEF = DSIGN(COEF,SIG)                                            

C***Normalize to obtain the Clebsch-Gordan coefficients.

      Y =  DBLE(2*J3+1)                                                 
      Y =DSQRT(Y)                                                       
      J3M3 = J3+M3                                                      
      IF ((J3M3/2)*2 .NE. J3M3) Y = -Y                                  
      DO 180 I = 1,NCOEF                                                
  180 F(I) = COEF*F(I)*Y                                                
  190 I = J1-J1MIN+1                                                    
      CLEB= F(I)                                                        
      RETURN                                                            
  200 IF (NCOEF .EQ. 2) GO TO 210                                       

C***Special case for only 1 coefficient.

      Y =  DBLE(2*J3+1)                                                 
      X =  DBLE(2*J1+1)                                                 
      J = J2-M2                                                         
      SIG = 1.0D0                                                       
      IF ((J/2)*2 .NE. J) SIG = -1.0D0                                  
      F(1) =DSQRT(Y/X)*SIG                                              
      GO TO 190                                                         

C***Special case for only 2 coefficients.

  210 F(1) = -1.0D0                                                     
      XJ1 =  DBLE(J1MIN)                                                
      XJ1P1 =  DBLE(J1MIN+1)                                            
      SJ1P1 = XJ1P1*XJ1P1                                               
      F(2) = F(1)*B(XJ1)/(XJ1*A(SJ1P1))                                 
      X = DBLE(J1MIN*2+1)                                               
      SUM = X*F(1)*F(1)+(X+2.0D0)*F(2)*F(2)                             
      COEF =DSQRT(1.0D0/SUM)                                            
      SIG = 1.0D0                                                       
      J = J2-J3-M1                                                      
      IF ((J/2)*2 .NE. J) SIG = -1.0D0                                  
      SIG = SIG*F(2)                                                    
      COEF = DSIGN(COEF,SIG)                                            
      Y =  DBLE(2*J3+1)                                                 
      Y =DSQRT(Y)                                                       
      J3M3 = J3+M3                                                      
      IF ((J3M3/2)*2 .NE. J3M3) Y = -Y                                  
      F(1) = COEF*Y*F(1)                                                
      F(2) = COEF*Y*F(2)                                                
      GO TO 190                                                         

C***Triangle inequalities were not satisfied.

  220 CLEB= 0.0D0                                                       
      RETURN                                                            
      END                                                               
      SUBROUTINE GGAUSX(N,XMOM,X,IPRNT,RE,BC,SIG)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE
C***  Calculate integration nodes given (R-RE) moments.
C***Use Sack and Donovan algorithm.

      DIMENSION XMOM(N*2),X(N)
      PARAMETER (ZERO=0.0D0,ONE=1.0D0)
      DIMENSION BC(10*N),SIG(2*N+1,2*N+1)
      DO 1 I=1,2*N
       BC(I)=ZERO
       BC(2*N+I)=RE
       BC(4*N+I)=ZERO
    1 CONTINUE
      IF(IPRNT.GE.3)THEN
       WRITE(6,2)
    2  FORMAT(/1X,'Moment integrals in GGAUSS ')
       CALL PRNTM2(XMOM,1,N*2,1)
      END IF
      CALL ORTHOG(N,XMOM,BC(2*N+1),BC(1),BC(6*N+1),BC(7*N+1),SIG)
      CALL GAUCOF(N,BC(6*N+1),BC(7*N+1),XMOM,X,BC(8*N+1))
      IF(X(1).LT.ZERO)THEN
       WRITE(6,3)X(1)
    3  FORMAT(/1X,'In GGAUSX, first quadrature point = ',1PE15.7,
     $        /1X,'which is a non-physical value.')
      STOP 'Vib Quad incorrect in GGAUSX in weigh.f '
      END IF

C***  Note that the vibrational quadrature points we want
C***to be returned to the program should be defined in terms of
C***(R-RE) and so we should subtract RE from the elements of X
C***before returning to the calling routine.

      DO 5 I=1,N
        X(I)=X(I)-RE
    5 CONTINUE

C***Diagnostic write-out.

C      WRITE(6,*)('NODES FROM LQMD ')
C      CALL PRNTM2(X,1,N,1)

      RETURN
      END
      SUBROUTINE ORTHOG(N,ANU,ALPHA,BETA,A,B,SIG)                       MJU12-02
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)                               MJU12-02
      SAVE

C***From "Orthogonal polynomials and Gaussian quadrature witH
C***nonclassical weight functions" by W.H. Press and S.A. Teukolsky,
C***Computers in Physics, p. 423, Jul/Aug 1990.

      PARAMETER (NMAX=60)
      DIMENSION A(N),ALPHA(2*N),ANU(N*2),B(N),BETA(2*N),
     1SIG(2*NMAX+1,2*NMAX+1)

C***computes the coefficients A_J and B_J, J=0,...N-1, of the
C***recurrence relation for monic orthogonal polynomials with
C***weight function W(X) by Wheeler's algorithm. On input,
C***ALPHA and BETA are the coefficients \ALPHA_J and \BETA_J,
C***J=0,...,2*N-1, of the recurrence relation for the
C***chosen basis of orthogonal polynomials. The modified
C***moments \NU_J are input in ANU. The first N coefficients
C***are returned in A and B.

      IF(N.GT.NMAX)THEN
       WRITE(6,1)N,NMAX
    1  FORMAT(/1X,'Error in ORTHOG: dimensions would have been',
     $      ' exceeded. ',2I5)
       STOP 'STOP in WEIGH in weigh.f'
      END IF
      DO 11 I=3,2*N
       SIG(I,1)=0D0
   11 CONTINUE
      DO 12 I=2,2*N+1
       SIG(I,2)=ANU(I-1)
   12 CONTINUE
      A(1)=ALPHA(1)+ANU(2)/ANU(1)
      B(1)=0D0
      DO 13 K=3,N+1
       DO 14 L=K,2*N-K+3
        SIG(L,K)=SIG(L+1,K-1)+(ALPHA(L-1)-A(K-2))*SIG(L,K-1)
     $          -B(K-2)*SIG(L,K-2)+BETA(L-1)*SIG(L-1,K-1)
   14  CONTINUE
       A(K-1)=ALPHA(K-1)+(SIG(K+1,K)/SIG(K,K))-(SIG(K,K-1)/SIG(K-1,K-1))

C***Diagnostic write-out.

C      WRITE(6,153)K,ALPHA(K-1),A(K-1),SIG(K,K),SIG(K-1,K-1),SIG(K+1,K),
C    $           SIG(K,K-1)
C 153  FORMAT(1X,I5,1P6E15.7)

       B(K-1)=SIG(K,K)/SIG(K-1,K-1)
   13 CONTINUE
      RETURN
      END
      SUBROUTINE GAUCOF(N,A,B,AMU0,X,W)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)                               MJU12-02
      SAVE

C***From "Orthogonal Polynomials and Gaussian quadrature with
C***nonclassical weight functions" by W.H. press and S.A. Teukolsky,
C***Computers in Physics, p. 423, Jul/Aug 1990.

      PARAMETER (NMAX=64)
      DIMENSION A(N),B(N),X(N),W(2*N)                                   MJU12-02

C***Computes the abscissas and weights for a Gaussian quadrature formula
C***from the Jacobi matrix. On input, A and B are the coefficients of the
C***recurrence relation for the set of monic orthogonal polynomials. The
C***quantity AMU0 is the integral of the weight function (i.e. the
C***scalar product of the first (constant) polynomial with itself).
C***The abscissas and weights are returned in descending order in X and W.

      DIMENSION Z(NMAX,NMAX)
      IF(N.GT.NMAX)THEN
       WRITE(6,2)N,NMAX
    2  FORMAT(/1X,'Error in GAUCOF: Dimensions would have been ',
     $       'exceeded ',2I5)
       STOP 'STOP in GAUCOF in weigh.f'
      END IF
      DO 11 I=1,N
       X(I)=A(I)
      IF(I.NE.1)W(I)=SQRT(B(I))
       DO 12 J=1,N
        Z(I,J)=0D0
   12  CONTINUE
       Z(I,I)=1D0
   11 CONTINUE
      CALL IMTQL2(NMAX,N,X,W,Z,IERR)
      IF(IERR.NE.0)THEN
       WRITE(6,1)IERR
    1  FORMAT(/1X,'In GAUCOF, on return from IMTQL2, IERR = ',I10)
       STOP 'STOP in GAUCOF after call IMTQL2 in weigh.f'
      END IF
      DO 13 I=1,N
       W(I)=AMU0*Z(1,I)*Z(1,I)
   13 CONTINUE
      RETURN
      END
      SUBROUTINE GTEN(A,B,FINTEG,QUAD,NDIV)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE

C***Calls GAUS10 NDIV times to do Gauss-Legendre quadrature.
C***Each call to GAUS10 is a 10-point quadrature.

      EXTERNAL FINTEG
      H=(B-A)/DBLE(NDIV)
      QUAD=0.0D0
      DO 900 N=1,NDIV
      FNM1=DBLE(N-1)
      C=A+H*FNM1
      D=C+H
      CALL GAUS10(C,D,FINTEG,F)
      QUAD=QUAD+F
  900 CONTINUE
      RETURN
      END
      SUBROUTINE GAUS10(A,B,FINTEG,QUAD)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE

      EXTERNAL FINTEG
      DIMENSION PT(5),WT(5)
      DATA PT(1)/0.148874338981631D0/
      DATA PT(2)/0.433395394129247D0/
      DATA PT(3)/0.679409568299024D0/
      DATA PT(4)/0.865063366688985D0/
      DATA PT(5)/0.973906528517172D0/
      DATA WT(1)/0.295524224714753D0/
      DATA WT(2)/0.269266719309996D0/
      DATA WT(3)/0.219086362515982D0/
      DATA WT(4)/0.149451349150581D0/
      DATA WT(5)/0.066671344308688D0/
      UNIT=(B-A)/2.0D0
      CENTER=(A+B)/2.0D0
      SIGN=-1.0D0
      QUAD=0.0D0
      DO 900 ISIGN=1,2
      FMULT=SIGN*UNIT
      DO 800 I=1,5
      Y=CENTER+FMULT*PT(I)
      F=WT(I)*FINTEG(Y)
      QUAD=QUAD+F
  800 CONTINUE
  900 SIGN=1.0D0
      QUAD=QUAD*UNIT
      RETURN
      END
      FUNCTION FINT1(T)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)

C***CALCULATE INTEGRAND

      DIMENSION RINT(99),X(99),S(99),PL(300),RINTA(99),RINTB(99)
      COMMON/INCOM/RINTA,RINTB,X,NP,NI,L,IREAL
      COMMON/INCOM2/RINT
      SINT=SIN(T)
      COST=SQRT(1D0-SINT*SINT)
      CALL LEG(PL,L,COST)
      F=PL(L)
      FINT1=SINT*F*AITKNG(T,RINT,S,X,NI,NP)
      RETURN
      END
      DOUBLE PRECISION FUNCTION AITKNG(Y,FX,GX,X,N,NDIM)

C***Finds AITKNG=FX(Y) from table of FX(X).
C***X'S must be in increasing order.
C***GX is a scratch array, of DIMENSION at least N+1.
C***N is number of points used to interpolate.  It must be even.
C***NDIM is number of elements of FX and X to be searched.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      COMMON /BUGCOM/ IS,NHALF
      DIMENSION FX(NDIM),X(NDIM),GX(1)
      IF (NDIM.LE.N) STOP 'NDIM < N in AITKNG in weigh.f'
      IF (N.LT.2) STOP 'N < 2 in AITKNG in weigh.f'
      IF(Y.GT.X(NDIM)) THEN
      WRITE(6,24)Y,X(NDIM)
   24 FORMAT(1X,'Bad limits on array Y in AITKNG',1PE15.8)
      ZERO=0.0D+0
      STOP 
      ENDIF
      NHALF = N/2
      IMIN =NHALF + 1
      IF (Y.GT.X(NDIM-NHALF)) GO TO 2
      DO 1 I=IMIN,NDIM
      IF (X(I).GT.Y) GO TO 4
    1 CONTINUE
    2 IS=NDIM-N
      GO TO 5
    4 IS=I-NHALF-1
    5 CONTINUE
      DO 40 I=1,N
   40 GX(I)=FX(IS+I)
      NM1=N-1
      DO 50 I = 1,NM1
      IP = I + 1
      DO 20 J = IP,N
      ISPJ=IS+J
      ISPI=IS+I
   20 GX(J) = (GX(I)*(X(ISPJ)-Y) - GX(J)*(X(ISPI)-Y))/(X(ISPJ)-X(ISPI))
   50 CONTINUE
      AITKNG = GX(N)
      RETURN
      END
      SUBROUTINE SDATA(N,XS)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE

C***This subroutine supplies the nodes for Hutson quadrature.

      DIMENSION XS(N),A1(2),A2(3),A3(4),A4(5),A5(6),A6(7),A7(8),A8(9),
     1          A9(10),A10(11),A11(12),A12(13),A13(14),A14(15)

      DATA A1/
     1        1.21845994025010D-01, -5.67466455969532D-02/
      DATA A2/
     1 2.04576347726030D-01, 4.36788881912811D-02,-1.07516920530722D-01
     2 /
      DATA A3/
     1 2.77833578775263D-01, 1.24854312723061D-01,-9.85543740795438D-03,
     2-1.46687523747592D-01
     3 /
      DATA A4/
     1 3.45672335651022D-01, 1.96964006098268D-01, 6.97124967089651D-02, 
     2-5.13754271546761D-02,-1.78823217032974D-01
     3 /
      DATA A5/
     1 4.10101476122449D-01, 2.63798308964395D-01, 1.40643446198689D-01,
     2 2.67407774728946D-02,-8.55089650875790D-02,-2.06146374951742D-01
     3 /
      DATA A6/
     1 4.72295863733512D-01, 3.27269584868073D-01, 2.06499028886589D-01,
     2 9.65903025402070D-02,-8.67572391808716D-03,-1.14549527010676D-01, 
     3-2.29927667152302D-01
     4 /
      DATA A7/
     1 5.33020710550743D-01, 3.88510042129439D-01, 2.69094401301673D-01,
     2 1.61554738372168D-01, 6.02043284152370D-02,-3.88483754435263D-02,
     3-1.39823710246296D-01,-2.50970165817455D-01
     4 /
      DATA A8/
     1 5.92815132585028D-01, 4.48263319219299D-01, 3.29513022519999D-01,
     2 2.23367365136812D-01, 1.24369611202854D-01, 2.91667041580671D-02,
     3-6.51249184284014D-02,-1.62176586844661D-01,-2.69817634791732D-01
     4 /
      DATA A9/
     1 6.52083271721403D-01, 5.07056306884790D-01, 3.88471198373216D-01,
     2 2.83068264110144D-01, 1.85485684151351D-01, 9.26177324390860D-02,
     3 2.11807692061299D-03,-8.83692121057372D-02,-1.82183552424429D-01,
     4-2.86587320706917D-01
     5 /
      DATA A10/
     1 7.11144239797734D-01, 5.65285408766697D-01, 4.46479136659112D-01,
     2 3.41348341649614D-01, 2.44555545759190D-01, 1.53113840290710D-01,
     3 6.49306406781814D-02,-2.18167250350586D-02,-1.09172276098399D-01,
     4-2.00256023438835D-01,-3.02375859671720D-01
     5 / 
      DATA A11/
     1 7.70261668393069D-01, 6.23264246680249D-01, 5.03992310655792D-01,
     2 3.98701801102262D-01, 3.02247804285682D-01, 2.11626453864474D-01,
     3 1.24874291775005D-01, 4.04245060658709D-02,-4.32386545469433D-02,
     4-1.27958298493064D-01,-2.16699414556198D-01,-3.16591984645357D-01
     5 /
      DATA A12/
     1 8.29662327955816D-01, 6.81252090229320D-01, 5.61106711557025D-01,
     2 4.55503428656840D-01, 3.59042332338977D-01, 2.68804860819669D-01,
     3 1.82893430710121D-01, 9.98753155156126D-02, 1.84907718912772D-02,
     4-6.25803346412785D-02,-1.45043121256230D-01,-2.31747285581261D-01,
     5-3.29676781170889D-01
     6 /
      DATA A13/
     1 8.89548526637673D-01, 7.39471874322491D-01, 6.18285954885676D-01,
     2 5.12051723871602D-01, 4.15304229313187D-01, 3.25116355939139D-01,
     3 2.39620612848030D-01, 1.57456788159711D-01, 7.75016709229130D-02,
     4-1.30968388958402D-03,-8.01646951668539D-02,-1.60668857659151D-01,
     5-2.45582602495585D-01,-3.41766818993918D-01
     6 /
      DATA A14/
     1 9.50106807569774D-01, 7.98122252347408D-01, 6.75678540257564D-01,
     2 5.68594823125577D-01, 4.71325181846761D-01, 3.80917474488040D-01,
     3 2.95512152480339D-01, 2.13786936113319D-01, 1.34694850568796D-01,
     4 5.73086184061313D-02,-1.93052960974547D-02,-9.62397969522216D-02,
     5-1.75025538292498D-01,-2.58351580828932D-01,-3.52972991487450D-01
     6 /
      GOTO (1,2,3,4,5,6,7,8,9,10,11,12,13,14,15), N
    1 WRITE(6,100)N
  100 FORMAT(1X,'Illegal choice for N in SDATA, N= ',I5) 
      STOP 'Bad value of NPOINTS in SDATA in weigh.f'
    2 DO 22 I=1,N
      XS(I)=A1(I)
   22 CONTINUE
      RETURN 
    3 DO 23 I=1,N
      XS(I)=A2(I)
   23 CONTINUE
      RETURN 
    4 DO 24 I=1,N
      XS(I)=A3(I)
   24 CONTINUE
      RETURN 
    5 DO 25 I=1,N
      XS(I)=A4(I)
   25 CONTINUE
      RETURN 
    6 DO 26 I=1,N
      XS(I)=A5(I)
   26 CONTINUE
      RETURN 
    7 DO 27 I=1,N
      XS(I)=A6(I)
   27 CONTINUE
      RETURN 
    8 DO 28 I=1,N
      XS(I)=A7(I)
   28 CONTINUE
      RETURN 
    9 DO 29 I=1,N
      XS(I)=A8(I)
   29 CONTINUE
      RETURN 
   10 DO 30 I=1,N
      XS(I)=A9(I)
   30 CONTINUE
      RETURN 
   11 DO 31 I=1,N
      XS(I)=A10(I)
   31 CONTINUE
      RETURN 
   12 DO 32 I=1,N
      XS(I)=A11(I)
   32 CONTINUE
      RETURN 
   13 DO 33 I=1,N
      XS(I)=A12(I)
   33 CONTINUE
      RETURN 
   14 DO 34 I=1,N
      XS(I)=A13(I)
   34 CONTINUE
      RETURN 
   15 DO 35 I=1,N
      XS(I)=A14(I)
   35 CONTINUE
      RETURN 
      END

      SUBROUTINE IMTQL2(NM,N,D,E,Z,IERR)
C
      INTEGER I,J,K,L,M,N,II,NM,MML,IERR
      DOUBLE PRECISION D(N),E(N),Z(NM,N)
      DOUBLE PRECISION B,C,F,G,P,R,S,TST1,TST2,PYTHAG
C
C     THIS SUBROUTINE IS A TRANSLATION OF THE ALGOL PROCEDURE IMTQL2,
C     NUM. MATH. 12, 377-383(1968) BY MARTIN AND WILKINSON,
C     AS MODIFIED IN NUM. MATH. 15, 450(1970) BY DUBRULLE.
C     HANDBOOK FOR AUTO. COMP., VOL.II-LINEAR ALGEBRA, 241-248(1971).
C
C     THIS SUBROUTINE FINDS THE EIGENVALUES AND EIGENVECTORS
C     OF A SYMMETRIC TRIDIAGONAL MATRIX BY THE IMPLICIT QL METHOD.
C     THE EIGENVECTORS OF A FULL SYMMETRIC MATRIX CAN ALSO
C     BE FOUND IF  TRED2  HAS BEEN USED TO REDUCE THIS
C     FULL MATRIX TO TRIDIAGONAL FORM.
C
C     ON INPUT
C
C        NM MUST BE SET TO THE ROW DIMENSION OF TWO-DIMENSIONAL
C          ARRAY PARAMETERS AS DECLARED IN THE CALLING PROGRAM
C          DIMENSION STATEMENT.
C
C        N IS THE ORDER OF THE MATRIX.
C
C        D CONTAINS THE DIAGONAL ELEMENTS OF THE INPUT MATRIX.
C
C        E CONTAINS THE SUBDIAGONAL ELEMENTS OF THE INPUT MATRIX
C          IN ITS LAST N-1 POSITIONS.  E(1) IS ARBITRARY.
C
C        Z CONTAINS THE TRANSFORMATION MATRIX PRODUCED IN THE
C          REDUCTION BY  TRED2, IF PERFORMED.  IF THE EIGENVECTORS
C          OF THE TRIDIAGONAL MATRIX ARE DESIRED, Z MUST CONTAIN
C          THE IDENTITY MATRIX.
C
C      ON OUTPUT
C
C        D CONTAINS THE EIGENVALUES IN ASCENDING ORDER.  IF AN
C          ERROR EXIT IS MADE, THE EIGENVALUES ARE CORRECT BUT
C          UNORDERED FOR INDICES 1,2,...,IERR-1.
C
C        E HAS BEEN DESTROYED.
C
C        Z CONTAINS ORTHONORMAL EIGENVECTORS OF THE SYMMETRIC
C          TRIDIAGONAL (OR FULL) MATRIX.  IF AN ERROR EXIT IS MADE,
C          Z CONTAINS THE EIGENVECTORS ASSOCIATED WITH THE STORED
C          EIGENVALUES.
C
C        IERR IS SET TO
C          ZERO       FOR NORMAL RETURN,
C          J          IF THE J-TH EIGENVALUE HAS NOT BEEN
C                     DETERMINED AFTER 30 ITERATIONS.
C
C     CALLS PYTHAG FOR  DSQRT(A*A + B*B) .
C
C     QUESTIONS AND COMMENTS SHOULD BE DIRECTED TO BURTON S. GARBOW,
C     MATHEMATICS AND COMPUTER SCIENCE DIV, ARGONNE NATIONAL LABORATORY
C
C     THIS VERSION DATED AUGUST 1983.
C
C     ------------------------------------------------------------------
C
      IERR = 0
      IF (N .EQ. 1) GO TO 1001
C
      DO 100 I = 2, N
  100 E(I-1) = E(I)
C
      E(N) = 0.0D0
C
      DO 240 L = 1, N
         J = 0
C     .......... LOOK FOR SMALL SUB-DIAGONAL ELEMENT ..........
  105    DO 110 M = L, N
            IF (M .EQ. N) GO TO 120
            TST1 = DABS(D(M)) + DABS(D(M+1))
            TST2 = TST1 + DABS(E(M))
            IF (TST2 .EQ. TST1) GO TO 120
  110    CONTINUE
C
  120    P = D(L)
         IF (M .EQ. L) GO TO 240
         IF (J .EQ. 30) GO TO 1000
         J = J + 1
C     .......... FORM SHIFT ..........
         G = (D(L+1) - P) / (2.0D0 * E(L))
         R = PYTHAG(G,1.0D0)
         G = D(M) - P + E(L) / (G + DSIGN(R,G))
         S = 1.0D0
         C = 1.0D0
         P = 0.0D0
         MML = M - L
C     .......... FOR I=M-1 STEP -1 UNTIL L DO -- ..........
         DO 200 II = 1, MML
            I = M - II
            F = S * E(I)
            B = C * E(I)
            R = PYTHAG(F,G)
            E(I+1) = R
            IF (R .EQ. 0.0D0) GO TO 210
            S = F / R
            C = G / R
            G = D(I+1) - P
            R = (D(I) - G) * S + 2.0D0 * C * B
            P = S * R
            D(I+1) = G + P
            G = C * R - B
C     .......... FORM VECTOR ..........
            DO 180 K = 1, N
               F = Z(K,I+1)
               Z(K,I+1) = S * Z(K,I) + C * F
               Z(K,I) = C * Z(K,I) - S * F
  180       CONTINUE
C
  200    CONTINUE
C
         D(L) = D(L) - P
         E(L) = G
         E(M) = 0.0D0
         GO TO 105
C     .......... RECOVER FROM UNDERFLOW ..........
  210    D(I+1) = D(I+1) - P
         E(M) = 0.0D0
         GO TO 105
  240 CONTINUE
C     .......... ORDER EIGENVALUES AND EIGENVECTORS ..........
      DO 300 II = 2, N
         I = II - 1
         K = I
         P = D(I)
C
         DO 260 J = II, N
            IF (D(J) .GE. P) GO TO 260
            K = J
            P = D(J)
  260    CONTINUE
C
         IF (K .EQ. I) GO TO 300
         D(K) = D(I)
         D(I) = P
C
         DO 280 J = 1, N
            P = Z(J,I)
            Z(J,I) = Z(J,K)
            Z(J,K) = P
  280    CONTINUE
C
  300 CONTINUE
C
      GO TO 1001
C     .......... SET ERROR -- NO CONVERGENCE TO AN
C                EIGENVALUE AFTER 30 ITERATIONS ..........
 1000 IERR = L
 1001 RETURN
      END
      DOUBLE PRECISION FUNCTION PYTHAG(A,B)
      DOUBLE PRECISION A,B
C
C     FINDS DSQRT(A**2+B**2) WITHOUT OVERFLOW OR DESTRUCTIVE UNDERFLOW
C
      DOUBLE PRECISION P,R,S,T,U
      P = DMAX1(DABS(A),DABS(B))
      IF (P .EQ. 0.0D0) GO TO 20
      R = (DMIN1(DABS(A),DABS(B))/P)**2
   10 CONTINUE
         T = 4.0D0 + R
         IF (T .EQ. 4.0D0) GO TO 20
         S = R/T
         U = 1.0D0 + 2.0D0*S
         P = U*P
         R = (S/U)**2 * R
      GO TO 10
   20 PYTHAG = P
      RETURN
      END
